@@ -21,8 +21,8 @@ else:
     # Use tests from the source
     suites = next(os.walk('dirsrvtests/tests/suites/'))[1]
 
-    # Filter out snmp as it is an empty directory:
-    suites.remove('snmp')
+    # Filter out webui because of broken tests
+    suites.remove('webui')
 
     # Run each replication test module separately to speed things up
     suites.remove('replication')
