@@ -37,10 +37,10 @@ pytestmark = pytest.mark.tier1
 logging.getLogger(__name__).setLevel(logging.DEBUG)
 log = logging.getLogger(__name__)
 
-PLUGIN_TIMESTAMP = 'nsslapd-logging-hr-timestamps-enabled'
 PLUGIN_LOGGING = 'nsslapd-plugin-logging'
 USER1_DN = 'uid=user1,' + DEFAULT_SUFFIX
 
+
 def add_users(topology_st, users_num):
     users = UserAccounts(topology_st, DEFAULT_SUFFIX)
     log.info('Adding %d users' % users_num)
@@ -205,6 +205,7 @@ def set_audit_log_config_values(topology_st, request, enabled, logsize):
 def set_audit_log_config_values_to_rotate(topology_st, request):
     set_audit_log_config_values(topology_st, request, 'on', '1')
 
+
 @pytest.fixture(scope="function")
 def disable_access_log_buffering(topology_st, request):
     log.info('Disable access log buffering')
@@ -217,6 +218,7 @@ def disable_access_log_buffering(topology_st, request):
 
     return disable_access_log_buffering
 
+
 def create_backend(inst, rdn, suffix):
     # We only support dc= in this test.
     assert suffix.startswith('dc=')
@@ -243,54 +245,9 @@ def create_backend(inst, rdn, suffix):
 
     return be1
 
-def test_check_default(topology_st):
-    """Check the default value of nsslapd-logging-hr-timestamps-enabled,
-     it should be ON
-
-    :id: 2d15002e-9ed3-4796-b0bb-bf04e4e59bd3
-
-    :setup: Standalone instance
-
-    :steps:
-         1. Fetch the value of nsslapd-logging-hr-timestamps-enabled attribute
-         2. Test that the attribute value should be "ON" by default
-
-    :expectedresults:
-         1. Value should be fetched successfully
-         2. Value should be "ON" by default
-    """
-
-    # Get the default value of nsslapd-logging-hr-timestamps-enabled attribute
-    default = topology_st.standalone.config.get_attr_val_utf8(PLUGIN_TIMESTAMP)
-
-    # Now check it should be ON by default
-    assert default == "on"
-    log.debug(default)
-
-
-def test_plugin_set_invalid(topology_st):
-    """Try to set some invalid values for nsslapd-logging-hr-timestamps-enabled
-    attribute
-
-    :id: c60a68d2-703a-42bf-a5c2-4040736d511a
-
-    :setup: Standalone instance
-
-    :steps:
-         1. Set some "JUNK" value of nsslapd-logging-hr-timestamps-enabled attribute
-
-    :expectedresults:
-         1. There should be an operation error
-    """
-
-    log.info('test_plugin_set_invalid - Expect to fail with junk value')
-    with pytest.raises(ldap.OPERATIONS_ERROR):
-        topology_st.standalone.config.set(PLUGIN_TIMESTAMP, 'JUNK')
-
 
 def test_log_plugin_on(topology_st, remove_users):
-    """Check access logs for millisecond, when
-    nsslapd-logging-hr-timestamps-enabled=ON
+    """Check access logs for millisecond
 
     :id: 65ae4e2a-295f-4222-8d69-12124bc7a872
 
@@ -323,55 +280,6 @@ def test_log_plugin_on(topology_st, remove_users):
     assert topology_st.standalone.ds_access_log.match(r'^\[.+\d{9}.+\].+')
 
 
-def test_log_plugin_off(topology_st, remove_users):
-    """Milliseconds should be absent from access logs when
-    nsslapd-logging-hr-timestamps-enabled=OFF
-
-    :id: b3400e46-d940-4574-b399-e3f4b49bc4b5
-
-    :setup: Standalone instance
-
-    :steps:
-         1. Set nsslapd-logging-hr-timestamps-enabled=OFF
-         2. Restart the server
-         3. Delete old access logs
-         4. Do search operations to generate fresh access logs
-         5. Restart the server
-         6. Check access logs
-
-    :expectedresults:
-         1. Attribute nsslapd-logging-hr-timestamps-enabled should be set to "OFF"
-         2. Server should restart
-         3. Access logs should be deleted
-         4. Search operation should PASS
-         5. Server should restart
-         6. There should not be any milliseconds added in the access logs
-    """
-
-    log.info('Bug 1273549 - Check access logs for missing millisecond, when attribute is OFF')
-
-    log.info('test_log_plugin_off - set the configuration attribute to OFF')
-    topology_st.standalone.config.set(PLUGIN_TIMESTAMP, 'OFF')
-
-    log.info('Restart the server to flush the logs')
-    topology_st.standalone.restart(timeout=10)
-
-    log.info('test_log_plugin_off - delete the previous access logs')
-    topology_st.standalone.deleteAccessLogs()
-
-    # Now generate some fresh logs
-    add_users(topology_st.standalone, 10)
-    search_users(topology_st.standalone)
-
-    log.info('Restart the server to flush the logs')
-    topology_st.standalone.restart(timeout=10)
-
-    log.info('check access log that microseconds are not present')
-    access_log_lines = topology_st.standalone.ds_access_log.readlines()
-    assert len(access_log_lines) > 0
-    assert not topology_st.standalone.ds_access_log.match(r'^\[.+\d{9}.+\].+')
-
-
 @pytest.mark.xfail(ds_is_older('1.4.0'), reason="May fail on 1.3.x because of bug 1358706")
 def test_internal_log_server_level_0(topology_st, clean_access_logs, disable_access_log_buffering):
     """Tests server-initiated internal operations
@@ -391,7 +299,6 @@ def test_internal_log_server_level_0(topology_st, clean_access_logs, disable_acc
     topo = topology_st.standalone
     default_log_level = topo.config.get_attr_val_utf8(LOG_ACCESS_LEVEL)
 
-
     log.info('Set nsslapd-plugin-logging to on')
     topo.config.set(PLUGIN_LOGGING, 'ON')
 
@@ -1462,9 +1369,47 @@ def test_missing_backend_suffix(topology_st, request):
         log.info('Restore dse.ldif')
         topology_st.standalone.stop()
         shutil.copy(dse_ldif + '.correct', dse_ldif)
+        topology_st.standalone.start()
 
     request.addfinalizer(fin)
 
+
+def test_errorlog_buffering(topology_st, request):
+    """Test log buffering works as expected when on or off
+
+    :id: 324ec5ed-c8ec-49fe-ab20-8c8cbfedca41
+    :setup: Standalone Instance
+    :steps:
+        1. Set buffering on
+        2. Reset logs and restart the server
+        3. Check for logging that should be buffered (not found)
+        4. Disable buffering
+        5. Reset logs and restart the server
+        6. Check for logging that should be found
+    :expectedresults:
+        1. Success
+        2. Success
+        3. Success
+        4. Success
+        5. Success
+        6. Success
+    """
+
+    # Configure instance
+    inst = topology_st.standalone
+    inst.config.replace('nsslapd-errorlog-logbuffering', 'on')
+    inst.deleteErrorLogs(restart=True)
+
+    time.sleep(1)
+    assert not inst.ds_error_log.match(".*slapd_daemon - slapd started.*")
+
+    inst.config.replace('nsslapd-errorlog-logbuffering', 'off')
+    inst.deleteErrorLogs(restart=True)
+
+    time.sleep(1)
+    assert inst.ds_error_log.match(".*slapd_daemon - slapd started.*")
+
+
 if __name__ == '__main__':
     # Run isolated
     # -s for DEBUG mode
