@@ -24,6 +24,8 @@ from lib389.topologies import topology_st
 from lib389.cli_ctl.health import health_check_run
 from lib389.paths import Paths
 
+from time import sleep
+
 pytestmark = pytest.mark.tier1
 
 CMD_OUTPUT = 'No issues found.'
@@ -59,6 +61,7 @@ def run_healthcheck_and_flush_log(topology, instance, searched_code, json, searc
         log.info('Use healthcheck without --json option')
         args.json = json
         health_check_run(instance, topology.logcap.log, args)
+
         assert topology.logcap.contains(searched_code)
         log.info('Healthcheck returned searched code: %s' % searched_code)
 
@@ -85,48 +88,6 @@ def setup_ldif(topology_st, request):
     request.addfinalizer(fin)
 
 
-@pytest.mark.xfail(ds_is_older("1.4.1"), reason="Not implemented")
-def test_healthcheck_logging_format_should_be_revised(topology_st):
-    """Check if HealthCheck returns DSCLE0001 code
-
-    :id: 277d7980-123b-481b-acba-d90921b9f5ac
-    :setup: Standalone instance
-    :steps:
-        1. Create DS instance
-        2. Set nsslapd-logging-hr-timestamps-enabled to 'off'
-        3. Use HealthCheck without --json option
-        4. Use HealthCheck with --json option
-        5. Set nsslapd-logging-hr-timestamps-enabled to 'on'
-        6. Use HealthCheck without --json option
-        7. Use HealthCheck with --json option
-    :expectedresults:
-        1. Success
-        2. Success
-        3. Healthcheck reports DSCLE0001 code and related details
-        4. Healthcheck reports DSCLE0001 code and related details
-        5. Success
-        6. Healthcheck reports no issue found
-        7. Healthcheck reports no issue found
-    """
-
-    RET_CODE = 'DSCLE0001'
-
-    standalone = topology_st.standalone
-
-    log.info('Set nsslapd-logging-hr-timestamps-enabled to off')
-    standalone.config.set('nsslapd-logging-hr-timestamps-enabled', 'off')
-    standalone.config.set("nsslapd-accesslog-logbuffering", "on")
-
-    run_healthcheck_and_flush_log(topology_st, standalone, json=False, searched_code=RET_CODE)
-    run_healthcheck_and_flush_log(topology_st, standalone, json=True, searched_code=RET_CODE)
-
-    log.info('Set nsslapd-logging-hr-timestamps-enabled to off')
-    standalone.config.set('nsslapd-logging-hr-timestamps-enabled', 'on')
-
-    run_healthcheck_and_flush_log(topology_st, standalone, json=False, searched_code=CMD_OUTPUT)
-    run_healthcheck_and_flush_log(topology_st, standalone, json=True, searched_code=JSON_OUTPUT)
-
-
 @pytest.mark.xfail(ds_is_older("1.4.1"), reason="Not implemented")
 def test_healthcheck_RI_plugin_is_misconfigured(topology_st):
     """Check if HealthCheck returns DSRILE0001 code
@@ -157,6 +118,8 @@ def test_healthcheck_RI_plugin_is_misconfigured(topology_st):
 
     standalone = topology_st.standalone
 
+    standalone.config.set("nsslapd-accesslog-logbuffering", "on")
+
     plugin = ReferentialIntegrityPlugin(standalone)
     plugin.disable()
     plugin.enable()
@@ -408,7 +371,6 @@ def test_healthcheck_notes_unindexed_search(topology_st, setup_ldif):
     db_cfg = DatabaseConfig(standalone)
     db_cfg.set([('nsslapd-idlistscanlimit', '100')])
 
-
     log.info('Stopping the server and running offline import...')
     standalone.stop()
     assert standalone.ldif2db(bename=DEFAULT_BENAME, suffixes=[DEFAULT_SUFFIX], encrypt=None, excludeSuffixes=None,
@@ -418,6 +380,7 @@ def test_healthcheck_notes_unindexed_search(topology_st, setup_ldif):
     log.info('Use filters to reproduce "notes=A" in access log')
     accounts = Accounts(standalone, DEFAULT_SUFFIX)
     accounts.filter('(uid=test*)')
+    sleep(1)
 
     log.info('Check that access log contains "notes=A"')
     assert standalone.ds_access_log.match(r'.*notes=A.*')
@@ -469,6 +432,7 @@ def test_healthcheck_notes_unknown_attribute(topology_st, setup_ldif):
     log.info('Use filters to reproduce "notes=F" in access log')
     accounts = Accounts(standalone, DEFAULT_SUFFIX)
     accounts.filter('(unknown=test)')
+    sleep(1)
 
     log.info('Check that access log contains "notes=F"')
     assert standalone.ds_access_log.match(r'.*notes=F.*')
@@ -477,6 +441,7 @@ def test_healthcheck_notes_unknown_attribute(topology_st, setup_ldif):
     run_healthcheck_and_flush_log(topology_st, standalone, RET_CODE, json=False)
     run_healthcheck_and_flush_log(topology_st, standalone, RET_CODE, json=True)
 
+
 def test_healthcheck_unauth_binds(topology_st):
     """Check if HealthCheck returns DSCLE0003 code when unauthorized binds are
     allowed
@@ -509,6 +474,7 @@ def test_healthcheck_unauth_binds(topology_st):
     log.info('Reset nsslapd-allow-unauthenticated-binds to off')
     inst.config.set("nsslapd-allow-unauthenticated-binds", "off")
 
+
 def test_healthcheck_accesslog_buffering(topology_st):
     """Check if HealthCheck returns DSCLE0004 code when acccess log buffering
     is disabled
@@ -541,6 +507,7 @@ def test_healthcheck_accesslog_buffering(topology_st):
     log.info('Reset nsslapd-accesslog-logbuffering to on')
     inst.config.set("nsslapd-accesslog-logbuffering", "on")
 
+
 def test_healthcheck_securitylog_buffering(topology_st):
     """Check if HealthCheck returns DSCLE0005 code when security log buffering
     is disabled
@@ -573,6 +540,7 @@ def test_healthcheck_securitylog_buffering(topology_st):
     log.info('Reset nnsslapd-securitylog-logbuffering to on')
     inst.config.set("nsslapd-securitylog-logbuffering", "on")
 
+
 def test_healthcheck_auditlog_buffering(topology_st):
     """Check if HealthCheck returns DSCLE0006 code when audit log buffering
     is disabled
