@@ -586,7 +586,7 @@ def test_import_wrong_file_path(topo):
 
 @pytest.mark.skipif(get_default_db_lib() != "mdb", reason="lmdb specific test")
 def test_crash_on_ldif2db_with_lmdb(topo, _import_clean):
-    """Make an import fail by specifying a too small db size then check that 
+    """Make an import fail by specifying a too small db size then check that
     there is no crash.
 
     :id: d42585b6-31d0-11ee-8724-482ae39447e5
@@ -601,9 +601,9 @@ def test_crash_on_ldif2db_with_lmdb(topo, _import_clean):
         1. Success
         2. Success
         3. Success (ns-slapd should not have aborted)
-        4. Import should fail 
+        4. Import should fail
         5. Success (ns-slapd should not have aborted)
-     
+
     """
     TINY_MAP_SIZE =  16 * 1024 * 1024
     inst = topo.standalone
@@ -626,6 +626,69 @@ def test_crash_on_ldif2db_with_lmdb(topo, _import_clean):
         _import_offline(topo, 500_000)
     __check_for_core(now)
 
+def test_online_import_under_load(topo):
+    """Perform an online import while the server is under load
+
+    :id: 56f7ac6f-4285-4bc4-8822-5ae9b502eee3
+    :setup: Standalone Instance
+    :steps:
+        1. Create and import LDIF for ldclt load
+        2. Start ldclt
+        3. Start online import
+        4. Wait a bit and kill the ldclt load
+        5. Check import task successfully completed
+
+    :expectedresults:
+        1. Success
+        2. Success
+        3. Success
+        4. Success
+        5. Success
+    """
+    inst = topo.standalone
+
+    # Create and import ldif to use with ldclt
+    ldif_dir = inst.get_ldif_dir()
+    import_ldif = ldif_dir + '/stress_import.ldif'
+    dbgen_users(inst, 1000, import_ldif, generic=True, suffix=DEFAULT_SUFFIX)
+    import_task = ImportTask(topo.standalone)
+    import_task.import_suffix_from_ldif(ldiffile=import_ldif,
+                                        suffix=DEFAULT_SUFFIX)
+    import_task.wait()
+    assert import_task.get_exit_code() == 0
+
+    # Start ldclt load
+    ldclt_cmd = [
+        '%s/ldclt' % inst.get_bin_dir(),
+        '-h', inst.host, '-p', str(inst.port),
+        '-f', '(uid=userXXXX)', '-e', 'esearch,random',
+        '-r1', '-R999', '-Q'
+    ]
+    p = subprocess.Popen(ldclt_cmd, start_new_session=True,
+                         stdout=subprocess.PIPE)
+    time.sleep(1)
+
+    # Start online import
+    import_task = ImportTask(topo.standalone)
+    import_task.import_suffix_from_ldif(ldiffile=import_ldif,
+                                        suffix=DEFAULT_SUFFIX)
+
+    # Wait a bit till the task is created and available for searching
+    for x in range(10):
+        if import_task.present('nstaskcreated'):
+            break
+        time.sleep(0.5)
+    assert import_task.present('nstaskcreated')
+
+    # Stop the load
+    time.sleep(3)
+    cmd = ['kill', '-9', str(p.pid)]
+    subprocess.Popen(cmd, stdout=subprocess.PIPE)
+
+    # import should finish
+    import_task.wait()
+    assert import_task.get_exit_code() == 0
+
 
 if __name__ == '__main__':
     # Run isolated
