@@ -261,8 +261,6 @@ def test_del_suffix_backend(topo):
     assert not topo.standalone.detectDisorderlyShutdown()
 
 
-@pytest.mark.bz1406101
-@pytest.mark.ds49071
 def test_import_duplicate_dn(topo):
     """Import ldif with duplicate DNs, should not log error "unable to flush"
 
@@ -321,7 +319,6 @@ ou: myDups00001
     log.info('Error log should have "Duplicated DN detected" message')
     assert standalone.ds_error_log.match('.*Duplicated DN detected.*')
 
-@pytest.mark.bz1749595
 @pytest.mark.tier2
 @pytest.mark.xfail(not _check_disk_space(), reason="not enough disk space for lmdb map")
 @pytest.mark.xfail(ds_is_older("1.3.10.1"), reason="bz1749595 not fixed on versions older than 1.3.10.1")
@@ -437,7 +434,58 @@ def test_large_ldif2db_ancestorid_index_creation(topo, _set_mdb_map_size):
         # The time for the ancestorid index creation should be less than 10s for an offline import of an ldif file with 100000 entries / 5 entries per node
         # Should be adjusted if these numbers are modified in the test
         assert etime <= 10
-    
+
+
+def create_backend_and_import(instance, ldif_file, suffix, backend):
+    log.info(f'Add suffix:{suffix} and backend: {backend}...')
+    backends = Backends(instance)
+    backends.create(properties={'nsslapd-suffix': suffix, 'name': backend})
+    props = {'numUsers': 10000, 'nodeLimit': 5, 'suffix': suffix}
+
+    log.info(f'Create a large nested ldif file using dbgen : {ldif_file}')
+    dbgen_nested_ldif(instance, ldif_file, props)
+
+    log.info('Stop the server and run offline import...')
+    instance.stop()
+    log.info('Measure the import time for the ldif file...')
+    start = time.time()
+    assert instance.ldif2db(backend, None, None, None, ldif_file)
+    end = time.time()
+    instance.start()
+    return end - start
+
+
+@pytest.mark.skipif(get_default_db_lib() == "mdb", reason="Not cache size over mdb")
+def test_ldif2db_after_backend_create(topo):
+    """Test that ldif2db after backend creation is not slow first time
+
+    :id: c1ab1df7-c70a-46be-bbca-8d65c6ebaa14
+    :setup: Standalone Instance
+    :steps:
+        1. Create backend and suffix
+        2. Generate large LDIF file
+        3. Stop server and run offline import
+        4. Measure import time
+        5. Restart server and repeat steps 1-4 with new backend and suffix
+    :expectedresults:
+        1. Operation successful
+        2. Operation successful
+        3. Operation successful
+        4. Import times should be approximately the same
+        5. Operation successful
+    """
+
+    instance = topo.standalone
+    ldif_dir = instance.get_ldif_dir()
+    ldif_file_1 = os.path.join(ldif_dir, 'large_nested_1.ldif')
+    ldif_file_2 = os.path.join(ldif_dir, 'large_nested_2.ldif')
+
+    import_time_1 = create_backend_and_import(instance, ldif_file_1, 'o=test_1', 'test_1')
+    import_time_2 = create_backend_and_import(instance, ldif_file_2, 'o=test_2', 'test_2')
+
+    log.info('Import times should be approximately the same')
+    assert abs(import_time_1 - import_time_2) < 5
+
 
 if __name__ == '__main__':
     # Run isolated
