@@ -10,7 +10,9 @@ import logging
 import pytest
 import os
 import time
+import signal
 import ldap
+from datetime import datetime
 from random import sample
 from lib389.utils import ds_is_older, ensure_list_bytes, ensure_bytes, ensure_str
 from lib389.topologies import topology_m1h1c1 as topo, topology_st, topology_m2 as topo_m2
@@ -22,6 +24,10 @@ from lib389.idm.group import Groups, Group
 from lib389.replica import ReplicationManager
 from lib389.tasks import *
 from lib389.idm.nscontainer import nsContainers
+from lib389.idm.domain import Domain
+from lib389.dirsrv_log import DirsrvErrorLog
+from lib389.dseldif import DSEldif
+from contextlib import suppress
 
 
 # Skip on older versions
@@ -301,6 +307,10 @@ def test_scheme_violation_errors_logged(topo_m2):
     memberof = MemberOfPlugin(inst)
     memberof.enable()
     memberof.set_autoaddoc('nsMemberOf')
+    if (memberof.get_memberofdeferredupdate() and memberof.get_memberofdeferredupdate().lower() == "on"):
+        delay = 3
+    else:
+        delay = 0
     inst.restart()
 
     users = UserAccounts(inst, SUFFIX)
@@ -314,6 +324,7 @@ def test_scheme_violation_errors_logged(topo_m2):
 
     testgroup.add('member', testuser.dn)
 
+    time.sleep(delay)
     user_memberof_attr = testuser.get_attr_val_utf8('memberof')
     assert user_memberof_attr
     log.info('memberOf attr value - {}'.format(user_memberof_attr))
@@ -352,11 +363,19 @@ def test_memberof_with_changelog_reset(topo_m2):
 
     log.info("Configure memberof on M1 and M2")
     memberof = MemberOfPlugin(m1)
+    if (memberof.get_memberofdeferredupdate() and memberof.get_memberofdeferredupdate().lower() == "on"):
+        # too difficult to make a large update work at shutdown
+        # need a dedicated test
+        return
     memberof.enable()
     memberof.set_autoaddoc('nsMemberOf')
     m1.restart()
 
     memberof = MemberOfPlugin(m2)
+    if (memberof.get_memberofdeferredupdate() and memberof.get_memberofdeferredupdate().lower() == "on"):
+        # too difficult to make a large update work at shutdown
+        # need a dedicated test
+        return
     memberof.enable()
     memberof.set_autoaddoc('nsMemberOf')
     m2.restart()
@@ -480,6 +499,10 @@ def test_memberof_group(topology_st):
     memberof = MemberOfPlugin(inst)
     memberof.enable()
     memberof.replace('memberOfEntryScope', SUBTREE_1)
+    if (memberof.get_memberofdeferredupdate() and memberof.get_memberofdeferredupdate().lower() == "on"):
+        delay = 3
+    else:
+        delay = 0
     inst.restart()
 
     add_container(inst, SUFFIX, 'sub1')
@@ -489,6 +512,7 @@ def test_memberof_group(topology_st):
     add_group(inst, 'g1', SUBTREE_1)
     add_group(inst, 'g2', SUBTREE_2)
 
+    time.sleep(delay)
     # _check_memberof
     dn1 = '%s,%s' % ('uid=test_m1', SUBTREE_1)
     dn2 = '%s,%s' % ('uid=test_m2', SUBTREE_1)
@@ -501,6 +525,7 @@ def test_memberof_group(topology_st):
 
     rename_entry(inst, 'cn=g2', SUBTREE_2, SUBTREE_1)
 
+    time.sleep(delay)
     g2n = '%s,%s' % ('cn=g2-new', SUBTREE_1)
     _find_memberof_ext(inst, dn1, g1, True)
     _find_memberof_ext(inst, dn2, g1, True)
@@ -562,6 +587,11 @@ def test_entrycache_on_modrdn_failure(topology_st):
 
     # only scopes peoplebase
     _config_memberof_entrycache_on_modrdn_failure(topology_st.standalone)
+    memberof = MemberOfPlugin(topology_st.standalone)
+    if (memberof.get_memberofdeferredupdate() and memberof.get_memberofdeferredupdate().lower() == "on"):
+        delay = 3
+    else:
+        delay = 0
     topology_st.standalone.restart(timeout=10)
 
     # create 10 users
@@ -583,6 +613,7 @@ def test_entrycache_on_modrdn_failure(topology_st):
                                    ],
                              'description': 'mygroup'})))
 
+    time.sleep(delay)
     # Check the those entries have memberof with group0
     for i in range(2):
         user_dn = 'cn=user%d,%s' % (i, peoplebase)
@@ -605,6 +636,7 @@ def test_entrycache_on_modrdn_failure(topology_st):
                                    ],
                              'description': 'mygroup'})))
 
+    time.sleep(delay)
     # Check the those entries have not memberof with group1
     for i in range(2):
         user_dn = 'cn=user%d,%s' % (i, peoplebase)
@@ -621,6 +653,8 @@ def test_entrycache_on_modrdn_failure(topology_st):
     # move group1 into the scope and check user0 and user1 are memberof group1
     topology_st.standalone.rename_s(group1_dn, 'cn=group_in1', newsuperior=peoplebase, delold=0)
     new_group1_dn = 'cn=group_in1,%s' % peoplebase
+
+    time.sleep(delay)
     for i in range(2):
         user_dn = 'cn=user%d,%s' % (i, peoplebase)
         ent = topology_st.standalone.getEntry(user_dn, ldap.SCOPE_BASE, "(objectclass=*)", ['memberof'])
@@ -642,7 +676,7 @@ def test_entrycache_on_modrdn_failure(topology_st):
                                    'cn=user3,%s' % peoplebase,
                                    ],
                              'description': entry_description})))
-
+    time.sleep(delay)
     # Check the those entries have not memberof with group2
     for i in (2, 3):
         user_dn = 'cn=user%d,%s' % (i, peoplebase)
@@ -653,31 +687,36 @@ def test_entrycache_on_modrdn_failure(topology_st):
     _disable_auto_oc_memberof(topology_st.standalone)
     topology_st.standalone.restart(timeout=10)
 
-    # move group2 into the scope and check it fails
-    try:
+    if (memberof.get_memberofdeferredupdate() and memberof.get_memberofdeferredupdate().lower() == "on"):
+        # move group2 into the scope and check it succeeds
         topology_st.standalone.rename_s(group2_dn, 'cn=group_in2', newsuperior=peoplebase, delold=0)
-        topology_st.standalone.log.info("This is unexpected, modrdn should fail as the member entry have not the appropriate objectclass")
-        assert False
-    except ldap.OBJECT_CLASS_VIOLATION:
-        pass
+        topology_st.standalone.log.info("This is expected, modrdn does not fail only updates of members will fail")
+    else:
+        # move group2 into the scope and check it fails
+        try:
+            topology_st.standalone.rename_s(group2_dn, 'cn=group_in2', newsuperior=peoplebase, delold=0)
+            topology_st.standalone.log.info("This is unexpected, modrdn should fail as the member entry have not the appropriate objectclass")
+            assert False
+        except ldap.OBJECT_CLASS_VIOLATION:
+            pass
 
-    # retrieve the entry having the specific description value
-    # check that the entry DN is the original group2 DN
-    ents = topology_st.standalone.search_s(DEFAULT_SUFFIX, ldap.SCOPE_SUBTREE, '(cn=gr*)')
-    found = False
-    for ent in ents:
-        topology_st.standalone.log.info("retrieve: %s with desc=%s" % (ent.dn, ent.getValue('description')))
-        if ent.getValue('description') == entry_description.encode():
-            found = True
-            assert ent.dn == group2_dn
-    assert found
+        # retrieve the entry having the specific description value
+        # check that the entry DN is the original group2 DN
+        ents = topology_st.standalone.search_s(DEFAULT_SUFFIX, ldap.SCOPE_SUBTREE, '(cn=gr*)')
+        found = False
+        for ent in ents:
+            topology_st.standalone.log.info("retrieve: %s with desc=%s" % (ent.dn, ent.getValue('description')))
+            if ent.getValue('description') == entry_description.encode():
+                found = True
+                assert ent.dn == group2_dn
+        assert found
 
 
 def _config_memberof_silent_memberof_failure(server):
     _config_memberof_entrycache_on_modrdn_failure(server)
 
 
-def test_silent_memberof_failure(topology_st):
+def test_silent_memberof_failure(topology_st, request):
     """This test checks that if during a MODRDN, the memberof plugin fails
     then MODRDN also fails
 
@@ -716,6 +755,11 @@ def test_silent_memberof_failure(topology_st):
     """
     # only scopes peoplebase
     _config_memberof_silent_memberof_failure(topology_st.standalone)
+    memberof = MemberOfPlugin(topology_st.standalone)
+    if (memberof.get_memberofdeferredupdate() and memberof.get_memberofdeferredupdate().lower() == "on"):
+        delay = 3
+    else:
+        delay = 0
     topology_st.standalone.restart(timeout=10)
 
     # first do some cleanup
@@ -723,10 +767,21 @@ def test_silent_memberof_failure(topology_st):
     for i in range(10):
         cn = 'user%d' % i
         dn = 'cn=%s,%s' % (cn, peoplebase)
-        topology_st.standalone.delete_s(dn)
-    topology_st.standalone.delete_s('cn=group_in0,%s' % peoplebase)
-    topology_st.standalone.delete_s('cn=group_in1,%s' % peoplebase)
-    topology_st.standalone.delete_s('cn=group_out2,%s' % SUFFIX)
+        try:
+            topology_st.standalone.delete_s(dn)
+        except ldap.NO_SUCH_OBJECT:
+            pass
+
+    for i in range(3):
+        try:
+            topology_st.standalone.delete_s('cn=group_in%d,%s' % (i, peoplebase))
+        except ldap.NO_SUCH_OBJECT:
+                pass
+
+    try:
+        topology_st.standalone.delete_s('cn=group_out2,%s' % SUFFIX)
+    except ldap.NO_SUCH_OBJECT:
+            pass
 
     # create 10 users
     for i in range(10):
@@ -746,6 +801,7 @@ def test_silent_memberof_failure(topology_st):
                                    ],
                              'description': 'mygroup'})))
 
+    time.sleep(delay)
     # Check the those entries have memberof with group0
     for i in range(2):
         user_dn = 'cn=user%d,%s' % (i, peoplebase)
@@ -768,6 +824,7 @@ def test_silent_memberof_failure(topology_st):
                                    ],
                              'description': 'mygroup'})))
 
+    time.sleep(delay)
     # Check the those entries have not memberof with group1
     for i in range(2):
         user_dn = 'cn=user%d,%s' % (i, peoplebase)
@@ -784,6 +841,7 @@ def test_silent_memberof_failure(topology_st):
     # move group1 into the scope and check user0 and user1 are memberof group1
     topology_st.standalone.rename_s(group1_dn, 'cn=group_in1', newsuperior=peoplebase, delold=0)
     new_group1_dn = 'cn=group_in1,%s' % peoplebase
+    time.sleep(delay)
     for i in range(2):
         user_dn = 'cn=user%d,%s' % (i, peoplebase)
         ent = topology_st.standalone.getEntry(user_dn, ldap.SCOPE_BASE, "(objectclass=*)", ['memberof'])
@@ -805,6 +863,7 @@ def test_silent_memberof_failure(topology_st):
                                    ],
                              'description': 'mygroup'})))
 
+    time.sleep(delay)
     # Check the those entries have not memberof with group2
     for i in (2, 3):
         user_dn = 'cn=user%d,%s' % (i, peoplebase)
@@ -815,14 +874,20 @@ def test_silent_memberof_failure(topology_st):
     _disable_auto_oc_memberof(topology_st.standalone)
     topology_st.standalone.restart(timeout=10)
 
-    # move group2 into the scope and check it fails
-    try:
+    if (memberof.get_memberofdeferredupdate() and memberof.get_memberofdeferredupdate().lower() == "on"):
+        # move group2 into the scope and check it succeeds
         topology_st.standalone.rename_s(group2_dn, 'cn=group_in2', newsuperior=peoplebase, delold=0)
-        topology_st.standalone.log.info("This is unexpected, modrdn should fail as the member entry have not the appropriate objectclass")
-        assert False
-    except ldap.OBJECT_CLASS_VIOLATION:
-        pass
+        topology_st.standalone.log.info("This is expected, modrdn does not fail only updates of members will fail")
+    else:
+        # move group2 into the scope and check it fails
+        try:
+            topology_st.standalone.rename_s(group2_dn, 'cn=group_in2', newsuperior=peoplebase, delold=0)
+            topology_st.standalone.log.info("This is unexpected, modrdn should fail as the member entry have not the appropriate objectclass")
+            assert False
+        except ldap.OBJECT_CLASS_VIOLATION:
+            pass
 
+    time.sleep(delay)
     # Check the those entries have not memberof
     for i in (2, 3):
         user_dn = 'cn=user%d,%s' % (i, peoplebase)
@@ -830,22 +895,32 @@ def test_silent_memberof_failure(topology_st):
         topology_st.standalone.log.info("Should assert %s has memberof is %s" % (user_dn, ent.hasAttr('memberof')))
         assert not ent.hasAttr('memberof')
 
-    # Create a group3 in the scope
-    group3_dn = 'cn=group3_in,%s' % peoplebase
-    try:
+    if (memberof.get_memberofdeferredupdate() and memberof.get_memberofdeferredupdate().lower() == "on"):
+        # Create a group3 in the scope
+        group3_dn = 'cn=group3_in,%s' % peoplebase
         topology_st.standalone.add_s(Entry((group3_dn, {'objectclass': ['top', 'groupofnames'],
-                             'member': [
-                                   'cn=user4,%s' % peoplebase,
-                                   'cn=user5,%s' % peoplebase,
-                                   ],
-                             'description': 'mygroup'})))
-        topology_st.standalone.log.info("This is unexpected, ADD should fail as the member entry have not the appropriate objectclass")
-        assert False
-    except ldap.OBJECT_CLASS_VIOLATION:
-        pass
-    except ldap.OPERATIONS_ERROR:
-        pass
+                                                        'member': ['cn=user4,%s' % peoplebase,
+                                                                   'cn=user5,%s' % peoplebase,],
+                                                        'description': 'mygroup'})))
+        topology_st.standalone.log.info("This is expected, add does not fail only updates of members will fail")
+    else:
+        # Create a group3 in the scope
+        group3_dn = 'cn=group3_in,%s' % peoplebase
+        try:
+            topology_st.standalone.add_s(Entry((group3_dn, {'objectclass': ['top', 'groupofnames'],
+                                 'member': [
+                                       'cn=user4,%s' % peoplebase,
+                                       'cn=user5,%s' % peoplebase,
+                                       ],
+                                 'description': 'mygroup'})))
+            topology_st.standalone.log.info("This is unexpected, ADD should fail as the member entry have not the appropriate objectclass")
+            assert False
+        except ldap.OBJECT_CLASS_VIOLATION:
+            pass
+        except ldap.OPERATIONS_ERROR:
+            pass
 
+    time.sleep(delay)
     # Check the those entries do not have memberof
     for i in (4, 5):
         user_dn = 'cn=user%d,%s' % (i, peoplebase)
@@ -853,6 +928,219 @@ def test_silent_memberof_failure(topology_st):
         topology_st.standalone.log.info("Should assert %s has memberof is %s" % (user_dn, ent.hasAttr('memberof')))
         assert not ent.hasAttr('memberof')
 
+    def fin():
+        # Cleanup the user[0-9]* entries
+        peoplebase = 'ou=people,%s' % SUFFIX
+        for i in range(10):
+            cn = 'user%d' % i
+            dn = 'cn=%s,%s' % (cn, peoplebase)
+            try:
+                topology_st.standalone.delete_s(dn)
+            except ldap.NO_SUCH_OBJECT:
+                pass
+
+        # Cleanup the user_ entries
+        ents = topology_st.standalone.search_s(DEFAULT_SUFFIX, ldap.SCOPE_SUBTREE, '(uid=user_*)')
+        for ent in ents:
+            try:
+                topology_st.standalone.delete_s(ent.dn)
+            except ldap.NO_SUCH_OBJECT:
+                pass
+
+        # Cleanup the test_ entries
+        ents = topology_st.standalone.search_s(DEFAULT_SUFFIX, ldap.SCOPE_SUBTREE, '(uid=test_*)')
+        for ent in ents:
+            try:
+                topology_st.standalone.delete_s(ent.dn)
+            except ldap.NO_SUCH_OBJECT:
+                pass
+
+        for i in range(3):
+            try:
+                topology_st.standalone.delete_s('cn=group_in%d,%s' % (i, peoplebase))
+            except ldap.NO_SUCH_OBJECT:
+                    pass
+
+        try:
+            topology_st.standalone.delete_s('cn=group_out2,%s' % SUFFIX)
+        except ldap.NO_SUCH_OBJECT:
+                pass
+
+    request.addfinalizer(fin)
+
+
+def check_memberof_consistency(inst, group):
+    """This function checks that there is same number of:
+         - entries having 'memberOf' attribute
+         - members in the group
+    """
+    suffix = Domain(inst, SUFFIX)
+    group_members = len(group.get_attr_vals('member'))
+    users_memberof = len(suffix.search(filter='(memberof=*)'))
+    assert group_members == users_memberof
+
+
+def count_global_fixup_message(errlog):
+    """This function returns a tuple (nbstarted, nsfinished) telling how many messages
+       (about Memberof pluging global fixed task) are found in the error log.
+    """
+    nbstarted = 0
+    nbfinished = 0
+    for line in errlog.match('.*Memberof plugin [a-z]* the global fixup task.*'):
+        if 'started' in line:
+            nbstarted += 1
+        elif 'finished' in line:
+            nbfinished += 1
+    log.info(f'Global fixup start was started {nbstarted} times.')
+    log.info(f'Global fixup start was finished {nbfinished} times.')
+    return (nbstarted, nbfinished)
+
+def _kill_instance(inst, sig=signal.SIGTERM, delay=None):
+    pid = None
+    try:
+        with open(inst.pid_file(), 'rb') as f:
+            for line in f.readlines():
+                try:
+                    pid = int(line.strip())
+                    break
+                except ValueError:
+                    continue
+    except IOError:
+        pass
+
+    if not pid or pid == 0:
+        pytest.raises(AssertionError)
+
+    if delay:
+        time.sleep(delay)
+    os.kill(pid, signal.SIGKILL)
+
+def test_shutdown_on_deferred_memberof(topology_st):
+    """This test checks that shutdown is handled properly if memberof updayes are deferred.
+
+    :id: c5629cae-15a0-11ee-8807-482ae39447e5
+    :setup: Standalone Instance
+    :steps:
+        1. Enable memberof plugin to scope SUFFIX
+        2. create 1000 users
+        3. Create a large groups with 500 members
+        4. Restart the instance (using the default 2 minutes timeout)
+        5. Check that users memberof and group members are in sync.
+        6. Modify the group to have 10 members.
+        7. Restart the instance with short timeout
+        8. Check that fixup task is in progress
+        9. Wait until fixup task is completed
+        10. Check that users memberof and group members are in sync.
+    :expectedresults:
+        1. should succeed
+        2. should succeed
+        3. should succeed
+        4. should succeed
+        5. should succeed
+        6. should succeed
+        7. should succeed
+        8. should succeed
+        9. should succeed
+        10. should succeed
+    """
+
+    inst = topology_st.standalone
+    inst.config.loglevel(vals=(ErrorLog.DEFAULT,ErrorLog.PLUGIN))
+    errlog = DirsrvErrorLog(inst)
+    test_timeout = 900
+
+    # Step 1. Enable memberof plugin to scope SUFFIX
+    memberof = MemberOfPlugin(inst)
+    delay=0
+    memberof.set_memberofdeferredupdate("on")
+    if (memberof.get_memberofdeferredupdate() and memberof.get_memberofdeferredupdate().lower() != "on"):
+        pytest.skip("Memberof deferred update not enabled or not supported.");
+    else:
+        delay=10
+    memberof.set_attr('memberOf')
+    memberof.replace_groupattr('member')
+    memberof.remove_all_entryscope()
+    memberof.remove_all_excludescope()
+    memberof.remove_configarea()
+    memberof.remove_autoaddoc()
+    memberof.enable()
+    inst.restart()
+
+    #Creates users and groups
+    users_dn = []
+
+    # Step 2. create 1000 users
+    for i in range(1000):
+        CN = '%s%d' % (USER_CN, i)
+        users = UserAccounts(inst, SUFFIX)
+        user_props = TEST_USER_PROPERTIES.copy()
+        user_props.update({'uid': CN, 'cn': CN, 'sn': '_%s' % CN})
+        testuser = users.create(properties=user_props)
+        users_dn.append(testuser.dn)
+
+    # Step 3. Create a large groups with 250 members
+    groups = Groups(inst, SUFFIX)
+    testgroup = groups.create(properties={'cn': 'group500', 'member': users_dn[0:249]})
+
+    # Step 4. Restart the instance (using the default 2 minutes timeout)
+    time.sleep(10)
+    log.info(f'Stopping instance at {datetime.now().strftime("%Y-%m-%d %H:%M:%S")}')
+    inst.stop()
+    log.info(f'Instance stopped at {datetime.now().strftime("%Y-%m-%d %H:%M:%S")}')
+    inst.start()
+
+    time.sleep(delay)
+    # Step 5. Check that users memberof and group members are in sync.
+    check_memberof_consistency(inst, testgroup)
+
+    # Step 6. Modify the group to get another big group.
+    testgroup.replace('member', users_dn[500:999])
+
+    # Step 7. Restart the instance with short timeout
+    pattern = 'deferred_thread_func - thread has stopped'
+    original_nbcleanstop = len(errlog.match(pattern))
+    log.info(f'Stopping instance at {datetime.now().strftime("%Y-%m-%d %H:%M:%S")}')
+    _kill_instance(inst, sig=signal.SIGKILL, delay=5)
+    log.info(f'Instance stopped at {datetime.now().strftime("%Y-%m-%d %H:%M:%S")}')
+    # Double check that timeout occured during shutdown
+    #  (i.e: no new 'deferred_thread_func - thread has stopped' message)
+    nbcleanstop = len(errlog.match(pattern))
+    assert nbcleanstop == original_nbcleanstop
+
+    original_nbfixupmsg = count_global_fixup_message(errlog)
+    log.info(f'Instance restarted after timeout at {datetime.now().strftime("%Y-%m-%d %H:%M:%S")}')
+    inst.restart()
+    assert inst.status()
+    log.info(f'Restart completed at {datetime.now().strftime("%Y-%m-%d %H:%M:%S")}')
+
+    # Check that memberofneedfixup is present
+    dse = DSEldif(inst)
+    assert dse.get(memberof.dn, 'memberofneedfixup', single=True)
+
+    # Step 8. Check that fixup task is in progress
+    # Note we have to wait as there may be some delay
+    elapsed_time = 0
+    nbfixupmsg = count_global_fixup_message(errlog)
+    while nbfixupmsg[0] == original_nbfixupmsg[0]:
+        assert elapsed_time <= test_timeout
+        assert inst.status()
+        time.sleep(5)
+        elapsed_time += 5
+        nbfixupmsg = count_global_fixup_message(errlog)
+
+    # Step 9. Wait until fixup task is completed
+    while nbfixupmsg[1] == original_nbfixupmsg[1]:
+        assert elapsed_time <= test_timeout
+        assert inst.status()
+        time.sleep(10)
+        elapsed_time += 10
+        nbfixupmsg = count_global_fixup_message(errlog)
+
+    # Step 10. Check that users memberof and group members are in sync.
+    time.sleep(delay)
+    check_memberof_consistency(inst, testgroup)
+
+
 if __name__ == '__main__':
     # Run isolated
     # -s for DEBUG mode
