@@ -889,6 +889,10 @@ def test_memberof(topo, args=None):
 
     # stop the plugin, and start it
     plugin = MemberOfPlugin(inst)
+    if (plugin.get_memberofdeferredupdate() and plugin.get_memberofdeferredupdate().lower() == "on"):
+        delay = 5
+    else:
+        delay = 0
     plugin.disable()
     plugin.enable()
 
@@ -923,6 +927,7 @@ def test_memberof(topo, args=None):
                                        'memberOfGroupAttr': 'member',
                                        'memberOfAttr': MEMBER_ATTR})
 
+    time.sleep(delay)
     # Check if the user now has a "memberOf" attribute
     entries = inst.search_s(user1.dn, ldap.SCOPE_BASE, '({}=*)'.format(MEMBER_ATTR))
     assert entries
@@ -930,6 +935,7 @@ def test_memberof(topo, args=None):
     # Remove "member" should remove "memberOf" from the entry
     group.remove_all('member')
 
+    time.sleep(delay)
     # Check that "memberOf" was removed
     entries = inst.search_s(user1.dn, ldap.SCOPE_BASE, '({}=*)'.format(MEMBER_ATTR))
     assert not entries
@@ -944,6 +950,7 @@ def test_memberof(topo, args=None):
     ############################################################################
     group.replace('uniquemember', user1.dn)
 
+    time.sleep(delay)
     # Check if the user now has a "memberOf" attribute
     entries = inst.search_s(user1.dn, ldap.SCOPE_BASE, '({}=*)'.format(MEMBER_ATTR))
     assert entries
@@ -951,6 +958,7 @@ def test_memberof(topo, args=None):
     # Remove "uniquemember" should remove "memberOf" from the entry
     group.remove_all('uniquemember')
 
+    time.sleep(delay)
     # Check that "memberOf" was removed
     entries = inst.search_s(user1.dn, ldap.SCOPE_BASE, '({}=*)'.format(MEMBER_ATTR))
     assert not entries
@@ -972,6 +980,7 @@ def test_memberof(topo, args=None):
                                       'member': user1.dn})
     group.add('objectclass', 'groupOfUniqueNames')
 
+    time.sleep(delay)
     # Test the shared config
     # Check if the user now has a "memberOf" attribute
     entries = inst.search_s(user1.dn, ldap.SCOPE_BASE, '({}=*)'.format(MEMBER_ATTR))
@@ -979,6 +988,7 @@ def test_memberof(topo, args=None):
 
     group.remove_all('member')
 
+    time.sleep(delay)
     # Check that "memberOf" was removed
     entries = inst.search_s(user1.dn, ldap.SCOPE_BASE, '({}=*)'.format(MEMBER_ATTR))
     assert not entries
@@ -990,6 +1000,7 @@ def test_memberof(topo, args=None):
 
     group.replace('uniquemember', user1.dn)
 
+    time.sleep(delay)
     # Check if the user now has a "memberOf" attribute
     entries = inst.search_s(user1.dn, ldap.SCOPE_BASE, '({}=*)'.format(MEMBER_ATTR))
     assert entries
@@ -997,6 +1008,7 @@ def test_memberof(topo, args=None):
     # Remove "uniquemember" should remove "memberOf" from the entry
     group.remove_all('uniquemember')
 
+    time.sleep(delay)
     # Check that "memberOf" was removed
     entries = inst.search_s(user1.dn, ldap.SCOPE_BASE, '({}=*)'.format(MEMBER_ATTR))
     assert not entries
@@ -1009,9 +1021,11 @@ def test_memberof(topo, args=None):
 
     # Remove shared config from plugin
     plugin.remove_configarea()
+    inst.restart()
 
     group.replace('member', user1.dn)
 
+    time.sleep(delay)
     # Check if the user now has a "memberOf" attribute
     entries = inst.search_s(user1.dn, ldap.SCOPE_BASE, '({}=*)'.format(MEMBER_ATTR))
     assert entries
@@ -1019,6 +1033,7 @@ def test_memberof(topo, args=None):
     # Remove "uniquemember" should remove "memberOf" from the entry
     group.remove_all('member')
 
+    time.sleep(delay)
     # Check that "memberOf" was removed
     entries = inst.search_s(user1.dn, ldap.SCOPE_BASE, '({}=*)'.format(MEMBER_ATTR))
     assert not entries
@@ -1038,6 +1053,7 @@ def test_memberof(topo, args=None):
     # Add uniquemember, should not update USER1
     group.replace('uniquemember', user1.dn)
 
+    time.sleep(delay)
     # Check for "memberOf"
     entries = inst.search_s(user1.dn, ldap.SCOPE_BASE, '({}=*)'.format(MEMBER_ATTR))
     assert not entries
