@@ -10,7 +10,7 @@ import pytest
 import subprocess
 from lib389.tasks import *
 from lib389.utils import *
-from lib389.topologies import topology_st
+from lib389.topologies import topology_st, topology_m1c1
 from lib389.idm.user import (UserAccount, UserAccounts)
 from lib389.plugins import (AccountPolicyPlugin, AccountPolicyConfig, AccountPolicyConfigs)
 from lib389.cos import (CosTemplate, CosPointerDefinition)
@@ -112,6 +112,40 @@ def accpol_local(topology_st, accpol_global, request):
     request.addfinalizer(fin)
 
 
+@pytest.fixture(scope="module")
+def setup_account_policy_plugin(topology_st):
+    inst = topology_st[0]
+
+    # Enable plugin and restart
+    plugin = AccountPolicyPlugin(inst)
+    plugin.disable()
+    plugin.enable()
+    inst.restart()
+
+    # Add config entry, set alwaysrecordlogin to yes (lastLoginHistorySize defaults to 5)
+    ap_configs = AccountPolicyConfigs(inst)
+    try:
+        ap_config = ap_configs.create(properties={'cn': 'config', 'alwaysrecordlogin': 'yes', })
+    except ldap.ALREADY_EXISTS:
+        ap_config = ap_configs.get('config')
+        ap_config.replace('alwaysrecordlogin', 'yes')
+
+    return ap_config
+
+
+@pytest.fixture(scope="module")
+def setup_test_user(topology_st, setup_account_policy_plugin):
+    inst = topology_st[0]
+    USER_PW = 'password'
+
+    # Add a test user entry
+    users = UserAccounts(inst, DEFAULT_SUFFIX)
+    user = users.create_test_user(uid=1000, gid=2000)
+    user.replace('userPassword', USER_PW)
+
+    return user
+
+
 def pwacc_lock(topology_st, suffix, subtree, userid, nousrs):
     """Lockout user account by attempting invalid password binds"""
 
@@ -424,7 +458,7 @@ def test_glremv_lastlogin(topology_st, accpol_global):
     del_users(topology_st, suffix, subtree, userid, nousrs)
 
 
-def test_lastlogin_history(topology_st, request):
+def test_login_history_valid_values(topology_st, setup_test_user, setup_account_policy_plugin):
     """Verify a user account with attr alwaysrecordlogin=yes returns no more
     than the last login history size and that the timestamps are in chronological order.
 
@@ -432,19 +466,16 @@ def test_lastlogin_history(topology_st, request):
     :setup: Standalone instance, Global account policy plugin configuration,
             set alwaysrecordlogin to yes.
     :steps:
-        1. Enable account policy plugin and restart instance.
-        2. Add a config entry, setting alwaysrecordlogin to yes (lastLoginHistorySize defaults to 5)
-        3. Create a test user and reset its password.
-        4. Bind as test user more times than lastLoginHistorySize.
-        5. Search on the test user DN for lastLoginTimeHistory attribute.
-        6. Verify returned entry contains only LOGIN_HIST_SIZE_FIVE timestamps in chronological order.
-        7. Modify plugin config entry, setting lastLoginHistorySize to LOGIN_HIST_SIZE_TWO
-        8. Bind as test user more times than lastLoginHistorySize.
+        1. Bind as test user more times than lastLoginHistorySize.
+        2. Search on the test user DN for lastLoginTimeHistory attribute.
+        3. Verify returned entry contains only LOGIN_HIST_SIZE_FIVE timestamps in chronological order.
+        4. Modify plugin config entry, setting lastLoginHistorySize to LOGIN_HIST_SIZE_TWO
+        5. Bind as test user more times than lastLoginHistorySize.
+        6. Search on the test user DN for lastLoginTimeHistory attribute.
+        7. Verify returned entry contains only LOGIN_HIST_SIZE_TWO timestamps in chronological order.
+        8. Modify plugin config entry, setting lastLoginHistorySize to LOGIN_HIST_SIZE_FIVE
         9. Search on the test user DN for lastLoginTimeHistory attribute.
-        10. Verify returned entry contains only LOGIN_HIST_SIZE_TWO timestamps in chronological order.
-        11. Modify plugin config entry, setting lastLoginHistorySize to LOGIN_HIST_SIZE_FIVE
-        12. Search on the test user DN for lastLoginTimeHistory attribute.
-        13. Verify returned entry contains only LOGIN_HIST_SIZE_FIVE timestamps in chronological order.
+        10. Verify returned entry contains only LOGIN_HIST_SIZE_FIVE timestamps in chronological order.
     :expectedresults:
         1. Success
         2. Success
@@ -456,9 +487,6 @@ def test_lastlogin_history(topology_st, request):
         8. Success
         9. Success
         10. Success
-        11. Success
-        12. Success
-        13. Success
     """
 
     USER_DN = 'uid=test_user_1000,ou=people,dc=example,dc=com'
@@ -468,25 +496,8 @@ def test_lastlogin_history(topology_st, request):
     LOGIN_HIST_SIZE_TWO = 2
 
     inst = topology_st[0]
-
-    # Enable plugin and restart
-    plugin = AccountPolicyPlugin(inst)
-    plugin.disable()
-    plugin.enable()
-    inst.restart()
-
-    # Add config entry, set alwaysrecordlogin to yes (lastLoginHistorySize defaults to 5)
-    ap_configs = AccountPolicyConfigs(inst)
-    try:
-        ap_config = ap_configs.create(properties={'cn': 'config', 'alwaysrecordlogin': 'yes', })
-    except ldap.ALREADY_EXISTS:
-        ap_config = ap_configs.get('config')
-        ap_config.replace('alwaysrecordlogin', 'yes')
-
-    # Add a test user entry
-    users = UserAccounts(inst, DEFAULT_SUFFIX)
-    user = users.create_test_user(uid=1000, gid=2000)
-    user.replace('userPassword', USER_PW)
+    user = setup_test_user
+    ap_config = setup_account_policy_plugin
 
     # Bind as test user more times than lastLoginHistorySize
     user_binds(user, USER_PW, LOGIN_HIST_NUM_BINDS_SEVEN)
@@ -494,12 +505,7 @@ def test_lastlogin_history(topology_st, request):
     # Verify lastLoginTimeHistory attribute returns the correct number of entries in chronological order
     verify_last_login_entries(inst, USER_DN, LOGIN_HIST_SIZE_FIVE)
 
-    # Reduce the lastLoginHistorySize to LOGIN_HIST_SIZE_TWO
-    try:
-        ap_config = ap_configs.create(properties={'cn': 'config', 'lastLoginHistorySize': str(LOGIN_HIST_SIZE_TWO)})
-    except ldap.ALREADY_EXISTS:
-        ap_config = ap_configs.get('config')
-        ap_config.replace('lastLoginHistorySize', str(LOGIN_HIST_SIZE_TWO))
+    ap_config.replace('lastLoginHistorySize', str(LOGIN_HIST_SIZE_TWO))
 
     # Bind as test user more times than lastLoginHistorySize
     user_binds(user, USER_PW, LOGIN_HIST_NUM_BINDS_SEVEN)
@@ -508,11 +514,7 @@ def test_lastlogin_history(topology_st, request):
     verify_last_login_entries(inst, USER_DN, LOGIN_HIST_SIZE_TWO)
 
     # Increase the lastLoginHistorySize to LOGIN_HIST_SIZE_FIVE
-    try:
-        ap_config = ap_configs.create(properties={'cn': 'config', 'lastLoginHistorySize': str(LOGIN_HIST_SIZE_FIVE)})
-    except ldap.ALREADY_EXISTS:
-        ap_config = ap_configs.get('config')
-        ap_config.replace('lastLoginHistorySize', str(LOGIN_HIST_SIZE_FIVE))
+    ap_config.replace('lastLoginHistorySize', str(LOGIN_HIST_SIZE_FIVE))
 
     # Bind as test user more times than lastLoginHistorySize
     user_binds(user, USER_PW, LOGIN_HIST_NUM_BINDS_SEVEN)
@@ -520,11 +522,84 @@ def test_lastlogin_history(topology_st, request):
     # Verify lastLoginTimeHistory attribute returns the correct number of entries in chronological order
     verify_last_login_entries(inst, USER_DN, LOGIN_HIST_SIZE_FIVE)
 
-    def fin():
-        log.info('test_lastlogin_history cleanup')
-        user.delete()
 
-    request.addfinalizer(fin)
+def test_lastlogin_history_size_zero(topology_st, setup_test_user, setup_account_policy_plugin):
+    """Verify that when lastLoginHistorySize is set to zero, no login history is recorded.
+
+    :id: c1169b98-ebd9-4fe9-8402-c95f6f80a184
+    :setup: Standalone instance, Global account policy plugin configuration,
+            set alwaysrecordlogin to yes, and a test user.
+    :steps:
+        1. Set the lastLoginHistorySize to 0.
+        2. Bind as the test user more times than the lastLoginHistorySize.
+        3. Search for the lastLoginTimeHistory attribute on the test user DN.
+    :expectedresults:
+        1. The lastLoginHistorySize is successfully set to 0.
+        2. Success.
+        3. The returned entry has no timestamps, as the size was set to zero.
+    """
+
+    USER_DN = 'uid=test_user_1000,ou=people,dc=example,dc=com'
+    USER_PW = 'password'
+    LOGIN_HIST_NUM_BINDS_THREE = 3
+    LOGIN_HIST_SIZE_ZERO = 0
+
+    inst = topology_st[0]
+    user = setup_test_user
+    ap_config = setup_account_policy_plugin
+
+    # Set lastLoginHistorySize to 0
+    ap_config.replace('lastLoginHistorySize', str(LOGIN_HIST_SIZE_ZERO))
+
+    # Bind as test user more times than lastLoginHistorySize
+    user_binds(user, USER_PW, LOGIN_HIST_NUM_BINDS_THREE)
+
+    # Verify no entries in lastLoginTimeHistory attribute
+    verify_last_login_entries(inst, USER_DN, LOGIN_HIST_SIZE_ZERO)
+
+
+def test_lastlogin_history_size_negative(topology_st, setup_account_policy_plugin):
+    """Verify that setting the lastLoginHistorySize to a negative number raises an error.
+
+    :id: 3e3252e0-ad66-4d49-b9a1-3e097f88f2c4
+    :setup: Standalone instance, Global account policy plugin configuration,
+            set alwaysrecordlogin to yes.
+    :steps:
+        1. Try to set the lastLoginHistorySize to a negative number.
+    :expectedresults:
+        1. A warning messge has been written to the error logs.
+    """
+
+    LOGIN_HIST_SIZE_NEGATIVE = -1
+    AC_POL_CFG_DN = "cn=config,cn=Account Policy Plugin,cn=plugins,cn=config"
+
+    inst = topology_st[0]
+    ap_config = setup_account_policy_plugin
+
+    # Try to set lastLoginHistorySize to negative
+    ap_config.replace('lastLoginHistorySize', str(LOGIN_HIST_SIZE_NEGATIVE))
+
+    assert inst.searchErrorsLog("Invalid value for login-history-size: -1")
+
+
+def test_lastlogin_history_size_non_integer(topology_st, setup_account_policy_plugin):
+    """Verify that setting the lastLoginHistorySize to a non-integer value raises an error.
+
+    :id: 460e17a0-4d76-4c1e-94e8-a09e185b4dca
+    :setup: Standalone instance, Global account policy plugin configuration,
+            set alwaysrecordlogin to yes.
+    :steps:
+        1. Try to set the lastLoginHistorySize to a non-integer value.
+    :expectedresults:
+        1. An ldap.INVALID_SYNTAX error is raised.
+    """
+
+    LOGIN_HIST_SIZE_NON_INTEGER = 'five'
+    ap_config = setup_account_policy_plugin
+
+    # Try to set lastLoginHistorySize to a non-integer
+    with pytest.raises(ldap.INVALID_SYNTAX):
+        ap_config.replace('lastLoginHistorySize', str(LOGIN_HIST_SIZE_NON_INTEGER))
 
 
 def test_glact_login(topology_st, accpol_global):
@@ -1223,6 +1298,127 @@ def test_locact_modrdn(topology_st, accpol_local):
     account_status(topology_st, suffix, subtree, userid, 1, 0, "Enabled")
     del_users(topology_st, suffix, subtree, userid, nousrs)
 
+def test_acct_policy_consumer(topology_m1c1, request):
+    """Test the lastLoginHistory is updated on consumer without
+    referral error
+
+    :id: 53a9a2c7-6b10-41c9-b9f9-bde412d04acb
+    :setup: Supplier Instance, Consumer Instance
+    :steps:
+        1. Create a test entry on the supplier
+        2. Configure lastLoginTime on supplier and consumer
+        3. On supplier 3 binds of the test entry
+        4. On supplier check there is 3 lastLoginHistory values
+        5. On supplier check there is no error in error logs
+        6. On consumer 3 binds of the test entry
+        7. On consumer check there is 3 lastLoginHistory values
+        8. On consumer check there is no error in error logs
+    :expectedresults:
+        1. Success
+        2. Success
+        3. Success
+        4. Success
+        5. Success
+        6. Success
+        7. Success
+        8. Success
+    """
+
+    supplier = topology_m1c1.ms['supplier1']
+    consumer = topology_m1c1.cs['consumer1']
+    USER_PW = 'password'
+
+    # Add on the supplier a test user entry and wait it is on the consumer
+    users_supplier = UserAccounts(supplier, DEFAULT_SUFFIX, rdn=None)
+    user_supplier = users_supplier.create_test_user(uid=1000, gid=2000)
+    user_supplier.replace('userPassword', USER_PW)
+
+    users_consumer = UserAccounts(consumer, DEFAULT_SUFFIX, rdn=None)
+    for i in range(0, 10):
+        try:
+            user_consumer = users_consumer.get("test_user_1000")
+            break
+        except ldap.NO_SUCH_OBJECT:
+            time.sleep(1)
+
+    # Configure lastLoginTime on supplier and consumer
+    plugin = AccountPolicyPlugin(supplier)
+    plugin.enable()
+    ACCPOL_DN = "cn={},{}".format(PLUGIN_ACCT_POLICY, DN_PLUGIN)
+    ACCP_CONF = "{},{}".format(DN_CONFIG, ACCPOL_DN)
+    plugin.set('nsslapd-pluginarg0', ACCP_CONF)
+    accp = AccountPolicyConfig(supplier, dn=ACCP_CONF)
+    accp.set('alwaysrecordlogin', 'yes')
+    accp.set('stateattrname', 'lastLoginTime')
+    supplier.restart(timeout=10)
+
+    plugin = AccountPolicyPlugin(consumer)
+    plugin.enable()
+    ACCPOL_DN = "cn={},{}".format(PLUGIN_ACCT_POLICY, DN_PLUGIN)
+    ACCP_CONF = "{},{}".format(DN_CONFIG, ACCPOL_DN)
+    plugin.set('nsslapd-pluginarg0', ACCP_CONF)
+    accp = AccountPolicyConfig(consumer, dn=ACCP_CONF)
+    accp.set('alwaysrecordlogin', 'yes')
+    accp.set('stateattrname', 'lastLoginTime')
+    consumer.restart(timeout=10)
+
+    # On supplier
+    # Do 3 binds with a delay to
+    # allow several values lastLoginHistory
+    user_supplier.bind(USER_PW)
+    time.sleep(2)
+    user_supplier = users_supplier.get("test_user_1000")
+    user_supplier.bind(USER_PW)
+    time.sleep(2)
+    user_supplier = users_supplier.get("test_user_1000")
+    user_supplier.bind(USER_PW)
+
+    # Verify there is no referral error
+    results = supplier.ds_error_log.match('.*.acct_update_login_history - Modify error 10 on entry*')
+    assert not results
+
+    # Verify that we got 3 values for lastLoginHistory
+    assert len(user_supplier.get_attr_vals_utf8_l('lastLoginHistory')) == 3
+
+    # On Consumer
+    # Do 3 binds with a delay to
+    # allow several values lastLoginHistory
+    user_supplier.bind(USER_PW)
+    user_consumer.bind(USER_PW)
+    time.sleep(2)
+    user_consumer = users_supplier.get("test_user_1000")
+    user_consumer.bind(USER_PW)
+    time.sleep(2)
+    user_consumer = users_supplier.get("test_user_1000")
+    user_consumer.bind(USER_PW)
+
+    # Verify there is no referral error
+    results = consumer.ds_error_log.match('.*.acct_update_login_history - Modify error 10 on entry*')
+    assert not results
+
+    # Verify that we got at least 3 values for lastLoginHistory
+    assert len(user_consumer.get_attr_vals_utf8_l('lastLoginHistory')) >= 3
+
+
+    def fin():
+        user_supplier.delete()
+        log.info('Disabling Global accpolicy plugin and removing pwpolicy attrs')
+        try:
+            plugin = AccountPolicyPlugin(supplier)
+            plugin.disable()
+        except ldap.LDAPError as e:
+            log.error('Failed to disable Global accpolicy plugin, {}'.format(e.message['desc']))
+            assert False
+        supplier.restart(timeout=10)
+        try:
+            plugin = AccountPolicyPlugin(consumer)
+            plugin.disable()
+        except ldap.LDAPError as e:
+            log.error('Failed to disable Global accpolicy plugin, {}'.format(e.message['desc']))
+            assert False
+        consumer.restart(timeout=10)
+
+    request.addfinalizer(fin)
 
 if __name__ == '__main__':
     # Run isolated
