@@ -1,5 +1,5 @@
 # --- BEGIN COPYRIGHT BLOCK ---
-# Copyright (C) 2018 Red Hat, Inc.
+# Copyright (C) 2020 Red Hat, Inc.
 # All rights reserved.
 #
 # License: GPL (version 3 or any later version).
@@ -10,15 +10,19 @@ import time
 import logging
 import ldap
 import pytest
+import re
 from itertools import permutations
 from lib389._constants import *
 from lib389.idm.nscontainer import nsContainers
-from lib389.idm.user import UserAccounts
+from lib389.idm.user import UserAccounts, UserAccount
 from lib389.idm.group import Groups
 from lib389.idm.organizationalunit import OrganizationalUnits
-from lib389.replica import ReplicationManager
+from lib389.replica import ReplicationManager, Replicas
 from lib389.agreement import Agreements
 from lib389.plugins import MemberOfPlugin
+from lib389.dirsrv_log import DirsrvErrorLog
+
+pytestmark = pytest.mark.tier1
 
 DEBUGGING = os.getenv("DEBUGGING", default=False)
 if DEBUGGING:
@@ -111,10 +115,10 @@ def _test_base(topology):
     audit log, error log for replica and access log for internal
     """
 
-    M1 = topology.ms["master1"]
+    M1 = topology.ms["supplier1"]
 
     conts = nsContainers(M1, SUFFIX)
-    base_m2 = conts.create(properties={'cn': 'test_container'})
+    base_m2 = conts.ensure_state(properties={'cn': 'test_container'})
 
     for inst in topology:
         inst.config.loglevel([ErrorLog.DEFAULT, ErrorLog.REPLICA], service='error')
@@ -126,17 +130,37 @@ def _test_base(topology):
     return base_m2
 
 
+def _dump_logs(topology):
+    """ Logs instances error logs"""
+    for inst in topology:
+        errlog = DirsrvErrorLog(inst)
+        log.info(f'{inst.serverid} errorlog:')
+        for l in errlog.readlines():
+            log.info(l.strip())
+
+
 def _delete_test_base(inst, base_m2_dn):
     """Delete test container with entries and entry conflicts"""
 
-    ents = inst.search_s(base_m2_dn, ldap.SCOPE_SUBTREE, filterstr="(|(objectclass=*)(objectclass=ldapsubentry))")
+    try:
+        ents = inst.search_s(base_m2_dn, ldap.SCOPE_SUBTREE, filterstr="(|(objectclass=*)(objectclass=ldapsubentry))")
+        for ent in sorted(ents, key=lambda e: len(e.dn), reverse=True):
+            log.debug("Delete entry children {}".format(ent.dn))
+            try:
+                inst.delete_ext_s(ent.dn)
+            except ldap.NO_SUCH_OBJECT:  # For the case with objectclass: glue entries
+                pass
+    except ldap.NO_SUCH_OBJECT:  # Subtree is already removed.
+        pass
 
-    for ent in sorted(ents, key=lambda e: len(e.dn), reverse=True):
-        log.debug("Delete entry children {}".format(ent.dn))
-        try:
-            inst.delete_ext_s(ent.dn)
-        except ldap.NO_SUCH_OBJECT:  # For the case with objectclass: glue entries
-            pass
+
+def _resume_agmts(inst):
+    """Resume all agreements in the instance"""
+
+    replicas = Replicas(inst)
+    replica = replicas.get(DEFAULT_SUFFIX)
+    for agreement in replica.get_agreements().list():
+        agreement.resume()
 
 
 @pytest.fixture
@@ -145,7 +169,17 @@ def base_m2(topology_m2, request):
 
     def fin():
         if not DEBUGGING:
-            _delete_test_base(topology_m2.ms["master1"], tb.dn)
+            _delete_test_base(topology_m2.ms["supplier1"], tb.dn)
+            _delete_test_base(topology_m2.ms["supplier2"], tb.dn)
+            # Replication may break while deleting the container because naming
+            # conflict entries still exists on the other side
+            # Note IMHO there a bug in the entryrdn handling of replicated delete operation
+            # ( children naming conflict or glue entries older than the parent delete operation should
+            #   should be deleted when the parent is deleted )
+            # So let restarts the agmt once everything is deleted.
+            topology_m2.pause_all_replicas()
+            topology_m2.resume_all_replicas()
+
     request.addfinalizer(fin)
 
     return tb
@@ -157,18 +191,18 @@ def base_m3(topology_m3, request):
 
     def fin():
         if not DEBUGGING:
-            _delete_test_base(topology_m3.ms["master1"], tb.dn)
+            _delete_test_base(topology_m3.ms["supplier1"], tb.dn)
     request.addfinalizer(fin)
 
     return tb
 
 
-class TestTwoMasters:
+class TestTwoSuppliers:
     def test_add_modrdn(self, topology_m2, base_m2):
         """Check that conflict properly resolved for create - modrdn operations
 
         :id: 77f09b18-03d1-45da-940b-1ad2c2908ebb
-        :setup: Two master replication, test container for entries, enable plugin logging,
+        :setup: Two supplier replication, test container for entries, enable plugin logging,
                 audit log, error log for replica and access log for internal
         :steps:
             1. Add five users to m1 and wait for replication to happen
@@ -180,7 +214,7 @@ class TestTwoMasters:
             7. Rename an entry on m1 and rename on m2. Use different entries
                but rename them to the same entry
             8. Resume replication
-            9. Check that the entries on both masters are the same and replication is working
+            9. Check that the entries on both suppliers are the same and replication is working
         :expectedresults:
             1. It should pass
             2. It should pass
@@ -192,8 +226,8 @@ class TestTwoMasters:
             8. It should pass
         """
 
-        M1 = topology_m2.ms["master1"]
-        M2 = topology_m2.ms["master2"]
+        M1 = topology_m2.ms["supplier1"]
+        M2 = topology_m2.ms["supplier2"]
         test_users_m1 = UserAccounts(M1, base_m2.dn, rdn=None)
         test_users_m2 = UserAccounts(M2, base_m2.dn, rdn=None)
         repl = ReplicationManager(SUFFIX)
@@ -238,7 +272,8 @@ class TestTwoMasters:
         which involve add, modify, modrdn and delete
 
         :id: 77f09b18-03d1-45da-940b-1ad2c2908eb1
-        :setup: Two master replication, test container for entries, enable plugin logging,
+        :customerscenario: True
+        :setup: Two supplier replication, test container for entries, enable plugin logging,
                 audit log, error log for replica and access log for internal
         :steps:
             1. Add ten users to m1 and wait for replication to happen
@@ -247,11 +282,11 @@ class TestTwoMasters:
             4. Test add-mod on m1 and add on m2
             5. Test add-modrdn on m1 and add on m2
             6. Test multiple add, modrdn
-            7. Test Add-del on both masters
+            7. Test Add-del on both suppliers
             8. Test modrdn-modrdn
             9. Test modrdn-del
             10. Resume replication
-            11. Check that the entries on both masters are the same and replication is working
+            11. Check that the entries on both suppliers are the same and replication is working
         :expectedresults:
             1. It should pass
             2. It should pass
@@ -266,8 +301,8 @@ class TestTwoMasters:
             11. It should pass
         """
 
-        M1 = topology_m2.ms["master1"]
-        M2 = topology_m2.ms["master2"]
+        M1 = topology_m2.ms["supplier1"]
+        M2 = topology_m2.ms["supplier2"]
 
         test_users_m1 = UserAccounts(M1, base_m2.dn, rdn=None)
         test_users_m2 = UserAccounts(M2, base_m2.dn, rdn=None)
@@ -335,7 +370,7 @@ class TestTwoMasters:
         _create_user(test_users_m1, user_num, sleep=True)
         _modify_user(test_users_m2, user_num, sleep=True)
 
-        log.info("Add - del on both masters")
+        log.info("Add - del on both suppliers")
         user_num += 1
         _create_user(test_users_m1, user_num)
         _delete_user(test_users_m1, user_num, sleep=True)
@@ -359,7 +394,6 @@ class TestTwoMasters:
         topology_m2.resume_all_replicas()
 
         repl.test_replication_topology(topology_m2)
-        time.sleep(30)
 
         user_dns_m1 = [user.dn for user in test_users_m1.list()]
         user_dns_m2 = [user.dn for user in test_users_m2.list()]
@@ -370,7 +404,7 @@ class TestTwoMasters:
         with memberOf and groups
 
         :id: 77f09b18-03d1-45da-940b-1ad2c2908eb3
-        :setup: Two master replication, test container for entries, enable plugin logging,
+        :setup: Two supplier replication, test container for entries, enable plugin logging,
                 audit log, error log for replica and access log for internal
         :steps:
             1. Enable memberOf plugin
@@ -382,7 +416,7 @@ class TestTwoMasters:
             7. Create a group on m2 and m1, delete from m1
             8. Create two different groups on m2
             9. Resume replication
-            10. Check that the entries on both masters are the same and replication is working
+            10. Check that the entries on both suppliers are the same and replication is working
         :expectedresults:
             1. It should pass
             2. It should pass
@@ -398,8 +432,8 @@ class TestTwoMasters:
 
         pytest.xfail("Issue 49591 - work in progress")
 
-        M1 = topology_m2.ms["master1"]
-        M2 = topology_m2.ms["master2"]
+        M1 = topology_m2.ms["supplier1"]
+        M2 = topology_m2.ms["supplier2"]
         test_users_m1 = UserAccounts(M1, base_m2.dn, rdn=None)
         test_groups_m1 = Groups(M1, base_m2.dn, rdn=None)
         test_groups_m2 = Groups(M2, base_m2.dn, rdn=None)
@@ -465,17 +499,17 @@ class TestTwoMasters:
         with managed entries
 
         :id: 77f09b18-03d1-45da-940b-1ad2c2908eb4
-        :setup: Two master replication, test container for entries, enable plugin logging,
+        :setup: Two supplier replication, test container for entries, enable plugin logging,
                 audit log, error log for replica and access log for internal
         :steps:
             1. Create ou=managed_users and ou=managed_groups under test container
             2. Configure managed entries plugin and add a template to test container
             3. Add a user to m1 and wait for replication to happen
             4. Pause replication
-            5. Create a user on m1 and m2 with a same group ID on both master
-            6. Create a user on m1 and m2 with a different group ID on both master
+            5. Create a user on m1 and m2 with a same group ID on both supplier
+            6. Create a user on m1 and m2 with a different group ID on both supplier
             7. Resume replication
-            8. Check that the entries on both masters are the same and replication is working
+            8. Check that the entries on both suppliers are the same and replication is working
         :expectedresults:
             1. It should pass
             2. It should pass
@@ -489,8 +523,8 @@ class TestTwoMasters:
 
         pytest.xfail("Issue 49591 - work in progress")
 
-        M1 = topology_m2.ms["master1"]
-        M2 = topology_m2.ms["master2"]
+        M1 = topology_m2.ms["supplier1"]
+        M2 = topology_m2.ms["supplier2"]
         repl = ReplicationManager(SUFFIX)
 
         ous = OrganizationalUnits(M1, DEFAULT_SUFFIX)
@@ -544,23 +578,23 @@ class TestTwoMasters:
         with nested entries with children
 
         :id: 77f09b18-03d1-45da-940b-1ad2c2908eb5
-        :setup: Two master replication, test container for entries, enable plugin logging,
+        :setup: Two supplier replication, test container for entries, enable plugin logging,
                 audit log, error log for replica and access log for internal
         :steps:
             1. Add 15 containers to m1 and wait for replication to happen
             2. Pause replication
-            3. Create parent-child on master2 and master1
-            4. Create parent-child on master1 and master2
-            5. Create parent-child on master1 and master2 different child rdn
-            6. Create parent-child on master1 and delete parent on master2
-            7. Create parent on master1, delete it and parent-child on master2, delete them
-            8. Create parent on master1, delete it and parent-two children on master2
-            9. Create parent-two children on master1 and parent-child on master2, delete them
+            3. Create parent-child on supplier2 and supplier1
+            4. Create parent-child on supplier1 and supplier2
+            5. Create parent-child on supplier1 and supplier2 different child rdn
+            6. Create parent-child on supplier1 and delete parent on supplier2
+            7. Create parent on supplier1, delete it and parent-child on supplier2, delete them
+            8. Create parent on supplier1, delete it and parent-two children on supplier2
+            9. Create parent-two children on supplier1 and parent-child on supplier2, delete them
             10. Create three subsets inside existing container entry, applying only part of changes on m2
             11. Create more combinations of the subset with parent-child on m1 and parent on m2
             12. Delete container on m1, modify user1 on m1, create parent on m2 and modify user2 on m2
             13. Resume replication
-            14. Check that the entries on both masters are the same and replication is working
+            14. Check that the entries on both suppliers are the same and replication is working
         :expectedresults:
             1. It should pass
             2. It should pass
@@ -580,8 +614,8 @@ class TestTwoMasters:
 
         pytest.xfail("Issue 49591 - work in progress")
 
-        M1 = topology_m2.ms["master1"]
-        M2 = topology_m2.ms["master2"]
+        M1 = topology_m2.ms["supplier1"]
+        M2 = topology_m2.ms["supplier2"]
         repl = ReplicationManager(SUFFIX)
         test_users_m1 = UserAccounts(M1, base_m2.dn, rdn=None)
         test_users_m2 = UserAccounts(M2, base_m2.dn, rdn=None)
@@ -597,25 +631,25 @@ class TestTwoMasters:
 
         topology_m2.pause_all_replicas()
 
-        log.info("Create parent-child on master2 and master1")
+        log.info("Create parent-child on supplier2 and supplier1")
         _create_container(M2, base_m2.dn, 'p0', sleep=True)
         cont_p = _create_container(M1, base_m2.dn, 'p0', sleep=True)
         _create_container(M1, cont_p.dn, 'c0', sleep=True)
         _create_container(M2, cont_p.dn, 'c0', sleep=True)
 
-        log.info("Create parent-child on master1 and master2")
+        log.info("Create parent-child on supplier1 and supplier2")
         cont_p = _create_container(M1, base_m2.dn, 'p1', sleep=True)
         _create_container(M2, base_m2.dn, 'p1', sleep=True)
         _create_container(M1, cont_p.dn, 'c1', sleep=True)
         _create_container(M2, cont_p.dn, 'c1', sleep=True)
 
-        log.info("Create parent-child on master1 and master2 different child rdn")
+        log.info("Create parent-child on supplier1 and supplier2 different child rdn")
         cont_p = _create_container(M1, base_m2.dn, 'p2', sleep=True)
         _create_container(M2, base_m2.dn, 'p2', sleep=True)
         _create_container(M1, cont_p.dn, 'c2', sleep=True)
         _create_container(M2, cont_p.dn, 'c3', sleep=True)
 
-        log.info("Create parent-child on master1 and delete parent on master2")
+        log.info("Create parent-child on supplier1 and delete parent on supplier2")
         cont_num = 0
         cont_p_m1 = _create_container(M1, cont_list[cont_num].dn, 'p0', sleep=True)
         cont_p_m2 = _create_container(M2, cont_list[cont_num].dn, 'p0', sleep=True)
@@ -628,7 +662,7 @@ class TestTwoMasters:
         _create_container(M1, cont_p_m1.dn, 'c0', sleep=True)
         _delete_container(cont_p_m2, sleep=True)
 
-        log.info("Create parent on master1, delete it and parent-child on master2, delete them")
+        log.info("Create parent on supplier1, delete it and parent-child on supplier2, delete them")
         cont_num += 1
         cont_p_m1 = _create_container(M1, cont_list[cont_num].dn, 'p0')
         _delete_container(cont_p_m1, sleep=True)
@@ -647,7 +681,7 @@ class TestTwoMasters:
         cont_p_m1 = _create_container(M1, cont_list[cont_num].dn, 'p0')
         _delete_container(cont_p_m1)
 
-        log.info("Create parent on master1, delete it and parent-two children on master2")
+        log.info("Create parent on supplier1, delete it and parent-two children on supplier2")
         cont_num += 1
         cont_p_m1 = _create_container(M1, cont_list[cont_num].dn, 'p0')
         _delete_container(cont_p_m1, sleep=True)
@@ -664,7 +698,7 @@ class TestTwoMasters:
         cont_p_m1 = _create_container(M1, cont_list[cont_num].dn, 'p0')
         _delete_container(cont_p_m1, sleep=True)
 
-        log.info("Create parent-two children on master1 and parent-child on master2, delete them")
+        log.info("Create parent-two children on supplier1 and parent-child on supplier2, delete them")
         cont_num += 1
         cont_p_m2 = _create_container(M2, cont_list[cont_num].dn, 'p0')
         cont_c_m2 = _create_container(M2, cont_p_m2.dn, 'c0')
@@ -744,7 +778,7 @@ class TestTwoMasters:
 
         conts_dns = {}
         for num in range(1, 3):
-            inst = topology_m2.ms["master{}".format(num)]
+            inst = topology_m2.ms["supplier{}".format(num)]
             conts_dns[inst.serverid] = []
             conts = nsContainers(inst, base_m2.dn)
             for cont in conts.list():
@@ -761,14 +795,195 @@ class TestTwoMasters:
         user_dns_m2 = [user.dn for user in test_users_m2.list()]
         assert set(user_dns_m1) == set(user_dns_m2)
 
+    def test_conflict_attribute_multi_valued(self, topology_m2, base_m2):
+        """A RDN attribute being multi-valued, checks that after several operations
+           MODRDN and MOD_REPL its RDN values are the same on both servers
 
-class TestThreeMasters:
+        :id: 225b3522-8ed7-4256-96f9-5fab9b7044a5
+        :setup: Two supplier replication,
+                audit log, error log for replica and access log for internal
+        :steps:
+            1. Create a test entry uid=user_test_1000,...
+            2. Pause all replication agreements
+            3. On M1 rename it into uid=foo1,...
+            4. On M2 rename it into uid=foo2,...
+            5. On M1 MOD_REPL uid:foo1
+            6. Resume all replication agreements
+            7. Check that entry on M1 has uid=foo1, foo2
+            8. Check that entry on M2 has uid=foo1, foo2
+            9. Check that entry on M1 and M2 has the same uid values
+        :expectedresults:
+            1. It should pass
+            2. It should pass
+            3. It should pass
+            4. It should pass
+            5. It should pass
+            6. It should pass
+            7. It should pass
+            8. It should pass
+            9. It should pass
+        """
+
+        M1 = topology_m2.ms["supplier1"]
+        M2 = topology_m2.ms["supplier2"]
+        repl = ReplicationManager(SUFFIX)
+
+        # add a test user
+        test_users_m1 = UserAccounts(M1, base_m2.dn, rdn=None)
+        user_1 = test_users_m1.create_test_user(uid=1000)
+        test_users_m2 = UserAccount(M2, user_1.dn)
+        # Waiting fo the user to be replicated
+        for i in range(0,60):
+            time.sleep(1)
+            if test_users_m2.exists():
+                break
+        try:
+            assert(test_users_m2.exists())
+        except AssertionError as e:
+            _dump_logs(topology_m2)
+            raise e from None
+
+        # Stop replication agreements
+        topology_m2.pause_all_replicas()
+
+        # On M1 rename test entry in uid=foo1
+        original_dn = user_1.dn
+        user_1.rename('uid=foo1')
+        time.sleep(1)
+
+        # On M2 rename test entry in uid=foo2
+        M2.rename_s(original_dn, 'uid=foo2')
+        time.sleep(2)
+
+        # on M1 MOD_REPL uid into foo1
+        user_1.replace('uid', 'foo1')
+
+        # resume replication agreements
+        topology_m2.resume_all_replicas()
+        repl.test_replication_topology(topology_m2)
+
+        # check that on M1, the entry 'uid' has two values 'foo1' and 'foo2'
+        final_dn = re.sub('^.*1000,', 'uid=foo2,', original_dn)
+        final_user_m1 = UserAccount(M1, final_dn)
+        for val in final_user_m1.get_attr_vals_utf8('uid'):
+            log.info("Check %s is on M1" % val)
+            assert(val in ['foo1', 'foo2'])
+
+        # check that on M2, the entry 'uid' has two values 'foo1' and 'foo2'
+        final_user_m2 = UserAccount(M2, final_dn)
+        for val in final_user_m2.get_attr_vals_utf8('uid'):
+            log.info("Check %s is on M1" % val)
+            assert(val in ['foo1', 'foo2'])
+
+        # check that the entry have the same uid values
+        for val in final_user_m1.get_attr_vals_utf8('uid'):
+            log.info("Check M1.uid %s is also on M2" % val)
+            assert(val in final_user_m2.get_attr_vals_utf8('uid'))
+
+        for val in final_user_m2.get_attr_vals_utf8('uid'):
+            log.info("Check M2.uid %s is also on M1" % val)
+            assert(val in final_user_m1.get_attr_vals_utf8('uid'))
+
+    def test_conflict_attribute_single_valued(self, topology_m2, base_m2):
+        """A RDN attribute being signle-valued, checks that after several operations
+           MODRDN and MOD_REPL its RDN values are the same on both servers
+
+        :id: c38ae613-5d1e-47cf-b051-c7284e64b817
+        :setup: Two supplier replication, test container for entries, enable plugin logging,
+                audit log, error log for replica and access log for internal
+        :steps:
+            1. Create a test entry uid=user_test_1000,...
+            2. Pause all replication agreements
+            3. On M1 rename it into employeenumber=foo1,...
+            4. On M2 rename it into employeenumber=foo2,...
+            5. On M1 MOD_REPL employeenumber:foo1
+            6. Resume all replication agreements
+            7. Check that entry on M1 has employeenumber=foo1
+            8. Check that entry on M2 has employeenumber=foo1
+            9. Check that entry on M1 and M2 has the same employeenumber values
+        :expectedresults:
+            1. It should pass
+            2. It should pass
+            3. It should pass
+            4. It should pass
+            5. It should pass
+            6. It should pass
+            7. It should pass
+            8. It should pass
+            9. It should pass
+        """
+
+        M1 = topology_m2.ms["supplier1"]
+        M2 = topology_m2.ms["supplier2"]
+        repl = ReplicationManager(SUFFIX)
+
+        # add a test user with a dummy 'uid' extra value because modrdn removes
+        # uid that conflict with 'account' objectclass
+        test_users_m1 = UserAccounts(M1, base_m2.dn, rdn=None)
+        user_1 = test_users_m1.create_test_user(uid=1000)
+        user_1.add('objectclass', 'extensibleobject')
+        user_1.add('uid', 'dummy')
+        test_users_m2 = UserAccount(M2, user_1.dn)
+
+        # Waiting fo the user to be replicated
+        for i in range(0,60):
+            time.sleep(1)
+            if test_users_m2.exists():
+                break
+        try:
+            assert(test_users_m2.exists())
+        except AssertionError as e:
+            _dump_logs(topology_m2)
+            raise e from None
+
+        # Stop replication agreements
+        topology_m2.pause_all_replicas()
+
+        # On M1 rename test entry in employeenumber=foo1
+        original_dn = user_1.dn
+        user_1.rename('employeenumber=foo1')
+        time.sleep(1)
+
+        # On M2 rename test entry in employeenumber=foo2
+        M2.rename_s(original_dn, 'employeenumber=foo2')
+        time.sleep(2)
+
+        # on M1 MOD_REPL uid into foo1
+        user_1.replace('employeenumber', 'foo1')
+
+        # resume replication agreements
+        topology_m2.resume_all_replicas()
+        repl.test_replication_topology(topology_m2)
+
+        # check that on M1, the entry 'employeenumber' has value 'foo1'
+        final_dn = re.sub('^.*1000,', 'employeenumber=foo2,', original_dn)
+        final_user_m1 = UserAccount(M1, final_dn)
+        for val in final_user_m1.get_attr_vals_utf8('employeenumber'):
+            log.info("Check %s is on M1" % val)
+            assert(val in ['foo1'])
+
+        # check that on M2, the entry 'employeenumber' has values 'foo1'
+        final_user_m2 = UserAccount(M2, final_dn)
+        for val in final_user_m2.get_attr_vals_utf8('employeenumber'):
+            log.info("Check %s is on M2" % val)
+            assert(val in ['foo1'])
+
+        # check that the entry have the same uid values
+        for val in final_user_m1.get_attr_vals_utf8('employeenumber'):
+            log.info("Check M1.uid %s is also on M2" % val)
+            assert(val in final_user_m2.get_attr_vals_utf8('employeenumber'))
+
+        for val in final_user_m2.get_attr_vals_utf8('employeenumber'):
+            log.info("Check M2.uid %s is also on M1" % val)
+            assert(val in final_user_m1.get_attr_vals_utf8('employeenumber'))
+
+class TestThreeSuppliers:
     def test_nested_entries(self, topology_m3, base_m3):
         """Check that conflict properly resolved for operations
         with nested entries with children
 
         :id: 77f09b18-03d1-45da-940b-1ad2c2908eb6
-        :setup: Three master replication, test container for entries, enable plugin logging,
+        :setup: Three supplier replication, test container for entries, enable plugin logging,
                 audit log, error log for replica and access log for internal
         :steps:
             1. Add 15 containers to m1 and wait for replication to happen
@@ -779,7 +994,7 @@ class TestThreeMasters:
                on m2 - delete one parent and create a child
             6. Test a few more parent-child combinations with three instances
             7. Resume replication
-            8. Check that the entries on both masters are the same and replication is working
+            8. Check that the entries on both suppliers are the same and replication is working
         :expectedresults:
             1. It should pass
             2. It should pass
@@ -793,9 +1008,9 @@ class TestThreeMasters:
 
         pytest.xfail("Issue 49591 - work in progress")
 
-        M1 = topology_m3.ms["master1"]
-        M2 = topology_m3.ms["master2"]
-        M3 = topology_m3.ms["master3"]
+        M1 = topology_m3.ms["supplier1"]
+        M2 = topology_m3.ms["supplier2"]
+        M3 = topology_m3.ms["supplier3"]
         repl = ReplicationManager(SUFFIX)
 
         cont_list = []
@@ -856,7 +1071,7 @@ class TestThreeMasters:
 
         conts_dns = {}
         for num in range(1, 4):
-            inst = topology_m3.ms["master{}".format(num)]
+            inst = topology_m3.ms["supplier{}".format(num)]
             conts_dns[inst.serverid] = []
             conts = nsContainers(inst, base_m3.dn)
             for cont in conts.list():
