@@ -68,7 +68,7 @@ class _AgmtHelper:
             self.binddn = f'cn={cn},cn=config'
         else:
             self.usedn = False
-            self.cn = f'{self.from_inst.host}:{self.from_inst.sslport}'
+            self.cn = ldap.dn.escape_dn_chars(f'{DEFAULT_SUFFIX}:{self.from_inst.host}:{self.from_inst.sslport}')
             self.binddn = f'cn={self.cn}, ou=Services, {DEFAULT_SUFFIX}'
         self.original_state = []
         self._pass = False
@@ -1165,6 +1165,15 @@ def test_online_reinit_may_hang(topo_with_sigkill):
     """
     M1 = topo_with_sigkill.ms["supplier1"]
     M2 = topo_with_sigkill.ms["supplier2"]
+
+    # The RFE 5367 (when enabled) retrieves the DN
+    # from the dncache. This hides an issue
+    # with primary fix for 6417.
+    # We need to disable the RFE to verify that the primary
+    # fix is properly fixed.
+    if ds_is_newer('2.3.1'):
+        M1.config.replace('nsslapd-return-original-entrydn', 'off')
+
     M1.stop()
     ldif_file = '%s/supplier1.ldif' % M1.get_ldif_dir()
     M1.db2ldif(bename=DEFAULT_BENAME, suffixes=[DEFAULT_SUFFIX],
