@@ -75,6 +75,7 @@ static pthread_mutex_t keeprunning_mutex;
 static pthread_cond_t keeprunning_cv;
 
 static int keeprunning = 0;
+static uint64_t batch_thread_running = 0;
 static referint_config *config = NULL;
 static Slapi_DN *_ConfigAreaDN = NULL;
 static Slapi_DN *_pluginDN = NULL;
@@ -1360,7 +1361,7 @@ bail:
 int
 referint_postop_close(Slapi_PBlock *pb __attribute__((unused)))
 {
-    /* signal the thread to exit */
+    /* signal the batch thread to exit */
     if (referint_get_delay() > 0) {
         pthread_mutex_lock(&keeprunning_mutex);
         keeprunning = 0;
@@ -1368,6 +1369,18 @@ referint_postop_close(Slapi_PBlock *pb __attribute__((unused)))
         pthread_mutex_unlock(&keeprunning_mutex);
     }
 
+    /* waiting for the batch thread to exit */
+    while (1) {
+        if (slapi_atomic_load_64(&batch_thread_running, __ATOMIC_ACQUIRE) == 0) {
+            /* batch thread exited */
+            break;
+        }
+
+        DS_Sleep(PR_MillisecondsToInterval(1000));
+    }
+
+
+
     slapi_destroy_rwlock(config_rwlock);
     config_rwlock = NULL;
 
@@ -1395,10 +1408,23 @@ referint_thread_func(void *arg __attribute__((unused)))
     int delay;
     int no_changes;
 
+    slapi_atomic_store_64(&batch_thread_running, 1, __ATOMIC_RELEASE);
+
     /*
      * keep running this thread until plugin is signaled to close
      */
     while (1) {
+        /*
+         * In case of shutdown, plugin close function (referint_postop_close)
+         * is waiting for the end of that thread to do the cleanup
+         */
+        pthread_mutex_lock(&keeprunning_mutex);
+        if (keeprunning == 0) {
+            pthread_mutex_unlock(&keeprunning_mutex);
+            break;
+        }
+        pthread_mutex_unlock(&keeprunning_mutex);
+
         /* refresh the config */
         slapi_ch_free_string(&logfilename);
         referint_get_config(&delay, &logfilename);
@@ -1458,12 +1484,27 @@ referint_thread_func(void *arg __attribute__((unused)))
             }
 
             ptoken = ldap_utf8strtok_r(NULL, delimiter, &iter);
+            if (ptoken == NULL) {
+                /* Invalid line in referint log, skip it */
+                slapi_log_err(SLAPI_LOG_ERR, REFERINT_PLUGIN_SUBSYSTEM,
+                        "Skipping invalid referint log line: (%s)\n", thisline);
+                slapi_sdn_free(&sdn);
+                continue;
+            }
             if (!strcasecmp(ptoken, "NULL")) {
                 tmpsuperior = NULL;
             } else {
                 tmpsuperior = slapi_sdn_new_normdn_byref(ptoken);
             }
+
             ptoken = ldap_utf8strtok_r(NULL, delimiter, &iter);
+            if (ptoken == NULL) {
+                /* Invalid line in referint log, skip it */
+                slapi_log_err(SLAPI_LOG_ERR, REFERINT_PLUGIN_SUBSYSTEM,
+                        "Skipping invalid referint log line: (%s)\n", thisline);
+                slapi_sdn_free(&sdn);
+                continue;
+            }
             if (strcasecmp(ptoken, "NULL") != 0) {
                 /* Set the bind DN in the thread data */
                 if (slapi_td_set_dn(slapi_ch_strdup(ptoken))) {
@@ -1498,6 +1539,8 @@ referint_thread_func(void *arg __attribute__((unused)))
         pthread_mutex_unlock(&keeprunning_mutex);
     }
 
+    slapi_atomic_store_64(&batch_thread_running, 0, __ATOMIC_RELEASE);
+
     /* cleanup resources allocated in start  */
     pthread_mutex_destroy(&keeprunning_mutex);
     pthread_cond_destroy(&keeprunning_cv);
@@ -1599,7 +1642,6 @@ writeintegritylog(Slapi_PBlock *pb, char *logfilename, Slapi_DN *sdn, char *newr
                       "writeintegritylog - Could not write integrity log \"%s\" " SLAPI_COMPONENT_NAME_NSPR " %d (%s)\n",
                       logfilename, PR_GetError(), slapd_pr_strerror(PR_GetError()));
 
-        PR_Unlock(referint_mutex);
         referint_unlock();
         return;
     }
