@@ -54,7 +54,7 @@ get_tombstone_csn(const Slapi_Entry *entry, const CSN **delcsn)
 static Slapi_DN *
 get_valid_parent_for_conflict(Slapi_Entry *entry)
 {
-    char *replconflict = slapi_entry_attr_get_charptr(entry, ATTR_NSDS5_REPLCONFLICT);
+    const char *replconflict = slapi_entry_attr_get_ref(entry, ATTR_NSDS5_REPLCONFLICT);
     char *validdn = NULL;
     Slapi_DN *valid_DN = NULL;
 
@@ -67,7 +67,6 @@ get_valid_parent_for_conflict(Slapi_Entry *entry)
                           "get_valid_parent_for_conflict - valid entry dn: %s\n",
                           validdn);
         }
-        slapi_ch_free_string(&replconflict);
     }
     return valid_DN;
 }
@@ -105,7 +104,7 @@ tombstone_to_conflict_check_parent(
         0,              /*attrsonly*/
         NULL,           /*Controls*/
         parentuniqueid, /*uniqueid*/
-        repl_get_plugin_identity(PLUGIN_MULTIMASTER_REPLICATION),
+        repl_get_plugin_identity(PLUGIN_MULTISUPPLIER_REPLICATION),
         0);
     slapi_search_internal_pb(newpb);
     slapi_pblock_get(newpb, SLAPI_PLUGIN_INTOP_RESULT, &op_result);
@@ -163,7 +162,7 @@ tombstone_to_glue_resolve_parent(
             0,              /*attrsonly*/
             NULL,           /*Controls*/
             parentuniqueid, /*uniqueid*/
-            repl_get_plugin_identity(PLUGIN_MULTIMASTER_REPLICATION),
+            repl_get_plugin_identity(PLUGIN_MULTISUPPLIER_REPLICATION),
             0);
         slapi_search_internal_pb(newpb);
         slapi_pblock_get(newpb, SLAPI_PLUGIN_INTOP_RESULT, &op_result);
@@ -207,7 +206,7 @@ conflict_to_tombstone(char *sessionid, Slapi_Entry *entry, CSN *opcsn)
     const char *uniqueid = slapi_entry_get_uniqueid(entry);
     const char *newrdn = NULL;
     char *conflictdn = NULL;
-    char *replconflict = slapi_entry_attr_get_charptr(entry, ATTR_NSDS5_REPLCONFLICT);
+    const char *replconflict = slapi_entry_attr_get_ref(entry, ATTR_NSDS5_REPLCONFLICT);
 
     if (replconflict) {
         conflictdn = strstr(replconflict, " (ADD) ");
@@ -237,7 +236,6 @@ conflict_to_tombstone(char *sessionid, Slapi_Entry *entry, CSN *opcsn)
     op_result = urp_fixup_delete_entry(uniqueid, slapi_entry_get_dn_const(entry), opcsn, 0);
 
 done:
-    slapi_ch_free_string(&replconflict);
     slapi_rdn_free(&srdn);
     return op_result;
 }
@@ -257,12 +255,12 @@ tombstone_to_conflict(
     int op_result = 0;
     Slapi_Mods smods;
     char csnstr[CSN_STRSIZE + 1];
-    char buf[BUFSIZ];
+
     char *uniqueid = slapi_entry_attr_get_charptr(tombstoneentry, "nsuiqueid");
-    char *entrydn = slapi_entry_attr_get_charptr(tombstoneentry, "nscpentrydn");
-    char *parentuniqueid = slapi_entry_attr_get_charptr(tombstoneentry, SLAPI_ATTR_VALUE_PARENT_UNIQUEID); /* Allocated */
+    const char *entrydn = slapi_entry_attr_get_ref(tombstoneentry, "nscpentrydn");
     char *parentdn = slapi_dn_parent(slapi_sdn_get_ndn(conflictdn));
     const CSN *dncsn = entry_get_dncsn(tombstoneentry);
+    char *buf = slapi_ch_smprintf("%s (%s) %s", REASON_ANNOTATE_DN, "ADD", entrydn);
     csn_as_string(dncsn, PR_FALSE, csnstr);
 
     slapi_log_err(SLAPI_LOG_REPL, repl_plugin_name,
@@ -271,6 +269,7 @@ tombstone_to_conflict(
     slapi_sdn_set_normdn_byval(slapi_entry_get_sdn(tombstoneentry), slapi_sdn_get_ndn(conflictdn));
     /* not just e_sdn, e_rsdn needs to be updated. */
     slapi_rdn_set_all_dn(slapi_entry_get_srdn(tombstoneentry), slapi_sdn_get_ndn(conflictdn));
+    /* Warning: urp_fixup_add_entry consumes tombstoneentry (including entrydn) */
     op_result = urp_fixup_add_entry(tombstoneentry, NULL, NULL, opcsn, OP_FLAG_RESURECT_ENTRY | OP_FLAG_NOOP);
 
     if (op_result) {
@@ -284,8 +283,6 @@ tombstone_to_conflict(
     slapi_mods_add(&smods, LDAP_MOD_ADD, "objectclass", strlen("ldapsubentry"), "ldapsubentry");
     slapi_mods_add(&smods, LDAP_MOD_DELETE, "objectclass", strlen("glue"), "glue");
     slapi_mods_add(&smods, LDAP_MOD_REPLACE, "conflictcsn", strlen(csnstr), csnstr);
-    PR_snprintf(buf, sizeof(buf), "%s (%s) %s",
-                REASON_ANNOTATE_DN, "ADD", entrydn);
     slapi_mods_add(&smods, LDAP_MOD_ADD, ATTR_NSDS5_REPLCONFLICT, strlen(buf), buf);
     op_result = urp_fixup_modify_entry(uniqueid, conflictdn, opcsn, &smods, 0);
     slapi_mods_done(&smods);
@@ -293,16 +290,11 @@ tombstone_to_conflict(
         /* the objectclass was already present */
         op_result = LDAP_SUCCESS;
     }
-/* this will go to postop
-	if (op_result == LDAP_SUCCESS) {
-		op_result = tombstone_to_conflict_check_parent(sessionid, parentdn, uniqueid, parentuniqueid, opcsn, conflictdn);
-	}
-	*/
+
 done:
+    slapi_ch_free_string(&buf);
     slapi_ch_free_string(&uniqueid);
-    slapi_ch_free_string(&parentuniqueid);
     slapi_ch_free_string(&parentdn);
-    slapi_ch_free_string(&entrydn);
     return op_result;
 }
 
@@ -320,7 +312,7 @@ tombstone_to_glue(
     Slapi_DN **newparentdn)
 {
     Slapi_DN *parentdn;
-    char *parentuniqueid;
+    const char *parentuniqueid;
     const char *tombstoneuniqueid;
     Slapi_Entry *addingentry = NULL;
     Slapi_Entry *addingentry_bakup = NULL;
@@ -340,7 +332,7 @@ tombstone_to_glue(
      * which won't help us identify the correct backend to search.
      */
     is_suffix_dn_ext(pb, gluedn, &parentdn, 1 /* is_tombstone */);
-    parentuniqueid = slapi_entry_attr_get_charptr(tombstoneentry, SLAPI_ATTR_VALUE_PARENT_UNIQUEID); /* Allocated */
+    parentuniqueid = slapi_entry_attr_get_ref(tombstoneentry, SLAPI_ATTR_VALUE_PARENT_UNIQUEID);
     tombstone_to_glue_resolve_parent(pb, sessionid, parentdn, parentuniqueid, opcsn, newparentdn);
 
     /* Submit an Add operation to turn the tombstone entry into glue. */
@@ -407,7 +399,6 @@ tombstone_to_glue(
         }
     }
     slapi_entry_free(addingentry_bakup);
-    slapi_ch_free_string(&parentuniqueid);
     if (op_result == LDAP_SUCCESS) {
         slapi_log_err(/*slapi_log_urp*/ SLAPI_LOG_ERR, repl_plugin_name,
                       "tombstone_to_glue - %s - Resurrected tombstone %s to glue reason '%s'\n", sessionid, addingdn, reason);
