@@ -61,13 +61,13 @@ do_add(Slapi_PBlock *pb)
     int rc;
     PRBool searchsubentry = PR_TRUE;
     Connection *pb_conn = NULL;
+    int32_t log_format = config_get_accesslog_log_format();
 
     slapi_log_err(SLAPI_LOG_TRACE, "do_add", "==>\n");
 
     slapi_pblock_get(pb, SLAPI_CONNECTION, &pb_conn);
     slapi_pblock_get(pb, SLAPI_OPERATION, &operation);
 
-
     if (operation == NULL || pb_conn == NULL) {
         slapi_log_err(SLAPI_LOG_ERR, "do_add", "NULL param: pb_conn (0x%p) pb_op (0x%p)\n",
                       pb_conn, operation);
@@ -176,12 +176,23 @@ do_add(Slapi_PBlock *pb)
           to modify so not to break existing clients */
         if (op_shared_is_allowed_attr(normtype, pb_conn->c_isreplication_session)) {
             if ((rc = slapi_entry_add_values(e, normtype, vals)) != LDAP_SUCCESS) {
-                slapi_log_access(LDAP_DEBUG_STATS,
-                                 "conn=%" PRIu64 " op=%d ADD dn=\"%s\", add values for type %s failed\n",
-                                 pb_conn->c_connid, operation->o_opid,
-                                 slapi_entry_get_dn_const(e), normtype);
-                send_ldap_result(pb, rc, NULL, NULL, 0, NULL);
+                if (log_format != LOG_FORMAT_DEFAULT) {
+                    /* JSON logging */
+                    slapd_log_pblock logpb = {0};
+                    char msg[BUFSIZ] = {0};
 
+                    PR_snprintf(msg, sizeof(msg), "add values for type %s failed", normtype);
+                    slapd_log_pblock_init(&logpb, log_format, pb);
+                    logpb.target_dn = slapi_entry_get_dn_const(e);
+                    logpb.msg = msg;
+                    slapd_log_access_add(&logpb);
+                } else {
+                    slapi_log_access(LDAP_DEBUG_STATS,
+                                    "conn=%" PRIu64 " op=%d ADD dn=\"%s\", add values for type %s failed\n",
+                                    pb_conn->c_connid, operation->o_opid,
+                                    slapi_entry_get_dn_const(e), normtype);
+                }
+                send_ldap_result(pb, rc, NULL, NULL, 0, NULL);
                 slapi_ch_free((void **)&normtype);
                 ber_bvecfree(vals);
                 goto free_and_return;
@@ -500,6 +511,8 @@ op_shared_add(Slapi_PBlock *pb)
     Slapi_DN *sdn = NULL;
     passwdPolicy *pwpolicy;
     Connection *pb_conn = NULL;
+    int32_t log_format = config_get_accesslog_log_format();
+    time_t start_time = {0};
 
     slapi_pblock_get(pb, SLAPI_OPERATION, &operation);
     slapi_pblock_get(pb, SLAPI_CONNECTION, &pb_conn);
@@ -523,30 +536,52 @@ op_shared_add(Slapi_PBlock *pb)
     proxy_err = proxyauth_get_dn(pb, &proxydn, &errtext);
 
     if (operation_is_flag_set(operation, OP_FLAG_ACTION_LOG_ACCESS)) {
+        slapd_log_pblock logpb = {0};
+
         if (proxydn) {
             proxystr = slapi_ch_smprintf(" authzid=\"%s\"", proxydn);
         }
 
+        slapd_log_pblock_init(&logpb, log_format, pb);
+        logpb.target_dn = slapi_entry_get_dn_const(e);
+        logpb.request_controls = operation_get_req_controls(operation);
+        logpb.authzid = proxydn;
+
         if (!internal_op) {
-            slapi_log_access(LDAP_DEBUG_STATS, "conn=%" PRIu64 " op=%d ADD dn=\"%s\"%s\n",
-                             pb_conn ? pb_conn->c_connid : -1,
-                             operation->o_opid,
-                             slapi_entry_get_dn_const(e),
-                             proxystr ? proxystr : "");
+            if (log_format != LOG_FORMAT_DEFAULT) {
+                /* JSON logging */
+                slapd_log_access_add(&logpb);
+            } else {
+                slapi_log_access(LDAP_DEBUG_STATS, "conn=%" PRIu64 " op=%d ADD dn=\"%s\"%s\n",
+                                 pb_conn ? pb_conn->c_connid : operation->o_connid,
+                                 operation->o_opid,
+                                 slapi_entry_get_dn_const(e),
+                                 proxystr ? proxystr : "");
+            }
         } else {
             uint64_t connid;
             int32_t op_id;
             int32_t op_internal_id;
             int32_t op_nested_count;
-            get_internal_conn_op(&connid, &op_id, &op_internal_id, &op_nested_count);
-            slapi_log_access(LDAP_DEBUG_ARGS,
-                             connid==0 ? "conn=Internal(%" PRId64 ") op=%d(%d)(%d) ADD dn=\"%s\"\n" :
-                                         "conn=%" PRId64 " (Internal) op=%d(%d)(%d) ADD dn=\"%s\"\n",
-                             connid,
-                             op_id,
-                             op_internal_id,
-                             op_nested_count,
-                             slapi_entry_get_dn_const(e));
+            get_internal_conn_op(&connid, &op_id, &op_internal_id, &op_nested_count, &start_time);
+            if (log_format != LOG_FORMAT_DEFAULT) {
+                /* JSON logging */
+                logpb.conn_time = start_time;
+                logpb.conn_id = connid;
+                logpb.op_id = op_id;
+                logpb.op_internal_id = op_internal_id;
+                logpb.op_nested_count = op_nested_count;
+                slapd_log_access_add(&logpb);
+            } else {
+                slapi_log_access(LDAP_DEBUG_ARGS,
+                                 connid==0 ? "conn=Internal(%" PRId64 ") op=%d(%d)(%d) ADD dn=\"%s\"\n" :
+                                             "conn=%" PRId64 " (Internal) op=%d(%d)(%d) ADD dn=\"%s\"\n",
+                                 connid,
+                                 op_id,
+                                 op_internal_id,
+                                 op_nested_count,
+                                 slapi_entry_get_dn_const(e));
+            }
         }
     }
 
