@@ -98,6 +98,9 @@ write_audit_log_entry(Slapi_PBlock *pb)
     default:
         return; /* Unsupported operation type. */
     }
+    if (change == NULL) {
+        return; /* No operation. */
+    }
     curtime = slapi_current_utc_time();
     /* log the raw, unnormalized DN */
     dn = slapi_sdn_get_udn(sdn);
@@ -381,9 +384,10 @@ write_audit_file_json(Slapi_PBlock *pb, Slapi_Entry *entry, int logtype,
                       "(%ld) using format (%s), trying default format...\n",
                       curtime, time_format);
         /* Got an error, use default format and try again */
-        if (strftime(local_time, JBUFSIZE, SLAPD_INIT_AUDITLOG_TIME_FORMAT, &tms) == 0) {
+        if (strftime(local_time, JBUFSIZE, SLAPD_INIT_LOG_TIME_FORMAT, &tms) == 0) {
             slapi_log_err(SLAPI_LOG_ERR, "write_audit_file_json",
                       "Unable to format time (%ld)\n", curtime);
+            slapi_ch_free_string(&time_format);
             return;
         }
     }
