@@ -533,7 +533,11 @@ dbgec_test_if_entry_pointer_is_valid(void *e, void *prev, int slot, int line)
          */ 
         slapi_log_err(SLAPI_LOG_FATAL, "dbgec_test_if_entry_pointer_is_valid", "cache.c[%d]: Wrong entry address: %p Previous entry address is: %p hash table slot is %d\n", line, e, prev, slot);
         slapi_log_backtrace(SLAPI_LOG_FATAL);
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Warray-bounds="
+#pragma GCC diagnostic ignored "-Wstringop-overflow="
         *(char*)23 = 1;   /* abort() somehow corrupt gdb stack backtrace so lets generate a SIGSEGV */
+#pragma GCC diagnostic pop
         abort();
     }
 }
@@ -1752,7 +1756,7 @@ cache_is_reverted_entry(struct cache *cache, struct backentry *e)
     cache_lock(cache);
     if (find_hash(cache->c_idtable, &e->ep_id, sizeof(ID), (void **)&dummy_e)) {
         if (dummy_e->ep_state & ENTRY_STATE_INVALID) {
-            slapi_log_err(SLAPI_LOG_WARNING, "cache_is_reverted_entry", "Entry reverted = %d (0x%lX)  [entry: 0x%lX] refcnt=%d\n", 
+            slapi_log_err(SLAPI_LOG_WARNING, "cache_is_reverted_entry", "Entry reverted = %d (0x%lX)  [entry: %p] refcnt=%d\n",
                           dummy_e->ep_state,
                           pthread_self(),
                           dummy_e, dummy_e->ep_refcnt);
