@@ -512,6 +512,7 @@ ldbm_back_modify(Slapi_PBlock *pb)
     entry_address *addr;
     int is_fixup_operation = 0;
     int is_ruv = 0; /* True if the current entry is RUV */
+    int is_internal = 0;
     CSN *opcsn = NULL;
     int repl_op;
     int opreturn = 0;
@@ -522,6 +523,7 @@ ldbm_back_modify(Slapi_PBlock *pb)
     int ec_locked = 0;
     int result_sent = 0;
     int32_t parent_op = 0;
+    int32_t betxn_callback_fails = 0; /* if a BETXN fails we need to revert entry cache */
     struct timespec parent_time;
     Slapi_Mods *smods_add_rdn = NULL;
 
@@ -534,6 +536,7 @@ ldbm_back_modify(Slapi_PBlock *pb)
     slapi_pblock_get(pb, SLAPI_OPERATION, &operation);
 
     fixup_tombstone = operation_is_flag_set(operation, OP_FLAG_TOMBSTONE_FIXUP);
+    is_internal = operation_is_flag_set(operation, OP_FLAG_INTERNAL);
 
     dblayer_txn_init(li, &txn); /* must do this before first goto error_return */
     /* the calls to perform searches require the parent txn if any
@@ -817,6 +820,9 @@ ldbm_back_modify(Slapi_PBlock *pb)
                 slapi_pblock_set(pb, SLAPI_PLUGIN_OPRETURN, ldap_result_code ? &ldap_result_code : &retval);
             }
             slapi_pblock_get(pb, SLAPI_PB_RESULT_TEXT, &ldap_result_message);
+            if (retval) {
+                betxn_callback_fails = 1;
+            }
             goto error_return;
         }
 
@@ -1017,10 +1023,12 @@ ldbm_back_modify(Slapi_PBlock *pb)
             slapi_pblock_set(pb, SLAPI_PLUGIN_OPRETURN, ldap_result_code ? &ldap_result_code : &retval);
         }
         slapi_pblock_get(pb, SLAPI_PB_RESULT_TEXT, &ldap_result_message);
+        betxn_callback_fails = 1;
         goto error_return;
     }
     retval = plugin_call_mmr_plugin_postop(pb, NULL,SLAPI_PLUGIN_BE_TXN_POST_MODIFY_FN);
     if (retval) {
+        betxn_callback_fails = 1;
         ldbm_set_error(pb, retval, &ldap_result_code, &ldap_result_message);
         goto error_return;
     }
@@ -1083,8 +1091,12 @@ error_return:
                 if (!opreturn) {
                     slapi_pblock_set(pb, SLAPI_PLUGIN_OPRETURN, ldap_result_code ? &ldap_result_code : &retval);
                 }
+                betxn_callback_fails = 1;
             }
             retval = plugin_call_mmr_plugin_postop(pb, NULL,SLAPI_PLUGIN_BE_TXN_POST_MODIFY_FN);
+            if (retval) {
+                betxn_callback_fails = 1;
+            }
 
             /* It is safer not to abort when the transaction is not started. */
             /* Release SERIAL LOCK */
@@ -1096,7 +1108,7 @@ error_return:
             rc = SLAPI_FAIL_GENERAL;
         }
         /* Revert the caches if this is the parent operation */
-        if (parent_op) {
+        if (parent_op && betxn_callback_fails) {
             revert_cache(inst, &parent_time);
         }
     }
@@ -1155,6 +1167,18 @@ common_return:
         }
         if (!result_sent) {
             /* result is already sent in find_entry. */
+            int deferred;
+
+            if (!is_internal) {
+                slapi_pblock_get(pb, SLAPI_DEFERRED_MEMBEROF, &deferred);
+                if (deferred) {
+                    PRIntervalTime delay = PR_MillisecondsToInterval(100);
+                    while (deferred) {
+                        DS_Sleep(delay);
+                        slapi_pblock_get(pb, SLAPI_DEFERRED_MEMBEROF, &deferred);
+                    }
+                }
+            }
             slapi_send_ldap_result(pb, ldap_result_code, NULL, ldap_result_message, 0, NULL);
         }
     }
