@@ -251,7 +251,7 @@ op_shared_search(Slapi_PBlock *pb, int send_result)
     char *errtext = NULL;
     int nentries, pnentries;
     int flag_search_base_found = 0;
-    int flag_no_such_object = 0;
+    bool flag_no_such_object = false;
     int flag_referral = 0;
     int flag_psearch = 0;
     int err_code = LDAP_SUCCESS;
@@ -263,7 +263,6 @@ op_shared_search(Slapi_PBlock *pb, int send_result)
     int sent_result = 0;
     unsigned int pr_stat = 0;
     Connection *pb_conn;
-
     ber_int_t pagesize = -1;
     ber_int_t estimate = 0; /* estimated search result set size */
     int curr_search_count = 0;
@@ -273,6 +272,8 @@ op_shared_search(Slapi_PBlock *pb, int send_result)
     Slapi_DN *orig_sdn = NULL;
     int free_sdn = 0;
     pthread_mutex_t *pagedresults_mutex = NULL;
+    int32_t log_format = config_get_accesslog_log_format();
+    slapd_log_pblock logpb = {0};
 
     be_list[0] = NULL;
     referral_list[0] = NULL;
@@ -316,7 +317,7 @@ op_shared_search(Slapi_PBlock *pb, int send_result)
         rc = -1;
         goto free_and_return_nolock;
     }
-    
+
     /* Set the time we actually started the operation */
     slapi_operation_set_time_started(operation);
 
@@ -333,10 +334,12 @@ op_shared_search(Slapi_PBlock *pb, int send_result)
         int32_t op_id;
         int32_t op_internal_id;
         int32_t op_nested_count;
+        time_t start_time;
 
         PR_ASSERT(fstr);
-        if (internal_op) {
-            get_internal_conn_op(&connid, &op_id, &op_internal_id, &op_nested_count);
+
+        if (proxydn) {
+            proxystr = slapi_ch_smprintf(" authzid=\"%s\"", proxydn);
         }
 
         if (NULL == attrs) {
@@ -347,10 +350,6 @@ op_shared_search(Slapi_PBlock *pb, int send_result)
             attrliststr = attrlistbuf;
         }
 
-        if (proxydn) {
-            proxystr = slapi_ch_smprintf(" authzid=\"%s\"", proxydn);
-        }
-
 #define SLAPD_SEARCH_FMTSTR_CONN_OP "conn=%" PRIu64 " op=%d"
 #define SLAPD_SEARCH_FMTSTR_CONN_OP_INT_INT "conn=Internal(%" PRIu64 ") op=%d(%d)(%d)"
 #define SLAPD_SEARCH_FMTSTR_CONN_OP_EXT_INT "conn=%" PRIu64 " (Internal) op=%d(%d)(%d)"
@@ -371,6 +370,7 @@ op_shared_search(Slapi_PBlock *pb, int send_result)
         if (!internal_op) {
             strcpy(fmtstr, SLAPD_SEARCH_FMTSTR_CONN_OP);
         } else {
+            get_internal_conn_op(&connid, &op_id, &op_internal_id, &op_nested_count, &start_time);
             if (connid == 0) {
                 strcpy(fmtstr, SLAPD_SEARCH_FMTSTR_CONN_OP_INT_INT);
             } else {
@@ -382,24 +382,48 @@ op_shared_search(Slapi_PBlock *pb, int send_result)
         strcat(fmtstr, LOG_ACCESS_FORMAT_ATTR_BUFSIZ(attrliststr, "\" attrs=", SLAPD_SEARCH_BUFPART));
         strcat(fmtstr, SLAPD_SEARCH_FMTSTR_REMAINDER);
 
+        /* Prep log pblock */
+        slapd_log_pblock_init(&logpb, log_format, pb);
+        logpb.authzid = proxydn;
+        logpb.base_dn = normbase;
+        logpb.scope = scope;
+        logpb.filter = fstr;
+        logpb.attrs = attrs;
+        logpb.psearch = flag_psearch ? PR_TRUE : PR_FALSE;
+
         if (!internal_op) {
-            slapi_log_access(LDAP_DEBUG_STATS, fmtstr,
-                             pb_conn->c_connid,
-                             operation->o_opid,
-                             normbase,
-                             scope, fstr, attrliststr,
-                             flag_psearch ? " options=persistent" : "",
-                             proxystr ? proxystr : "");
+            if (log_format != LOG_FORMAT_DEFAULT) {
+                slapd_log_access_search(&logpb);
+            } else {
+                slapi_log_access(LDAP_DEBUG_STATS, fmtstr,
+                                 pb_conn->c_connid,
+                                 operation->o_opid,
+                                 normbase,
+                                 scope, fstr, attrliststr,
+                                 flag_psearch ? " options=persistent" : "",
+                                 proxystr ? proxystr : "");
+            }
+
         } else {
-            slapi_log_access(LDAP_DEBUG_ARGS, fmtstr,
-                             connid,
-                             op_id,
-                             op_internal_id,
-                             op_nested_count,
-                             normbase,
-                             scope, fstr, attrliststr,
-                             flag_psearch ? " options=persistent" : "",
-                             proxystr ? proxystr : "");
+            /* Internal op */
+            if (log_format != LOG_FORMAT_DEFAULT) {
+                logpb.conn_time = start_time;
+                logpb.conn_id = connid;
+                logpb.op_id = op_id;
+                logpb.op_internal_id = op_internal_id;
+                logpb.op_nested_count = op_nested_count;
+                slapd_log_access_search(&logpb);
+            } else {
+                slapi_log_access(LDAP_DEBUG_ARGS, fmtstr,
+                                 connid,
+                                 op_id,
+                                 op_internal_id,
+                                 op_nested_count,
+                                 normbase,
+                                 scope, fstr, attrliststr,
+                                 flag_psearch ? " options=persistent" : "",
+                                 proxystr ? proxystr : "");
+            }
         }
     }
 
@@ -852,7 +876,7 @@ op_shared_search(Slapi_PBlock *pb, int send_result)
                     /* may be the object exist somewhere else
                      * wait the end of the loop to send back this error
                      */
-                    flag_no_such_object = 1;
+                    flag_no_such_object = true;
                 } else {
                     /* err something other than LDAP_NO_SUCH_OBJECT, so the backend will
                      * have sent the result -
@@ -862,6 +886,7 @@ op_shared_search(Slapi_PBlock *pb, int send_result)
                 /* fall through */
 
             case -1: /* an error occurred */
+                slapi_pblock_get(pb, SLAPI_RESULT_CODE, &err);
                 /* PAGED RESULTS */
                 /* Explicit ctrlp test avoid gcc -fanalyzer warning */
                 if (op_is_pagedresults(operation)) {
@@ -870,32 +895,31 @@ op_shared_search(Slapi_PBlock *pb, int send_result)
 #pragma GCC diagnostic ignored "-Wanalyzer-null-argument"
                     /* cleanup the slot */
                     pthread_mutex_lock(pagedresults_mutex);
+                    if (err != LDAP_NO_SUCH_OBJECT && !flag_no_such_object) {
+                        /* Free the results if not "no_such_object" */
+                        void *sr = NULL;
+                        slapi_pblock_get(pb, SLAPI_SEARCH_RESULT_SET, &sr);
+                        be->be_search_results_release(&sr);
+                    }
                     pagedresults_set_search_result(pb_conn, operation, NULL, 1, pr_idx);
                     rc = pagedresults_set_current_be(pb_conn, NULL, pr_idx, 1);
                     pthread_mutex_unlock(pagedresults_mutex);
 #pragma GCC diagnostic pop
                 }
-                if (1 == flag_no_such_object) {
-                    break;
-                }
-                slapi_pblock_get(pb, SLAPI_RESULT_CODE, &err);
-                if (err == LDAP_NO_SUCH_OBJECT) {
-                    /* may be the object exist somewhere else
-                     * wait the end of the loop to send back this error
-                     */
-                    flag_no_such_object = 1;
+
+                if (err == LDAP_NO_SUCH_OBJECT || flag_no_such_object) {
+                    /* Maybe the object exists somewhere else, wait to the end
+                     * of the loop to send back this error */
+                    flag_no_such_object = true;
                     break;
                 } else {
-                    /* for error other than LDAP_NO_SUCH_OBJECT
-                     * the error has already been sent
-                     * stop the search here
-                     */
+                    /* For error other than LDAP_NO_SUCH_OBJECT the error has
+                     * already been sent stop the search here */
                     cache_return_target_entry(pb, be, operation);
                     goto free_and_return;
                 }
 
             /* when rc == SLAPI_FAIL_DISKFULL this case is executed */
-
             case SLAPI_FAIL_DISKFULL:
                 operation_out_of_disk_space();
                 cache_return_target_entry(pb, be, operation);
@@ -1598,21 +1622,34 @@ op_shared_log_error_access(Slapi_PBlock *pb, const char *type, const char *dn, c
     char *proxystr = NULL;
     Slapi_Operation *operation;
     Connection *pb_conn;
+    int32_t log_format = config_get_accesslog_log_format();
+    slapd_log_pblock logpb = {0};
 
     slapi_pblock_get(pb, SLAPI_OPERATION, &operation);
     slapi_pblock_get(pb, SLAPI_CONNECTION, &pb_conn);
 
-    if ((proxyauth_get_dn(pb, &proxydn, NULL) == LDAP_SUCCESS)) {
+    if ((proxyauth_get_dn(pb, &proxydn, NULL) == LDAP_SUCCESS &&
+        log_format == LOG_FORMAT_DEFAULT))
+    {
         proxystr = slapi_ch_smprintf(" authzid=\"%s\"", proxydn);
     }
 
-    slapi_log_access(LDAP_DEBUG_STATS, "conn=%" PRIu64 " op=%d %s dn=\"%s\"%s, %s\n",
-                     (pb_conn ? pb_conn->c_connid : 0),
-                     (operation ? operation->o_opid : 0),
-                     type,
-                     dn,
-                     proxystr ? proxystr : "",
-                     msg ? msg : "");
+    if (log_format != LOG_FORMAT_DEFAULT) {
+        slapd_log_pblock_init(&logpb, log_format, pb);
+        logpb.authzid = proxydn;
+        logpb.target_dn = dn;
+        logpb.msg = msg;
+        logpb.op_type = type;
+        slapd_log_access_error(&logpb);
+    } else {
+        slapi_log_access(LDAP_DEBUG_STATS, "conn=%" PRIu64 " op=%d %s dn=\"%s\"%s, %s\n",
+                         pb_conn ? pb_conn->c_connid : 0,
+                         operation ? operation->o_opid : 0,
+                         type,
+                         dn,
+                         proxystr ? proxystr : "",
+                         msg ? msg : "");
+    }
 
     slapi_ch_free_string(&proxydn);
     slapi_ch_free_string(&proxystr);
