@@ -1,6 +1,6 @@
 /** BEGIN COPYRIGHT BLOCK
  * Copyright (C) 2001 Sun Microsystems, Inc. Used by permission.
- * Copyright (C) 2021 Red Hat, Inc.
+ * Copyright (C) 2021-2024 Red Hat, Inc.
  * All rights reserved.
  *
  * License: GPL (version 3 or any later version).
@@ -14,6 +14,7 @@
 #ifndef _PROTO_SLAP
 #define _PROTO_SLAP
 
+
 /*
  * Forward structure declarations
  */
@@ -386,6 +387,7 @@ int config_set_validate_cert_switch(const char *attrname, char *value, char *err
 int config_set_accesslogbuffering(const char *attrname, char *value, char *errorbuf, int apply);
 int config_set_auditlogbuffering(const char *attrname, char *value, char *errorbuf, int apply);
 int config_set_securitylogbuffering(const char *attrname, char *value, char *errorbuf, int apply);
+int config_set_errorlogbuffering(const char *attrname, char *value, char *errorbuf, int apply);
 int config_set_csnlogging(const char *attrname, char *value, char *errorbuf, int apply);
 int config_set_force_sasl_external(const char *attrname, char *value, char *errorbuf, int apply);
 int config_set_entryusn_global(const char *attrname, char *value, char *errorbuf, int apply);
@@ -401,6 +403,8 @@ int config_set_auditlog_log_format(const char *attrname, char *value, char *erro
 int config_set_auditlog_time_format(const char *attrname, char *value, char *errorbuf, int apply);
 int config_set_auditfaillog_unhashed_pw(const char *attrname, char *value, char *errorbuf, int apply);
 int32_t config_set_auditlog_display_attrs(const char *attrname, char *value, char *errorbuf, int apply);
+int config_set_accesslog_log_format(const char *attrname, char *value, char *errorbuf, int apply);
+int config_set_accesslog_time_format(const char *attrname, char *value, char *errorbuf, int apply);
 int config_set_external_libs_debug_enabled(const char *attrname, char *value, char *errorbuf, int apply);
 int config_set_ndn_cache_enabled(const char *attrname, char *value, char *errorbuf, int apply);
 int config_set_ndn_cache_max_size(const char *attrname, char *value, char *errorbuf, int apply);
@@ -423,12 +427,6 @@ int config_set_maxsimplepaged_per_conn(const char *attrname, char *value, char *
 int log_external_libs_debug_set_log_fn(void);
 int log_set_backend(const char *attrname, char *value, int logtype, char *errorbuf, int apply);
 
-#ifdef HAVE_CLOCK_GETTIME
-int config_set_logging_hr_timestamps(const char *attrname, char *value, char *errorbuf, int apply);
-void log_enable_hr_timestamps(void);
-void log_disable_hr_timestamps(void);
-#endif
-
 int config_get_SSLclientAuth(void);
 int config_get_ssl_check_hostname(void);
 tls_check_crl_t config_get_tls_check_crl(void);
@@ -529,6 +527,8 @@ int config_get_auditfaillog_logging_enabled(void);
 char *config_get_auditlog_display_attrs(void);
 int config_get_auditlog_log_format(void);
 char *config_get_auditlog_time_format(void);
+int config_get_accesslog_log_format(void);
+char *config_get_accesslog_time_format(void);
 char *config_get_referral_mode(void);
 int config_get_num_listeners(void);
 int config_check_referral_mode(void);
@@ -630,6 +630,7 @@ int config_get_extract_pem(void);
 
 int32_t config_get_enable_upgrade_hash(void);
 int32_t config_set_enable_upgrade_hash(const char *attrname, char *value, char *errorbuf, int apply);
+int32_t config_set_scheme_list_no_upgrade_hash(const char *attrname, char *value, char *errorbuf, int apply);
 
 
 int32_t config_get_enable_ldapssotoken(void);
@@ -673,6 +674,7 @@ int get_ldapmessage_controls(Slapi_PBlock *pb, BerElement *ber, LDAPControl ***c
 int get_ldapmessage_controls_ext(Slapi_PBlock *pb, BerElement *ber, LDAPControl ***controls, int ignore_criticality);
 int write_controls(BerElement *ber, LDAPControl **ctrls);
 void add_control(LDAPControl ***ctrlsp, LDAPControl *newctrl);
+void slapi_parse_control(LDAPControl *ctrl, char **oid, char **value, PRBool *isCritical);
 
 /*
  * daemon.c
@@ -904,11 +906,11 @@ int check_log_max_size(
     char *returntext,
     int logtype);
 
-
 void g_set_accesslog_level(int val);
 void g_set_statlog_level(int val);
 void g_set_securitylog_level(int val);
 void log__delete_rotated_logs(void);
+void slapd_log_pblock_init(slapd_log_pblock *logpb, int32_t log_format, Slapi_PBlock *pb);
 
 /*
  * util.c
@@ -972,7 +974,8 @@ void operation_set_target_spec_str(Slapi_Operation *op, const char *target_spec)
 unsigned long operation_get_abandoned_op(const Slapi_Operation *op);
 void operation_set_abandoned_op(Slapi_Operation *op, unsigned long abndoned_op);
 void operation_set_type(Slapi_Operation *op, unsigned long type);
-
+LDAPControl **operation_get_req_controls(const Operation *o);
+LDAPControl **operation_get_result_controls(const Operation *o);
 
 /*
  * plugin.c
@@ -1164,6 +1167,7 @@ void do_search(Slapi_PBlock *pb);
 char *check_private_certdir(void);
 int slapd_nss_init(int init_ssl, int config_available);
 int slapd_ssl_init(void);
+void slapd_ssl_destroy(void);
 int slapd_ssl_init2(PRFileDesc **fd, int startTLS);
 int slapd_security_library_is_initialized(void);
 int slapd_ssl_listener_is_initialized(void);
@@ -1376,11 +1380,11 @@ void g_set_global_mrl(struct matchingRuleList *newglobalmrl);
 /*
  * generation.c
  */
+void free_server_dataversion(void);
 
 /*
  * factory.c
  */
-
 int factory_register_type(const char *name, size_t offset);
 void *factory_create_extension(int type, void *object, void *parent);
 void factory_destroy_extension(int type, void *object, void *parent, void **extension);
@@ -1545,6 +1549,7 @@ int connection_is_free(Connection *conn, int user_lock);
 int connection_is_active_nolock(Connection *conn);
 ber_slen_t openldap_read_function(Sockbuf_IO_Desc *sbiod, void *buf, ber_len_t len);
 int32_t connection_has_psearch(Connection *c);
+void free_worker_thread_indexes(void);
 
 /*
  * saslbind.c
