@@ -11,30 +11,33 @@ import { ManageBackupsModal, SchemaReloadModal, CreateInstanceModal } from "./ds
 import { LDAPEditor } from "./LDAPEditor.jsx";
 import { log_cmd } from "./lib/tools.jsx";
 import {
-    Alert,
-    AlertGroup,
-    AlertActionCloseButton,
-    AlertVariant,
-    Button,
-    Dropdown,
-    DropdownToggle,
-    DropdownItem,
-    DropdownPosition,
-    DropdownSeparator,
-    Grid, GridItem,
-    FormSelect,
-    FormSelectOption,
-    PageSectionVariants,
-    Progress,
-    ProgressMeasureLocation,
-    Spinner,
-    Tab,
-    Tabs,
-    TabTitleText,
-    Text,
-    TextContent,
-    TextVariants
-} from "@patternfly/react-core";
+	Alert,
+	AlertGroup,
+	AlertActionCloseButton,
+	AlertVariant,
+	Button,
+	Grid,
+	GridItem,
+	FormSelect,
+	FormSelectOption,
+	PageSectionVariants,
+	Progress,
+	ProgressMeasureLocation,
+	Spinner,
+	Tab,
+	Tabs,
+	TabTitleText,
+	Text,
+	TextContent,
+	TextVariants
+} from '@patternfly/react-core';
+import {
+	Dropdown,
+	DropdownToggle,
+	DropdownItem,
+	DropdownPosition,
+	DropdownSeparator
+} from '@patternfly/react-core/deprecated';
 import { CaretDownIcon } from '@patternfly/react-icons/dist/esm/icons/caret-down-icon';
 
 const _ = cockpit.gettext;
@@ -43,7 +46,8 @@ const staticStates = {
     noPackage: (
         <TextContent>
             <Text className="ds-margin-top-xlg" component={TextVariants.h2}>
-                {_("There is no <b>389-ds-base</b> package installed on this system. Sorry there is nothing to manage...")}
+                {_("There is no ")}<b>{_("389-ds-base")}</b>
+                {_(" package installed on this system. Sorry there is nothing to manage...")}
             </Text>
         </TextContent>
     ),
@@ -57,7 +61,9 @@ const staticStates = {
     notRunning: (
         <TextContent>
             <Text className="ds-margin-top-xlg ds-indent-md" component={TextVariants.h2}>
-                {_("This server instance is not running, either start it from the <b>Actions</b> dropdown menu, or choose a different instance")}
+                {_("This server instance is not running, either start it from the ")}
+                <b>{_("Actions")}</b>
+                {_(" dropdown menu, or choose a different instance")}
             </Text>
         </TextContent>
     ),
@@ -109,7 +115,7 @@ export class DSInstance extends React.Component {
         };
 
         // Dropdown tasks
-        this.handleToggle = dropdownIsOpen => {
+        this.handleToggle = (_event, dropdownIsOpen) => {
             this.setState({
                 dropdownIsOpen
             });
@@ -445,33 +451,45 @@ export class DSInstance extends React.Component {
     loadBackups() {
         let cmd = ["dsctl", "-j", this.state.serverId, "backups"];
         log_cmd("loadBackups", "Load Backups", cmd);
-        cockpit.spawn(cmd, { superuser: true, err: "message" }).done(content => {
-            this.updateProgress(25);
-            const config = JSON.parse(content);
-            const rows = [];
-            for (const row of config.items) {
-                rows.push([row[0], row[1], row[2]]);
-            }
-            // Get the server version from the monitor
-            cmd = ["dsconf", "-j", "ldapi://%2fvar%2frun%2fslapd-" + this.state.serverId + ".socket", "monitor", "server"];
-            log_cmd("loadBackups", "Get the server version", cmd);
-            cockpit
-                    .spawn(cmd, { superuser: true, err: "message" }).done(content => {
-                        const monitor = JSON.parse(content);
-                        this.setState({
-                            backupRows: rows,
-                            version: monitor.attrs.version[0],
-                        });
-                    })
-                    .fail(_ => {
-                        this.setState({
-                            backupRows: rows,
-                        });
+        cockpit.spawn(cmd, { superuser: true, err: "message" })
+                .done(content => {
+                    this.updateProgress(25);
+                    const config = JSON.parse(content);
+                    const rows = [];
+                    for (const row of config.items) {
+                        rows.push([row[0], row[1], row[2]]);
+                    }
+                    // Get the server version from the monitor
+                    cmd = ["dsconf", "-j", "ldapi://%2fvar%2frun%2fslapd-" + this.state.serverId + ".socket", "monitor", "server"];
+                    log_cmd("loadBackups", "Get the server version", cmd);
+                    cockpit
+                            .spawn(cmd, { superuser: true, err: "message" }).done(content => {
+                                const monitor = JSON.parse(content);
+                                this.setState({
+                                    backupRows: rows,
+                                    version: monitor.attrs.version[0],
+                                });
+                            })
+                            .fail(_ => {
+                                this.setState({
+                                    backupRows: rows,
+                                });
+                            });
+                })
+                .fail(err => {
+                    this.updateProgress(25);
+                    const errMsg = JSON.parse(err);
+                    this.addNotification(
+                        "error",
+                        cockpit.format(_("Load Backups operation failed - $0"), errMsg.desc)
+                    );
+                    this.setState({
+                        backupRows: [],
                     });
-        });
+                });
     }
 
-    handleServerIdChange(e) {
+    handleServerIdChange(_event, e) {
         this.setState({
             pageLoadingState: { state: "loading", jsx: "" },
             progressValue: 25
@@ -679,7 +697,12 @@ export class DSInstance extends React.Component {
                             <span className="spinner spinner-lg spinner-inline" />
                         </p>
                         <div className="ds-margin-top-lg">
-                            <Progress value={progressValue} label={`${progressValue}%`} measureLocation={ProgressMeasureLocation.inside} />
+                            <Progress 
+                                value={progressValue} 
+                                label={`${progressValue}%`} 
+                                measureLocation={ProgressMeasureLocation.inside}
+                                aria-label="Directory Server Configuration loading progress"
+                            />
                         </div>
                     </div>
                 </div>
@@ -752,7 +775,12 @@ export class DSInstance extends React.Component {
                             position={DropdownPosition.right}
                             onSelect={this.handleDropdown}
                             toggle={
-                                <DropdownToggle onToggle={this.handleToggle} toggleIndicator={CaretDownIcon} isPrimary id="ds-dropdown">
+                                <DropdownToggle 
+                                    onToggle={(event, isOpen) => this.handleToggle(event, isOpen)} 
+                                    toggleIndicator={CaretDownIcon}
+                                    variant="primary"
+                                    id="ds-dropdown"
+                                >
                                     {_("Actions")}
                                 </DropdownToggle>
                             }
