@@ -4,23 +4,25 @@ import { DoubleConfirmModal } from "../notifications.jsx";
 import { IndexTable } from "./databaseTables.jsx";
 import { log_cmd } from "../tools.jsx";
 import {
-    Button,
-    Checkbox,
-    Form,
-    Grid,
-    GridItem,
-    Modal,
-    ModalVariant,
-    Select,
-    SelectVariant,
-    SelectOption,
-    Tab,
-    Tabs,
-    TabTitleText,
-    Text,
-    TextContent,
-    TextVariants,
-} from "@patternfly/react-core";
+	Button,
+	Checkbox,
+	Form,
+	Grid,
+	GridItem,
+	Modal,
+	ModalVariant,
+	Tab,
+	Tabs,
+	TabTitleText,
+	Text,
+	TextContent,
+	TextVariants
+} from '@patternfly/react-core';
+import {
+	Select,
+	SelectVariant,
+	SelectOption
+} from '@patternfly/react-core/deprecated';
 import PropTypes from "prop-types";
 
 const _ = cockpit.gettext;
@@ -88,7 +90,7 @@ export class SuffixIndexes extends React.Component {
                 );
             }
         };
-        this.handleAttributeToggle = isAttributeOpen => {
+        this.handleAttributeToggle = (_event, isAttributeOpen) => {
             this.setState({
                 isAttributeOpen
             });
@@ -100,7 +102,7 @@ export class SuffixIndexes extends React.Component {
             });
         };
 
-        this.handleMatchingruleAddToggle = isMatchingruleOpen => {
+        this.handleMatchingruleAddToggle = (_event, isMatchingruleOpen) => {
             this.setState({
                 isMatchingruleOpen
             });
@@ -112,7 +114,7 @@ export class SuffixIndexes extends React.Component {
             });
         };
 
-        this.handleMatchingruleEditToggle = isMatchingruleOpen => {
+        this.handleMatchingruleEditToggle = (_event, isMatchingruleOpen) => {
             this.setState({
                 isMatchingruleOpen
             });
@@ -628,7 +630,7 @@ export class SuffixIndexes extends React.Component {
                 });
     }
 
-    onSelectToggle = (isExpanded, toggleId) => {
+    onSelectToggle = (_event, isExpanded, toggleId) => {
         this.setState({
             [toggleId]: isExpanded
         });
@@ -867,10 +869,10 @@ class AddIndexModal extends React.Component {
                                 <Checkbox
                                     id="indexTypeEq"
                                     isChecked={this.props.indexTypeEq}
-                                    onChange={(checked, e) => {
+                                    onChange={(e, checked) => {
                                         handleChange(e);
                                     }}
-                                    label={_("Equailty Indexing")}
+                                    label={_("Equality Indexing")}
                                 />
                             </GridItem>
                         </Grid>
@@ -879,7 +881,7 @@ class AddIndexModal extends React.Component {
                                 <Checkbox
                                     id="indexTypePres"
                                     isChecked={this.props.indexTypePres}
-                                    onChange={(checked, e) => {
+                                    onChange={(e, checked) => {
                                         handleChange(e);
                                     }}
                                     label={_("Presence Indexing")}
@@ -891,7 +893,7 @@ class AddIndexModal extends React.Component {
                                 <Checkbox
                                     id="indexTypeSub"
                                     isChecked={this.props.indexTypeSub}
-                                    onChange={(checked, e) => {
+                                    onChange={(e, checked) => {
                                         handleChange(e);
                                     }}
                                     label={_("Substring Indexing")}
@@ -903,7 +905,7 @@ class AddIndexModal extends React.Component {
                                 <Checkbox
                                     id="indexTypeApprox"
                                     isChecked={this.props.indexTypeApprox}
-                                    onChange={(checked, e) => {
+                                    onChange={(e, checked) => {
                                         handleChange(e);
                                     }}
                                     label={_("Approximate Indexing")}
@@ -947,7 +949,7 @@ class AddIndexModal extends React.Component {
                             <Checkbox
                                 id="reindexOnAdd"
                                 isChecked={this.props.reindexOnAdd}
-                                onChange={(checked, e) => {
+                                onChange={(e, checked) => {
                                     handleChange(e);
                                 }}
                                 label={_("Index attribute after creation")}
@@ -1008,10 +1010,10 @@ class EditIndexModal extends React.Component {
                 <Checkbox
                 id="indexTypeEq"
                 isChecked={this.props.indexTypeEq}
-                onChange={(checked, e) => {
+                onChange={(e, checked) => {
                     handleChange(e);
                 }}
-                label={_("Equailty Indexing")}
+                label={_("Equality Indexing")}
                 />
             </div>
         );
@@ -1020,7 +1022,7 @@ class EditIndexModal extends React.Component {
                 <Checkbox
                 id="indexTypePres"
                 isChecked={this.props.indexTypePres}
-                onChange={(checked, e) => {
+                onChange={(e, checked) => {
                     handleChange(e);
                 }}
                 label={_("Presence Indexing")}
@@ -1032,7 +1034,7 @@ class EditIndexModal extends React.Component {
                 <Checkbox
                 id="indexTypeSub"
                 isChecked={this.props.indexTypeSub}
-                onChange={(checked, e) => {
+                onChange={(e, checked) => {
                     handleChange(e);
                 }}
                 label={_("Substring Indexing")}
@@ -1044,7 +1046,7 @@ class EditIndexModal extends React.Component {
                 <Checkbox
                 id="indexTypeApprox"
                 isChecked={this.props.indexTypeApprox}
-                onChange={(checked, e) => {
+                onChange={(e, checked) => {
                     handleChange(e);
                 }}
                 label={_("Approximate Indexing")}
@@ -1058,7 +1060,7 @@ class EditIndexModal extends React.Component {
                     <Checkbox
                     id="indexTypeEq"
                     isChecked={this.props.indexTypeEq}
-                    onChange={(checked, e) => {
+                    onChange={(e, checked) => {
                         handleChange(e);
                     }}
                     label={_("Equality Indexing")}
@@ -1072,7 +1074,7 @@ class EditIndexModal extends React.Component {
                     <Checkbox
                     id="indexTypePres"
                     isChecked={this.props.indexTypePres}
-                    onChange={(checked, e) => {
+                    onChange={(e, checked) => {
                         handleChange(e);
                     }}
                     label={_("Presence Indexing")}
@@ -1086,7 +1088,7 @@ class EditIndexModal extends React.Component {
                     <Checkbox
                     id="indexTypeSub"
                     isChecked={this.props.indexTypeSub}
-                    onChange={(checked, e) => {
+                    onChange={(e, checked) => {
                         handleChange(e);
                     }}
                     label={_("Substring Indexing")}
@@ -1100,7 +1102,7 @@ class EditIndexModal extends React.Component {
                     <Checkbox
                     id="indexTypeApprox"
                     isChecked={this.props.indexTypeApprox}
-                    onChange={(checked, e) => {
+                    onChange={(e, checked) => {
                         handleChange(e);
                     }}
                     label={_("Approximate Indexing")}
@@ -1198,7 +1200,7 @@ class EditIndexModal extends React.Component {
                             <Checkbox
                                 id="reindexOnAdd"
                                 isChecked={this.props.reindexOnAdd}
-                                onChange={(checked, e) => {
+                                onChange={(e, checked) => {
                                     handleChange(e);
                                 }}
                                 label={_("Reindex Attribute After Saving")}
