@@ -1,16 +1,18 @@
 import cockpit from "cockpit";
 import React from 'react';
 import {
-    Alert,
-    Card,
-    CardBody,
-    CardTitle,
-    ClipboardCopy,
-    ClipboardCopyVariant,
-    Spinner,
-    Switch,
-    Wizard
+	Alert,
+	Card,
+	CardBody,
+	CardTitle,
+	ClipboardCopy,
+	ClipboardCopyVariant,
+	Spinner,
+	Switch
 } from '@patternfly/react-core';
+import {
+	Wizard
+} from '@patternfly/react-core/deprecated';
 import {
     headerCol,
 } from '@patternfly/react-table';
@@ -94,7 +96,7 @@ class DeleteOperationWizard extends React.Component {
             }
         };
 
-        this.handleChangeAck = isAckChecked => {
+        this.handleChangeAck = (_event, isAckChecked) => {
             this.setState({ isAckChecked });
         };
         // End constructor().
@@ -223,7 +225,7 @@ class DeleteOperationWizard extends React.Component {
                                 label={_("Yes, I'm sure.")}
                                 labelOff={_("No, don't delete.")}
                                 isChecked={isAckChecked}
-                                onChange={this.handleChangeAck}
+                                onChange={(event, isChecked) => this.handleChangeAck(event, isChecked)}
                             />
                         </CardBody>
                     </Card>
