@@ -273,7 +273,7 @@ class ConflictCompareModal extends React.Component {
                             </p>
                         </GridItem>
                         <GridItem span={12}>
-                            <TextArea id="conflictValid" resizeOrientation="vertical" className="ds-conflict" value={valid} isReadOnly />
+                            <TextArea id="conflictValid" resizeOrientation="vertical" className="ds-conflict" value={valid}  readOnlyVariant="default" />
                         </GridItem>
                         <GridItem className="ds-margin-top-lg" span={6}>
                             <TextContent>
@@ -288,7 +288,7 @@ class ConflictCompareModal extends React.Component {
                             </p>
                         </GridItem>
                         <GridItem span={12}>
-                            <TextArea id="conflictConflict" resizeOrientation="vertical" className="ds-conflict" value={conflict} isReadOnly />
+                            <TextArea id="conflictConflict" resizeOrientation="vertical" className="ds-conflict" value={conflict}  readOnlyVariant="default" />
                         </GridItem>
                         <hr />
                         <div className="ds-container">
@@ -432,7 +432,7 @@ class ReportCredentialsModal extends React.Component {
                                         id="credsHostname"
                                         aria-describedby="cachememsize"
                                         name="credsHostname"
-                                        onChange={(str, e) => {
+                                        onChange={(e, str) => {
                                             handleFieldChange(e);
                                         }}
                                     />
@@ -469,7 +469,7 @@ class ReportCredentialsModal extends React.Component {
                                         id="credsBinddn"
                                         aria-describedby="cachememsize"
                                         name="credsBinddn"
-                                        onChange={(str, e) => {
+                                        onChange={(e, str) => {
                                             handleFieldChange(e);
                                         }}
                                     />
@@ -487,7 +487,7 @@ class ReportCredentialsModal extends React.Component {
                                         aria-describedby="cachememsize"
                                         name="credsBindpw"
                                         isDisabled={pwInputInterractive}
-                                        onChange={(str, e) => {
+                                        onChange={(e, str) => {
                                             handleFieldChange(e);
                                         }}
                                     />
@@ -501,7 +501,7 @@ class ReportCredentialsModal extends React.Component {
                                     <Checkbox
                                         isChecked={pwInputInterractive}
                                         id="pwInputInterractive"
-                                        onChange={(checked, e) => {
+                                        onChange={(e, checked) => {
                                             handleFieldChange(e);
                                         }}
                                     />
@@ -570,7 +570,7 @@ class ReportConnectionModal extends React.Component {
                                         id="connName"
                                         aria-describedby="connName"
                                         name="connName"
-                                        onChange={(str, e) => {
+                                        onChange={(e, str) => {
                                             handleFieldChange(e);
                                         }}
                                     />
@@ -587,7 +587,7 @@ class ReportConnectionModal extends React.Component {
                                         id="connHostname"
                                         aria-describedby="connHostname"
                                         name="connHostname"
-                                        onChange={(str, e) => {
+                                        onChange={(e, str) => {
                                             handleFieldChange(e);
                                         }}
                                     />
@@ -624,13 +624,13 @@ class ReportConnectionModal extends React.Component {
                                         id="connBindDN"
                                         aria-describedby="connBindDN"
                                         name="connBindDN"
-                                        onChange={(str, e) => {
+                                        onChange={(e, str) => {
                                             handleFieldChange(e);
                                         }}
                                     />
                                 </GridItem>
                             </Grid>
-                            <Grid title={_("Bind password for the specified instance.  You can also speciy a password file but the filename needs to be inside of brackets [/PATH/FILE]")}>
+                            <Grid title={_("Bind password for the specified instance.  You can also specify a password file but the filename needs to be inside of brackets [/PATH/FILE]")}>
                                 <GridItem className="ds-label" span={3}>
                                     {_("Password")}
                                 </GridItem>
@@ -642,7 +642,7 @@ class ReportConnectionModal extends React.Component {
                                         aria-describedby="connCred"
                                         name="connCred"
                                         isDisabled={pwInputInterractive}
-                                        onChange={(str, e) => {
+                                        onChange={(e, str) => {
                                             handleFieldChange(e);
                                         }}
                                     />
@@ -656,7 +656,7 @@ class ReportConnectionModal extends React.Component {
                                     <Checkbox
                                         isChecked={pwInputInterractive}
                                         id="pwInputInterractive"
-                                        onChange={(checked, e) => {
+                                        onChange={(e, checked) => {
                                             handleFieldChange(e);
                                         }}
                                     />
@@ -724,7 +724,7 @@ class ReportAliasesModal extends React.Component {
                                         id="aliasName"
                                         aria-describedby="aliasName"
                                         name="aliasName"
-                                        onChange={(str, e) => {
+                                        onChange={(e, str) => {
                                             handleFieldChange(e);
                                         }}
                                     />
@@ -741,7 +741,7 @@ class ReportAliasesModal extends React.Component {
                                         id="aliasHostname"
                                         aria-describedby="aliasHostname"
                                         name="aliasHostname"
-                                        onChange={(str, e) => {
+                                        onChange={(e, str) => {
                                             handleFieldChange(e);
                                         }}
                                     />
@@ -834,7 +834,7 @@ class ReportLoginModal extends React.Component {
                                 aria-describedby="loginBinddn"
                                 name="loginBinddn"
                                 isDisabled={disableBinddn}
-                                onChange={(str, e) => {
+                                onChange={(e, str) => {
                                     handleChange(e);
                                 }}
                             />
@@ -851,7 +851,7 @@ class ReportLoginModal extends React.Component {
                                 id="loginBindpw"
                                 aria-describedby="loginBindpw"
                                 name="loginBindpw"
-                                onChange={(str, e) => {
+                                onChange={(e, str) => {
                                     handleChange(e);
                                 }}
                             />
@@ -926,7 +926,7 @@ class FullReportContent extends React.Component {
                                     title={_("Display all agreements including the disabled ones and the ones we failed to connect to")}
                                     isChecked={this.state.showDisabledAgreements}
                                     id="showDisabledAgreements"
-                                    onChange={(checked, e) => {
+                                    onChange={(e, checked) => {
                                         this.handleSwitchChange(e);
                                     }}
                                     label={_("Show Disabled Agreements")}
@@ -945,7 +945,7 @@ class FullReportContent extends React.Component {
                             <GridItem span={12}>
                                 <Checkbox
                                     isChecked={this.state.oneTableReport}
-                                    onChange={(checked, e) => {
+                                    onChange={(e, checked) => {
                                         this.handleSwitchChange(e);
                                     }}
                                     id="oneTableReport"
