@@ -31,8 +31,7 @@ import {
     SortByDirection,
 } from '@patternfly/react-table';
 import { TrashAltIcon } from '@patternfly/react-icons/dist/js/icons/trash-alt-icon';
-import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
-import { faSyncAlt } from '@fortawesome/free-solid-svg-icons';
+import { SyncAltIcon } from "@patternfly/react-icons";
 import { DoubleConfirmModal } from "../notifications.jsx";
 
 const _ = cockpit.gettext;
@@ -106,7 +105,7 @@ export class ReplMonitor extends React.Component {
             aliasSortBy: {},
         };
 
-        this.handleToggle = (isExpanded) => {
+        this.handleToggle = (_event, isExpanded) => {
             this.setState({
                 isExpanded
             });
@@ -1381,7 +1380,7 @@ export class ReplMonitor extends React.Component {
                     <Tab eventKey={1} id="prepare-new-report" title={<TabTitleText>{_("Prepare New Report")}</TabTitleText>}>
                         <ExpandableSection
                             toggleText={this.state.isExpanded ? _("Hide Help") : _("Show Help")}
-                            onToggle={this.handleToggle}
+                            onToggle={(event, isExpanded) => this.handleToggle(event, isExpanded)}
                             isExpanded={this.state.isExpanded}
                             className="ds-margin-top-lg ds-left-margin"
                         >
@@ -1504,7 +1503,7 @@ export class ReplMonitor extends React.Component {
         }
 
         let overwriteWarning = (
-            _("Only one monitor configuraton can be saved in the server's '~/.dsrc' file.  There is already an existing monitor configuration, and if you proceed it will be completely overwritten with the new configuraton."));
+            _("Only one monitor configuration can be saved in the server's '~/.dsrc' file.  There is already an existing monitor configuration, and if you proceed it will be completely overwritten with the new configuration."));
         if (this.state.credRows.length === 0 && this.state.aliasRows.length === 0) {
             overwriteWarning = (
                 _("This will save the current credentials and aliases to the server's '~/.dsrc' file so it can be reused in the future."));
@@ -1516,13 +1515,13 @@ export class ReplMonitor extends React.Component {
                     <TextContent>
                         <Text component={TextVariants.h3}>
                             {_("Synchronization Report")}
-                            <FontAwesomeIcon
-                                size="lg"
-                                className="ds-left-margin ds-refresh"
-                                icon={faSyncAlt}
-                                title={_("Refresh replication monitor")}
+                            <Button 
+                                variant="plain"
+                                aria-label={_("Refresh replication monitor")}
                                 onClick={this.props.handleReload}
-                            />
+                            >
+                                <SyncAltIcon />
+                            </Button>
                         </Text>
                     </TextContent>
                 </div>
