@@ -1,31 +1,36 @@
 import cockpit from "cockpit";
 import React from "react";
 import {
-    Button,
-    Checkbox,
-    Form,
-    FormHelperText,
-    Grid,
-    GridItem,
-    Modal,
-    ModalVariant,
-    Select,
-    SelectVariant,
-    SelectOption,
-    TextInput,
-    ValidatedOptions,
-} from "@patternfly/react-core";
+	Button,
+	Checkbox,
+	Form,
+	FormHelperText,
+	Grid,
+	GridItem,
+	Modal,
+	ModalVariant,
+	TextInput,
+	ValidatedOptions
+} from '@patternfly/react-core';
+import {
+	Select,
+	SelectVariant,
+	SelectOption
+} from '@patternfly/react-core/deprecated';
 import PropTypes from "prop-types";
 import PluginBasicConfig from "./pluginBasicConfig.jsx";
 import { log_cmd, valid_dn } from "../tools.jsx";
-import { DoubleConfirmModal } from "../notifications.jsx";
+import {
+    DoubleConfirmModal,
+    WarningModal
+} from "../notifications.jsx";
 
 const _ = cockpit.gettext;
 
 // Use default account policy name
 
 class AccountPolicy extends React.Component {
-    componentDidMount() {
+    componentDidMount(prevProps) {
         this.updateFields();
     }
 
@@ -48,6 +53,8 @@ class AccountPolicy extends React.Component {
         this.handleAddConfig = this.handleAddConfig.bind(this);
         this.handleEditConfig = this.handleEditConfig.bind(this);
         this.deleteConfig = this.deleteConfig.bind(this);
+        this.handleDeleteConfig = this.handleDeleteConfig.bind(this);
+        this.closeWarningModal = this.closeWarningModal.bind(this);
         this.handleSaveConfig = this.handleSaveConfig.bind(this);
         this.cmdOperation = this.cmdOperation.bind(this);
         this.handleShowConfirmDelete = this.handleShowConfirmDelete.bind(this);
@@ -74,6 +81,7 @@ class AccountPolicy extends React.Component {
             limitAttrName: "",
             specAttrName: "",
             stateAttrName: "",
+            checkAllStateAttrs: false,
             _configDN: "",
             _altStateAttrName: [],
             _alwaysRecordLogin: false,
@@ -81,6 +89,7 @@ class AccountPolicy extends React.Component {
             _limitAttrName: "",
             _specAttrName: "",
             _stateAttrName: "",
+            _checkAllStateAttrs: false,
             errorModal: {},
             saveBtnDisabledModal: true,
             modalChecked: false,
@@ -94,6 +103,8 @@ class AccountPolicy extends React.Component {
             isAltStateAttrOpen: false,
             isLimitAttrOpen: false,
             showConfirmDelete: false,
+            showWarningModal: false,
+            warningMessage: "",
         };
 
         // Always Record Login Attribute
@@ -107,7 +118,7 @@ class AccountPolicy extends React.Component {
                 }, () => { this.validateConfig() });
             }
         };
-        this.handleRecordLoginToggle = isRecordLoginOpen => {
+        this.handleRecordLoginToggle = (_event, isRecordLoginOpen) => {
             this.setState({
                 isRecordLoginOpen
             });
@@ -130,7 +141,7 @@ class AccountPolicy extends React.Component {
                 }, () => { this.validateConfig() });
             }
         };
-        this.handleSpecificAttrToggle = isSpecificAttrOpen => {
+        this.handleSpecificAttrToggle = (_event, isSpecificAttrOpen) => {
             this.setState({
                 isSpecificAttrOpen
             });
@@ -153,7 +164,7 @@ class AccountPolicy extends React.Component {
                 }, () => { this.validateConfig() });
             }
         };
-        this.handleStateAttrToggle = isStateAttrOpen => {
+        this.handleStateAttrToggle = (_event, isStateAttrOpen) => {
             this.setState({
                 isStateAttrOpen
             });
@@ -176,7 +187,7 @@ class AccountPolicy extends React.Component {
                 }, () => { this.validateConfig() });
             }
         };
-        this.handleAlternativeStateToggle = isAltStateAttrOpen => {
+        this.handleAlternativeStateToggle = (_event, isAltStateAttrOpen) => {
             this.setState({
                 isAltStateAttrOpen
             });
@@ -199,7 +210,7 @@ class AccountPolicy extends React.Component {
                 }, () => { this.validateConfig() });
             }
         };
-        this.handleLimitAttrToggle = isLimitAttrOpen => {
+        this.handleLimitAttrToggle = (_event, isLimitAttrOpen) => {
             this.setState({
                 isLimitAttrOpen
             });
@@ -275,6 +286,7 @@ class AccountPolicy extends React.Component {
                 limitAttrName: "accountInactivityLimit",
                 specAttrName: "acctPolicySubentry",
                 stateAttrName: "lastLoginTime",
+                checkAllStateAttrs: false,
                 _configDN: "",
                 _altStateAttrName: "createTimestamp",
                 _alwaysRecordLogin: false,
@@ -282,6 +294,7 @@ class AccountPolicy extends React.Component {
                 _limitAttrName: "accountInactivityLimit",
                 _specAttrName: "acctPolicySubentry",
                 _stateAttrName: "lastLoginTime",
+                _checkAllStateAttrs: false,
                 savingModal: false,
                 saveBtnDisabledModal: true,
             });
@@ -311,7 +324,6 @@ class AccountPolicy extends React.Component {
                             savingModal: false,
                             saveBtnDisabledModal: true,
                             configDN: this.state.configArea,
-                            _configDN: this.state.configArea,
                             altStateAttrName:
                             configEntry.altstateattrname === undefined
                                 ? "createTimestamp"
@@ -376,18 +388,21 @@ class AccountPolicy extends React.Component {
                             configEntryModalShow: true,
                             newEntry: true,
                             configDN: this.state.configArea,
+                            _configDN: this.state.configArea,
                             altStateAttrName: "createTimestamp",
                             alwaysRecordLogin: false,
                             alwaysRecordLoginAttr: "lastLoginTime",
                             limitAttrName: "accountInactivityLimit",
                             specAttrName: "acctPolicySubentry",
                             stateAttrName: "lastLoginTime",
+                            checkAllStateAttrs: false,
                             _altStateAttrName: "createTimestamp",
                             _alwaysRecordLogin: false,
                             _alwaysRecordLoginAttr: "lastLoginTime",
                             _limitAttrName: "accountInactivityLimit",
                             _specAttrName: "acctPolicySubentry",
                             _stateAttrName: "lastLoginTime",
+                            _checkAllStateAttrs: false,
                             saveBtnDisabledModal: false, // We preset the form so it's ready to save
                         });
                     });
@@ -406,7 +421,8 @@ class AccountPolicy extends React.Component {
             alwaysRecordLoginAttr,
             limitAttrName,
             specAttrName,
-            stateAttrName
+            stateAttrName,
+            checkAllStateAttrs
         } = this.state;
 
         let cmd = [
@@ -419,7 +435,9 @@ class AccountPolicy extends React.Component {
             action,
             configDN,
             "--always-record-login",
-            alwaysRecordLogin ? "yes" : "no"
+            alwaysRecordLogin ? "yes" : "no",
+            "--check-all-state-attrs",
+            checkAllStateAttrs ? "yes" : "no",
         ];
 
         cmd = [...cmd, "--alt-state-attr"];
@@ -524,6 +542,22 @@ class AccountPolicy extends React.Component {
                 });
     }
 
+    handleDeleteConfig() {
+        const parentDN = "cn=Account Policy Plugin,cn=plugins,cn=config";
+        if (this.state.configDN.toLowerCase().endsWith(parentDN.toLowerCase())) {
+            this.setState({
+                showWarningModal: true,
+                warningMessage: _("Cannot delete this entry as it is a child of the Account Policy Plugin configuration."),
+            });
+        } else {
+            this.handleShowConfirmDelete();
+        }
+    }
+
+    closeWarningModal() {
+        this.setState({ showWarningModal: false });
+    }
+
     deleteConfig() {
         const cmd = [
             "dsconf",
@@ -569,13 +603,19 @@ class AccountPolicy extends React.Component {
 
     handleAddConfig() {
         this.cmdOperation("add");
+        if (!this.state.saveBtnDisabled && !this.state.saving) {
+            this.handleSaveConfig();
+        }
     }
 
     handleEditConfig() {
         this.cmdOperation("set");
+        if (!this.state.saveBtnDisabled && !this.state.saving) {
+            this.handleSaveConfig();
+        }
     }
 
-    handleCheckboxChange(checked, e) {
+    handleCheckboxChange(e, checked) {
         this.setState({
             [e.target.id]: checked
         }, () => { this.validateConfig() });
@@ -600,7 +640,8 @@ class AccountPolicy extends React.Component {
             all_good = false;
             const attrs = [
                 'configDN', 'altStateAttrName', 'alwaysRecordLogin',
-                'alwaysRecordLoginAttr', 'limitAttrName', 'stateAttrName'
+                'alwaysRecordLoginAttr', 'limitAttrName', 'stateAttrName',
+                'checkAllStateAttrs',
             ];
             for (const check_attr of attrs) {
                 if (this.state[check_attr] !== this.state['_' + check_attr]) {
@@ -659,10 +700,18 @@ class AccountPolicy extends React.Component {
         if (this.props.rows.length > 0) {
             const pluginRow = this.props.rows.find(row => row.cn[0] === "Account Policy Plugin");
             this.setState({
-                configArea:
-                    pluginRow.nsslapd_pluginconfigarea === undefined
+                configDN:
+                    pluginRow["nsslapd-pluginarg0"] === undefined
                         ? ""
-                        : pluginRow.nsslapd_pluginconfigarea[0]
+                        : pluginRow["nsslapd-pluginarg0"][0],
+                configArea:
+                    pluginRow["nsslapd-pluginarg0"] === undefined
+                        ? ""
+                        : pluginRow["nsslapd-pluginarg0"][0],
+                _configArea:
+                    pluginRow["nsslapd-pluginarg0"] === undefined
+                        ? ""
+                        : pluginRow["nsslapd-pluginarg0"][0],
             }, () => { this.sharedConfigExists() });
         }
     }
@@ -699,7 +748,9 @@ class AccountPolicy extends React.Component {
                         _("Successfully updated Account Policy Plugin")
                     );
                     this.setState({
-                        saving: false
+                        saving: false,
+                        saveBtnDisabled: true,
+                        _configArea: this.state.configArea
                     });
                     this.props.pluginListHandler();
                 })
@@ -730,6 +781,7 @@ class AccountPolicy extends React.Component {
             limitAttrName,
             specAttrName,
             stateAttrName,
+            checkAllStateAttrs,
             newEntry,
             configEntryModalShow,
             error,
@@ -750,7 +802,7 @@ class AccountPolicy extends React.Component {
         let modalButtons = [];
         if (!newEntry) {
             modalButtons = [
-                <Button key="del" variant="primary" onClick={this.handleShowConfirmDelete}>
+                <Button key="del" variant="primary" onClick={this.handleDeleteConfig}>
                     {_("Delete Config")}
                 </Button>,
                 <Button
@@ -809,11 +861,11 @@ class AccountPolicy extends React.Component {
                                     id="configDN"
                                     aria-describedby="horizontal-form-name-helper"
                                     name="configDN"
-                                    onChange={(str, e) => { this.handleModalChange(e) }}
+                                    onChange={(e, str) => { this.handleModalChange(e) }}
                                     validated={errorModal.configDN ? ValidatedOptions.error : ValidatedOptions.default}
-                                    isDisabled={newEntry}
+                                    isDisabled
                                 />
-                                <FormHelperText isError isHidden={!errorModal.configDN}>
+                                <FormHelperText  >
                                     {_("Value must be a valid DN")}
                                 </FormHelperText>
                             </GridItem>
@@ -825,8 +877,8 @@ class AccountPolicy extends React.Component {
                             <GridItem span={4}>
                                 <Select
                                     variant={SelectVariant.typeahead}
-                                    typeAheadAriaLabel="Type an attribute name"
-                                    onToggle={this.handleRecordLoginToggle}
+                                    typeAheadAriaLabel={_("Type an attribute name")}
+                                    onToggle={(event, isOpen) => this.handleRecordLoginToggle(event, isOpen)}
                                     onSelect={this.handleRecordLoginSelect}
                                     onClear={this.handleRecordLoginClear}
                                     selections={alwaysRecordLoginAttr}
@@ -849,7 +901,7 @@ class AccountPolicy extends React.Component {
                                     className="ds-left-margin"
                                     isChecked={alwaysRecordLogin}
                                     title={_("Sets that every entry records its last login time (alwaysRecordLogin)")}
-                                    onChange={this.handleCheckboxChange}
+                                    onChange={(e, checked) => this.handleCheckboxChange(e, checked)}
                                     label={_("Always Record Login")}
                                 />
                             </GridItem>
@@ -861,8 +913,8 @@ class AccountPolicy extends React.Component {
                             <GridItem span={8}>
                                 <Select
                                     variant={SelectVariant.typeahead}
-                                    typeAheadAriaLabel="Type an attribute name"
-                                    onToggle={this.handleSpecificAttrToggle}
+                                    typeAheadAriaLabel={_("Type an attribute name")}
+                                    onToggle={(event, isOpen) => this.handleSpecificAttrToggle(event, isOpen)}
                                     onSelect={this.handleSpecificAttrSelect}
                                     onClear={this.handleSpecificAttrClear}
                                     selections={specAttrName}
@@ -880,15 +932,15 @@ class AccountPolicy extends React.Component {
                                 </Select>
                             </GridItem>
                         </Grid>
-                        <Grid title={_("Specifies the primary time attribute used to evaluate an account policy (stateAttrName)")}>
+                        <Grid title={_("Specifies the attribute within the policy to use for the account inactivation limit (limitAttrName)")}>
                             <GridItem span={4} className="ds-label">
                                 {_("Limit Attribute")}
                             </GridItem>
                             <GridItem span={8}>
                                 <Select
                                     variant={SelectVariant.typeahead}
-                                    typeAheadAriaLabel="Type an attribute name"
-                                    onToggle={this.handleLimitAttrToggle}
+                                    typeAheadAriaLabel={_("Type an attribute name")}
+                                    onToggle={(event, isOpen) => this.handleLimitAttrToggle(event, isOpen)}
                                     onSelect={this.handleLimitAttrSelect}
                                     onClear={this.handleLimitAttrClear}
                                     selections={limitAttrName}
@@ -913,8 +965,8 @@ class AccountPolicy extends React.Component {
                             <GridItem span={8}>
                                 <Select
                                     variant={SelectVariant.typeahead}
-                                    typeAheadAriaLabel="Type an attribute name"
-                                    onToggle={this.handleStateAttrToggle}
+                                    typeAheadAriaLabel={_("Type an attribute name")}
+                                    onToggle={(event, isOpen) => this.handleStateAttrToggle(event, isOpen)}
                                     onSelect={this.handleStateAttrSelect}
                                     onClear={this.handleStateAttrClear}
                                     selections={stateAttrName}
@@ -922,6 +974,7 @@ class AccountPolicy extends React.Component {
                                     aria-labelledby="typeAhead-state-attr"
                                     placeholderText={_("Type an attribute name ...")}
                                     noResultsFoundText={_("There are no matching entries")}
+                                    isCreatable
                                 >
                                     {this.props.attributes.map((attr, index) => (
                                         <SelectOption
@@ -932,15 +985,15 @@ class AccountPolicy extends React.Component {
                                 </Select>
                             </GridItem>
                         </Grid>
-                        <Grid title={_("Provides a backup attribute for the server to reference to evaluate the expiration time (altStateAttrName)")}>
+                        <Grid title={_("Provides a backup attribute to evaluate the expiration time if the main state attribute is not present (altStateAttrName)")}>
                             <GridItem span={4} className="ds-label">
                                 {_("Alternative State Attribute")}
                             </GridItem>
                             <GridItem span={8}>
                                 <Select
                                     variant={SelectVariant.typeahead}
-                                    typeAheadAriaLabel="Type an attribute name"
-                                    onToggle={this.handleAlternativeStateToggle}
+                                    typeAheadAriaLabel={_("Type an attribute name")}
+                                    onToggle={(event, isOpen) => this.handleAlternativeStateToggle(event, isOpen)}
                                     onSelect={this.handleAlternativeStateSelect}
                                     onClear={this.handleAlternativeStateClear}
                                     selections={altStateAttrName}
@@ -948,6 +1001,7 @@ class AccountPolicy extends React.Component {
                                     aria-labelledby="typeAhead-alt-state-attr"
                                     placeholderText={_("Type an attribute name ...")}
                                     noResultsFoundText={_("There are no matching entries")}
+                                    isCreatable
                                 >
                                     {this.props.attributes.map((attr, index) => (
                                         <SelectOption
@@ -958,30 +1012,18 @@ class AccountPolicy extends React.Component {
                                 </Select>
                             </GridItem>
                         </Grid>
-                        <Grid title={_("Specifies the attribute within the policy to use for the account inactivation limit (limitAttrName)")}>
+                        <Grid title={_("Check both the 'state attribute', and the 'alternate state attribute' regaredless if the main state attribute is present")}>
                             <GridItem span={4} className="ds-label">
-                                {_("Limit Attribute")}
+                                {_("Check All State Attributes")}
                             </GridItem>
                             <GridItem span={8}>
-                                <Select
-                                    variant={SelectVariant.typeahead}
-                                    typeAheadAriaLabel={_("Type an attribute name")}
-                                    onToggle={this.handleLimitAttrToggle}
-                                    onSelect={this.handleLimitAttrSelect}
-                                    onClear={this.handleLimitAttrClear}
-                                    selections={limitAttrName}
-                                    isOpen={this.state.isLimitAttrOpen}
-                                    aria-labelledby="typeAhead-limit-attr"
-                                    placeholderText={_("Type an attribute name ...")}
-                                    noResultsFoundText={_("There are no matching entries")}
-                                >
-                                    {this.props.attributes.map((attr, index) => (
-                                        <SelectOption
-                                            key={index}
-                                            value={attr}
-                                        />
-                                    ))}
-                                </Select>
+                                <Checkbox
+                                    id="checkAllStateAttrs"
+                                    className="ds-left-margin"
+                                    isChecked={checkAllStateAttrs}
+                                    onChange={(e, checked) => this.handleCheckboxChange(e, checked)}
+                                    label={_("Check Both - State and Alternative State Attributes")}
+                                />
                             </GridItem>
                         </Grid>
                     </Form>
@@ -999,7 +1041,7 @@ class AccountPolicy extends React.Component {
                     toggleLoadingHandler={this.props.toggleLoadingHandler}
                 >
                     <Form isHorizontal autoComplete="off">
-                        <Grid title={_("DN of the shared config entry (nsslapd-pluginConfigArea)")}>
+                        <Grid title={_("DN of the shared config entry (nsslapd-pluginarg0)")}>
                             <GridItem span={3} className="ds-label">
                                 {_("Shared Config Entry")}
                             </GridItem>
@@ -1010,10 +1052,10 @@ class AccountPolicy extends React.Component {
                                     id="configArea"
                                     aria-describedby="horizontal-form-name-helper"
                                     name="configArea"
-                                    onChange={(str, e) => { this.handleFieldChange(e) }}
+                                    onChange={(e, str) => { this.handleFieldChange(e) }}
                                     validated={error.configArea ? ValidatedOptions.error : ValidatedOptions.default}
                                 />
-                                <FormHelperText isError isHidden={!error.configArea}>
+                                <FormHelperText  >
                                     {_("Value must be a valid DN")}
                                 </FormHelperText>
                             </GridItem>
@@ -1023,7 +1065,7 @@ class AccountPolicy extends React.Component {
                                     key="manage"
                                     variant="primary"
                                     onClick={this.handleOpenModal}
-                                    isDisabled={!this.state.sharedConfigExists && saveBtnDisabled}
+                                    isDisabled={error.configArea || !configArea}
                                 >
                                     {this.state.sharedConfigExists ? _("Manage Config") : _("Create Config")}
                                 </Button>
@@ -1056,6 +1098,12 @@ class AccountPolicy extends React.Component {
                     mSpinningMsg={_("Deleting ...")}
                     mBtnName={_("Delete")}
                 />
+                <WarningModal
+                    showModal={this.state.showWarningModal}
+                    closeHandler={this.closeWarningModal}
+                    mTitle={_("Cannot Delete Entry")}
+                    mMsg={this.state.warningMessage}
+                />
             </div>
         );
     }
