@@ -210,7 +210,7 @@ class PassthroughAuthentication extends React.Component {
             "list"
         ];
         this.props.toggleLoadingHandler();
-        log_cmd("loadURLs", "Get Passthough Authentication Plugin Configs", cmd);
+        log_cmd("loadURLs", "Get Passthrough Authentication Plugin Configs", cmd);
         cockpit
                 .spawn(cmd, { superuser: true, err: "message" })
                 .done(content => {
@@ -299,7 +299,7 @@ class PassthroughAuthentication extends React.Component {
             modalSpinning: true
         });
 
-        log_cmd("deleteURL", "Delete the Passthough Authentication Plugin URL entry", cmd);
+        log_cmd("deleteURL", "Delete the Passthrough Authentication Plugin URL entry", cmd);
         cockpit
                 .spawn(cmd, {
                     superuser: true,
@@ -367,7 +367,7 @@ class PassthroughAuthentication extends React.Component {
         });
         log_cmd(
             "PassthroughAuthOperation",
-            `Do the ${action} operation on the Passthough Authentication Plugin`,
+            `Do the ${action} operation on the Passthrough Authentication Plugin`,
             cmd
         );
         cockpit
@@ -500,7 +500,7 @@ class PassthroughAuthentication extends React.Component {
                                 <FormSelect
                                     id="urlConnType"
                                     value={urlConnType}
-                                    onChange={(value, event) => {
+                                    onChange={(event, value) => {
                                         this.handlePassthruChange(event);
                                     }}
                                     aria-label="FormSelect Input"
@@ -522,7 +522,7 @@ class PassthroughAuthentication extends React.Component {
                                         id={content.id}
                                         aria-describedby="horizontal-form-name-helper"
                                         name={content.name}
-                                        onChange={(str, e) => {
+                                        onChange={(e, str) => {
                                             this.handlePassthruChange(e);
                                         }}
                                         validated={error[content.id] ? ValidatedOptions.error : ValidatedOptions.default}
@@ -564,7 +564,7 @@ class PassthroughAuthentication extends React.Component {
                                 <FormSelect
                                     id="urlLDVer"
                                     value={urlLDVer}
-                                    onChange={(value, event) => {
+                                    onChange={(event, value) => {
                                         this.handlePassthruChange(event);
                                     }}
                                     aria-label="FormSelect Input"
@@ -579,7 +579,7 @@ class PassthroughAuthentication extends React.Component {
                                 <Checkbox
                                     id="urlStartTLS"
                                     isChecked={urlStartTLS}
-                                    onChange={(checked, e) => { this.handlePassthruChange(e) }}
+                                    onChange={(e, checked) => { this.handlePassthruChange(e) }}
                                     title={_("A flag of whether to use Start TLS for the connection to the authenticating directory. Start TLS establishes a secure connection over the standard port, so it is useful for connecting using LDAP instead of LDAPS. The TLS server and CA certificates need to be available on both of the servers. To use Start TLS, the LDAP URL must use ldap:, not ldaps:.")}
                                     label={_("Enable StartTLS")}
                                 />
