@@ -1,22 +1,27 @@
+import cockpit from "cockpit";
 import React from "react";
 import {
-    Button,
-    Checkbox,
-    Form,
-    FormSelect,
-    FormSelectOption,
-    Grid,
-    GridItem,
-    Modal,
-    ModalVariant,
-    Select,
-    SelectVariant,
-    SelectOption,
-    TextInput,
-    ValidatedOptions,
-} from "@patternfly/react-core";
+	Button,
+	Checkbox,
+	Form,
+	FormSelect,
+	FormSelectOption,
+	Grid,
+	GridItem,
+	Modal,
+	ModalVariant,
+	TextInput,
+	ValidatedOptions
+} from '@patternfly/react-core';
+import {
+	Select,
+	SelectVariant,
+	SelectOption
+} from '@patternfly/react-core/deprecated';
 import PropTypes from "prop-types";
 
+const _ = cockpit.gettext;
+
 class ObjectClassModal extends React.Component {
     render() {
         const {
@@ -52,33 +57,35 @@ class ObjectClassModal extends React.Component {
         } = this.props;
 
         const modalTitle =
-            ocModalViewOnly ? (
-                `View ObjectClass - ${ocName}`
-            ) : (
-                <div>
-                    {newOcEntry ? "Add" : "Edit"} ObjectClass
-                    {ocName != "" ? ` - ${ocName}` : ""}{" "}
-                </div>
-            );
+            ocModalViewOnly
+                ? (
+                    cockpit.format(_("View ObjectClass - $0"), ocName)
+                )
+                : (
+                    <div>
+                        {cockpit.format(_("$0 ObjectClass"), newOcEntry ? _("Add") : _("Edit"))}
+                        {ocName !== "" ? ` - ${ocName}` : ""}{" "}
+                    </div>
+                );
 
         const btnList = [
             <Button key="cancel" variant="link" onClick={closeModal}>
-                Close
+                {_("Close")}
             </Button>
         ];
         if (!ocModalViewOnly) {
-            let btnText = "Save";
+            let btnText = _("Save");
             const extraPrimaryProps = {};
 
             if (loading) {
-                btnText = "Saving...";
-                extraPrimaryProps.spinnerAriaValueText = "Loading";
+                btnText = _("Saving...");
+                extraPrimaryProps.spinnerAriaValueText = _("Loading");
             }
             btnList.unshift(
                 <Button
                     key="oc"
                     isLoading={loading}
-                    spinnerAriaValueText={loading ? "Loading" : undefined}
+                    spinnerAriaValueText={loading ? _("Loading") : undefined}
                     variant="primary"
                     onClick={newOcEntry ? addHandler : editHandler}
                     {...extraPrimaryProps}
@@ -100,9 +107,9 @@ class ObjectClassModal extends React.Component {
                     actions={btnList}
                 >
                     <Form isHorizontal autoComplete="off">
-                        <Grid title="Name of the objectClass">
+                        <Grid title={_("Name of the objectClass")}>
                             <GridItem className="ds-label" span={3}>
-                                Objectclass Name
+                                {_("Objectclass Name")}
                             </GridItem>
                             <GridItem span={9}>
                                 <TextInput
@@ -111,15 +118,15 @@ class ObjectClassModal extends React.Component {
                                     id="ocName"
                                     aria-describedby="horizontal-form-name-helper"
                                     name="ocName"
-                                    onChange={(str, e) => { handleFieldChange(e) }}
+                                    onChange={(e, str) => { handleFieldChange(e) }}
                                     validated={error.ocName ? ValidatedOptions.error : ValidatedOptions.default}
                                     isDisabled={!newOcEntry}
                                 />
                             </GridItem>
                         </Grid>
-                        <Grid title="Describes what is the objectClass's purpose">
+                        <Grid title={_("Describes what is the objectClass's purpose")}>
                             <GridItem className="ds-label" span={3}>
-                                Description
+                                {_("Description")}
                             </GridItem>
                             <GridItem span={9}>
                                 <TextInput
@@ -128,14 +135,14 @@ class ObjectClassModal extends React.Component {
                                     id="ocDesc"
                                     aria-describedby="horizontal-form-name-helper"
                                     name="ocDesc"
-                                    onChange={(str, e) => { handleFieldChange(e) }}
+                                    onChange={(e, str) => { handleFieldChange(e) }}
                                     validated={error.ocDesc ? ValidatedOptions.error : ValidatedOptions.default}
                                 />
                             </GridItem>
                         </Grid>
-                        <Grid title="Object identifier">
+                        <Grid title={_("Object identifier")}>
                             <GridItem className="ds-label" span={3}>
-                                OID (optional)
+                                {_("OID (optional)")}
                             </GridItem>
                             <GridItem span={9}>
                                 <TextInput
@@ -145,20 +152,20 @@ class ObjectClassModal extends React.Component {
                                     aria-describedby="horizontal-form-name-helper"
                                     name="ocOID"
                                     isDisabled={ocModalViewOnly}
-                                    onChange={(str, e) => { handleFieldChange(e) }}
+                                    onChange={(e, str) => { handleFieldChange(e) }}
                                 />
                             </GridItem>
                         </Grid>
-                        <Grid title="An objectClass's parent">
+                        <Grid title={_("An objectClass's parent")}>
                             <GridItem className="ds-label" span={3}>
-                                Parent Objectclass
+                                {_("Parent Objectclass")}
                             </GridItem>
                             <GridItem span={9}>
                                 <FormSelect
                                     id="ocParent"
                                     value={ocParent}
                                     isDisabled={ocModalViewOnly}
-                                    onChange={(str, e) => { handleFieldChange(e) }}
+                                    onChange={(e, str) => { handleFieldChange(e) }}
                                     aria-label="FormSelect Input"
                                 >
                                     {objectclasses.map((obj, index) => (
@@ -167,16 +174,16 @@ class ObjectClassModal extends React.Component {
                                 </FormSelect>
                             </GridItem>
                         </Grid>
-                        <Grid title="An objectClass's kind">
+                        <Grid title={_("An objectClass's kind")}>
                             <GridItem className="ds-label" span={3}>
-                                Objectclass Kind
+                                {_("Objectclass Kind")}
                             </GridItem>
                             <GridItem span={9}>
                                 <FormSelect
                                     id="ocKind"
                                     value={ocKind}
                                     isDisabled={ocModalViewOnly}
-                                    onChange={(str, e) => { handleFieldChange(e) }}
+                                    onChange={(e, str) => { handleFieldChange(e) }}
                                     aria-label="FormSelect Input"
                                 >
                                     <FormSelectOption key={0} value="STRUCTURAL" label="STRUCTURAL" />
@@ -185,9 +192,9 @@ class ObjectClassModal extends React.Component {
                                 </FormSelect>
                             </GridItem>
                         </Grid>
-                        <Grid title="A must attribute name">
+                        <Grid title={_("A must attribute name")}>
                             <GridItem className="ds-label" span={3}>
-                                Required Attributes
+                                {_("Required Attributes")}
                             </GridItem>
                             <GridItem span={9}>
                                 <Select
@@ -200,8 +207,8 @@ class ObjectClassModal extends React.Component {
                                     id="ocMust"
                                     isOpen={isRequiredAttrsOpen}
                                     aria-labelledby="typeAhead-required-attrs"
-                                    placeholderText="Type an attribute name..."
-                                    noResultsFoundText="There are no matching entries"
+                                    placeholderText={_("Type an attribute name...")}
+                                    noResultsFoundText={_("There are no matching entries")}
                                     isCreatable
                                     onCreateOption={onRequiredAttrsCreateOption}
                                     direction="up"
@@ -216,9 +223,9 @@ class ObjectClassModal extends React.Component {
                                 </Select>
                             </GridItem>
                         </Grid>
-                        <Grid title="A may attribute name">
+                        <Grid title={_("A may attribute name")}>
                             <GridItem className="ds-label" span={3}>
-                                Allowed Attributes
+                                {_("Allowed Attributes")}
                             </GridItem>
                             <GridItem span={9}>
                                 <Select
@@ -231,8 +238,8 @@ class ObjectClassModal extends React.Component {
                                     id="ocMay"
                                     isOpen={isAllowedAttrsOpen}
                                     aria-labelledby="typeAhead-allowed-attrs"
-                                    placeholderText="Type an attribute name..."
-                                    noResultsFoundText="There are no matching entries"
+                                    placeholderText={_("Type an attribute name...")}
+                                    noResultsFoundText={_("There are no matching entries")}
                                     isCreatable
                                     onCreateOption={onAllowedAttrsCreateOption}
                                     direction="up"
@@ -342,33 +349,35 @@ class AttributeTypeModal extends React.Component {
             saveBtnDisabled,
         } = this.props;
         const modalTitle =
-            atModalViewOnly ? (
-                `View Attribute - ${atName}`
-            ) : (
-                <div>
-                    {newAtEntry ? "Add" : "Edit"} Attribute
-                    {atName != "" ? ` - ${atName}` : ""}{" "}
-                </div>
-            );
+            atModalViewOnly
+                ? (
+                    cockpit.format(_("View Attribute - $0"), atName)
+                )
+                : (
+                    <div>
+                        {cockpit.format(_("$0 Attribute"), newAtEntry ? _("Add") : _("Edit"))}
+                        {atName !== "" ? ` - ${atName}` : ""}{" "}
+                    </div>
+                );
 
         const btnList = [
             <Button key="cancel" variant="link" onClick={closeModal}>
-                Close
+                {_("Close")}
             </Button>
         ];
         if (!atModalViewOnly) {
-            let btnText = "Save";
+            let btnText = _("Save");
             const extraPrimaryProps = {};
 
             if (loading) {
-                btnText = "Saving...";
-                extraPrimaryProps.spinnerAriaValueText = "Loading";
+                btnText = _("Saving...");
+                extraPrimaryProps.spinnerAriaValueText = _("Loading");
             }
             btnList.unshift(
                 <Button
                     key="at"
                     isLoading={loading}
-                    spinnerAriaValueText={loading ? "Loading" : undefined}
+                    spinnerAriaValueText={loading ? _("Loading") : undefined}
                     variant="primary"
                     onClick={newAtEntry ? addHandler : editHandler}
                     {...extraPrimaryProps}
@@ -390,9 +399,9 @@ class AttributeTypeModal extends React.Component {
                     actions={btnList}
                 >
                     <Form isHorizontal autoComplete="off">
-                        <Grid title="Name of the attribute">
+                        <Grid title={_("Name of the attribute")}>
                             <GridItem className="ds-label" span={3}>
-                                Attribute Name
+                                {_("Attribute Name")}
                             </GridItem>
                             <GridItem span={9}>
                                 <TextInput
@@ -402,14 +411,14 @@ class AttributeTypeModal extends React.Component {
                                     aria-describedby="horizontal-form-name-helper"
                                     name="atName"
                                     isDisabled={!newAtEntry}
-                                    onChange={(str, e) => { handleFieldChange(e) }}
+                                    onChange={(e, str) => { handleFieldChange(e) }}
                                     validated={error.atName ? ValidatedOptions.error : ValidatedOptions.default}
                                 />
                             </GridItem>
                         </Grid>
-                        <Grid title="Describes what is the attribute's purpose">
+                        <Grid title={_("Describes what is the attribute's purpose")}>
                             <GridItem className="ds-label" span={3}>
-                                Description
+                                {_("Description")}
                             </GridItem>
                             <GridItem span={9}>
                                 <TextInput
@@ -419,14 +428,14 @@ class AttributeTypeModal extends React.Component {
                                     aria-describedby="horizontal-form-name-helper"
                                     name="atDesc"
                                     isDisabled={atModalViewOnly}
-                                    onChange={(str, e) => { handleFieldChange(e) }}
+                                    onChange={(e, str) => { handleFieldChange(e) }}
                                     validated={error.atDesc ? ValidatedOptions.error : ValidatedOptions.default}
                                 />
                             </GridItem>
                         </Grid>
-                        <Grid title="Object identifier">
+                        <Grid title={_("Object identifier")}>
                             <GridItem className="ds-label" span={3}>
-                                OID (optional)
+                                {_("OID (optional)")}
                             </GridItem>
                             <GridItem span={9}>
                                 <TextInput
@@ -436,13 +445,13 @@ class AttributeTypeModal extends React.Component {
                                     aria-describedby="horizontal-form-name-helper"
                                     name="atOID"
                                     isDisabled={atModalViewOnly}
-                                    onChange={(str, e) => { handleFieldChange(e) }}
+                                    onChange={(e, str) => { handleFieldChange(e) }}
                                 />
                             </GridItem>
                         </Grid>
-                        <Grid title="An attribute's parent/superior ">
+                        <Grid title={_("An attribute's parent/superior")}>
                             <GridItem className="ds-label" span={3}>
-                                Parent Attribute
+                                {_("Parent Attribute")}
                             </GridItem>
                             <GridItem span={9}>
                                 <Select
@@ -454,8 +463,8 @@ class AttributeTypeModal extends React.Component {
                                     selections={atParent}
                                     isOpen={isParentAttrOpen}
                                     aria-labelledby="typeAhead-parent-attr"
-                                    placeholderText="Type an attribute name..."
-                                    noResultsFoundText="There are no matching entries"
+                                    placeholderText={_("Type an attribute name...")}
+                                    noResultsFoundText={_("There are no matching entries")}
                                 >
                                     {attributes.map((attr, index) => (
                                         <SelectOption
@@ -466,16 +475,16 @@ class AttributeTypeModal extends React.Component {
                                 </Select>
                             </GridItem>
                         </Grid>
-                        <Grid title="An attribute's syntax">
+                        <Grid title={_("An attribute's syntax")}>
                             <GridItem className="ds-label" span={3}>
-                                Syntax Name
+                                {_("Syntax Name")}
                             </GridItem>
                             <GridItem span={9}>
                                 <FormSelect
                                     id="atSyntax"
                                     value={atSyntax}
                                     isDisabled={atModalViewOnly}
-                                    onChange={(str, e) => { handleFieldChange(e) }}
+                                    onChange={(e, str) => { handleFieldChange(e) }}
                                     aria-label="FormSelect Input"
                                 >
                                     {syntaxes.map((syntax, index) => (
@@ -484,16 +493,16 @@ class AttributeTypeModal extends React.Component {
                                 </FormSelect>
                             </GridItem>
                         </Grid>
-                        <Grid title="An attribute's usage purpose">
+                        <Grid title={_("An attribute's usage purpose")}>
                             <GridItem className="ds-label" span={3}>
-                                Attribute Usage
+                                {_("Attribute Usage")}
                             </GridItem>
                             <GridItem span={9}>
                                 <FormSelect
                                     id="atUsage"
                                     value={atUsage}
                                     isDisabled={atModalViewOnly}
-                                    onChange={(str, e) => { handleFieldChange(e) }}
+                                    onChange={(e, str) => { handleFieldChange(e) }}
                                     aria-label="FormSelect Input"
                                 >
                                     <FormSelectOption key={0} value="userApplications" label="userApplications" />
@@ -503,41 +512,41 @@ class AttributeTypeModal extends React.Component {
                                 </FormSelect>
                             </GridItem>
                         </Grid>
-                        <Grid title="If attribute can have a multiple values">
+                        <Grid title={_("If attribute can have a multiple values")}>
                             <GridItem className="ds-label" span={3}>
-                                Multivalued Attribute
+                                {_("Multivalued Attribute")}
                             </GridItem>
                             <GridItem span={9}>
                                 <Checkbox
                                     id="atMultivalued"
                                     isChecked={atMultivalued}
-                                    title="If attribute can have a multiple values"
-                                    onChange={(checked, e) => {
+                                    title={_("If attribute can have a multiple values")}
+                                    onChange={(e, checked) => {
                                         handleFieldChange(e);
                                     }}
                                     isDisabled={atModalViewOnly}
                                 />
                             </GridItem>
                         </Grid>
-                        <Grid title="If attribute is not modifiable by a client application">
+                        <Grid title={_("If attribute is not modifiable by a client application")}>
                             <GridItem className="ds-label" span={3}>
-                                Not Modifiable By A User
+                                {_("Not Modifiable By A User")}
                             </GridItem>
                             <GridItem span={9}>
                                 <Checkbox
                                     id="atNoUserMod"
                                     isChecked={atNoUserMod}
-                                    title="If attribute is not modifiable by a client application"
-                                    onChange={(checked, e) => {
+                                    title={_("If attribute is not modifiable by a client application")}
+                                    onChange={(e, checked) => {
                                         handleFieldChange(e);
                                     }}
                                     isDisabled={atModalViewOnly}
                                 />
                             </GridItem>
                         </Grid>
-                        <Grid title="An alias name for the attribute">
+                        <Grid title={_("An alias name for the attribute")}>
                             <GridItem className="ds-label" span={3}>
-                                Alias Names
+                                {_("Alias Names")}
                             </GridItem>
                             <GridItem span={9}>
                                 <Select
@@ -549,8 +558,8 @@ class AttributeTypeModal extends React.Component {
                                     selections={atAlias}
                                     isOpen={isAliasNameOpen}
                                     aria-labelledby="typeAhead-alias-name"
-                                    placeholderText="Type an alias name..."
-                                    noResultsFoundText="There are no matching entries"
+                                    placeholderText={_("Type an alias name...")}
+                                    noResultsFoundText={_("There are no matching entries")}
                                     isCreatable
                                     onCreateOption={onAliasNameCreateOption}
                                 >
@@ -564,9 +573,9 @@ class AttributeTypeModal extends React.Component {
                             </GridItem>
                         </Grid>
 
-                        <Grid title="An equality matching rule">
+                        <Grid title={_("An equality matching rule")}>
                             <GridItem className="ds-label" span={3}>
-                                Equality Matching Rule
+                                {_("Equality Matching Rule")}
                             </GridItem>
                             <GridItem span={9}>
                                 <Select
@@ -578,8 +587,8 @@ class AttributeTypeModal extends React.Component {
                                     selections={atEqMr}
                                     isOpen={isEqualityMROpen}
                                     aria-labelledby="typeAhead-equality-mr"
-                                    placeholderText="Type an Equality matching rule..."
-                                    noResultsFoundText="There are no matching rules"
+                                    placeholderText={_("Type an Equality matching rule...")}
+                                    noResultsFoundText={_("There are no matching rules")}
                                 >
                                     {matchingrules.map((mr, index) => (
                                         <SelectOption
@@ -590,9 +599,9 @@ class AttributeTypeModal extends React.Component {
                                 </Select>
                             </GridItem>
                         </Grid>
-                        <Grid title="An order matching rule">
+                        <Grid title={_("An order matching rule")}>
                             <GridItem className="ds-label" span={3}>
-                                Order Matching Rule
+                                {_("Order Matching Rule")}
                             </GridItem>
                             <GridItem span={9}>
                                 <Select
@@ -604,8 +613,8 @@ class AttributeTypeModal extends React.Component {
                                     selections={atOrder}
                                     isOpen={isOrderMROpen}
                                     aria-labelledby="typeAhead-order-mr"
-                                    placeholderText="Type an Ordering matching rule.."
-                                    noResultsFoundText="There are no matching rules"
+                                    placeholderText={_("Type an Ordering matching rule..")}
+                                    noResultsFoundText={_("There are no matching rules")}
                                 >
                                     {matchingrules.map((mr, index) => (
                                         <SelectOption
@@ -616,9 +625,9 @@ class AttributeTypeModal extends React.Component {
                                 </Select>
                             </GridItem>
                         </Grid>
-                        <Grid title="A substring matching rule">
+                        <Grid title={_("A substring matching rule")}>
                             <GridItem className="ds-label" span={3}>
-                                Substring Matching Rule
+                                {_("Substring Matching Rule")}
                             </GridItem>
                             <GridItem span={9}>
                                 <Select
@@ -629,8 +638,8 @@ class AttributeTypeModal extends React.Component {
                                     onClear={onSubstringMRClear}
                                     selections={atSubMr}
                                     isOpen={isSubstringMROpen}
-                                    placeholderText="Type a Substring matching rule..."
-                                    noResultsFoundText="There are no matching rules"
+                                    placeholderText={_("Type a Substring matching rule...")}
+                                    noResultsFoundText={_("There are no matching rules")}
                                 >
                                     {matchingrules.map((mr, index) => (
                                         <SelectOption
