@@ -9,13 +9,15 @@ import {
     Tooltip,
 } from '@patternfly/react-core';
 import {
-    expandable,
     Table,
-    TableHeader,
-    TableBody,
-    TableVariant,
-    sortable,
-    SortByDirection,
+	SortByDirection,
+    Thead,
+    Tr,
+    Th,
+    Tbody,
+    Td,
+    ActionsColumn,
+    ExpandableRowContent
 } from '@patternfly/react-table';
 import PropTypes from "prop-types";
 
@@ -33,9 +35,9 @@ class KeyTable extends React.Component {
             rows: [],
             hasRows: false,
             columns: [
-                { title: _("Cipher"), transforms: [sortable] },
-                { title: _("Key Identifier"), transforms: [sortable] },
-                { title: _("State"), transforms: [sortable] },
+                { title: _("Cipher"), sortable: true },
+                { title: _("Key Identifier"), sortable: true },
+                { title: _("State"), sortable: true },
             ],
         };
 
@@ -50,6 +52,8 @@ class KeyTable extends React.Component {
                 perPage
             });
         };
+
+        this.handleSort = this.handleSort.bind(this);
     }
 
     componentDidMount() {
@@ -58,12 +62,11 @@ class KeyTable extends React.Component {
         let hasRows = true;
 
         for (const ServerKey of this.props.ServerKeys) {
-            rows.push(
-                {
-                    isOpen: false,
-                    cells: [ServerKey.attrs.cipher, ServerKey.attrs.key_id, ServerKey.attrs.state],
-                },
-            );
+            rows.push([
+                ServerKey.attrs.cipher,
+                ServerKey.attrs.key_id,
+                ServerKey.attrs.state
+            ]);
         }
 
         if (rows.length === 0) {
@@ -79,63 +82,107 @@ class KeyTable extends React.Component {
         });
     }
 
-    actions() {
-        return [
-            {
-                title: _("Delete Key"),
-                onClick: (event, rowId, rowData, extra) => {
-                    if (rowData.cells[1]) {
-                        this.props.delKey(rowData.cells[1]);
-                    }
+    getActionsForRow = (rowData) => [
+        {
+            title: _("Delete Key"),
+            onClick: () => {
+                if (rowData[1]) {
+                    this.props.delKey(rowData[1]);
                 }
             }
-        ];
+        }
+    ];
+
+    handleSort(_event, index, direction) {
+        const sortedRows = [...this.state.rows].sort((a, b) => 
+            (a[index] < b[index] ? -1 : a[index] > b[index] ? 1 : 0)
+        );
+        
+        this.setState({
+            sortBy: {
+                index,
+                direction
+            },
+            rows: direction === SortByDirection.asc ? sortedRows : sortedRows.reverse()
+        });
     }
 
     render() {
         const { perPage, page, sortBy, rows, columns, hasRows } = this.state;
+        const startIdx = (perPage * page) - perPage;
+        const tableRows = rows.slice(startIdx, startIdx + perPage);
 
         return (
             <div className="ds-margin-top-lg">
                 <Tooltip
-                        content={
-                            <div>
-                                <p>
-                                    {_("An orphan key is a private key in the NSS DB for which there is NO cert with the corresponding public key. An orphan key is created during CSR creation, when the certificate associated with a CSR has been imported into the NSS DB its orphan state will be removed.")}
-                                    <br /><br />
-                                    {_("Make sure an orphan key is not associated with a submitted CSR before you delete it.")}
-                                </p>
-                            </div>
-                        }
+                    content={
+                        <div>
+                            <p>
+                                {_("An orphan key is a private key in the NSS DB for which there is NO cert with the corresponding public key. An orphan key is created during CSR creation, when the certificate associated with a CSR has been imported into the NSS DB its orphan state will be removed.")}
+                                <br /><br />
+                                {_("Make sure an orphan key is not associated with a submitted CSR before you delete it.")}
+                            </p>
+                        </div>
+                    }
                 >
                     <a className="ds-font-size-sm">{_("What is an orphan key?")}</a>
                 </Tooltip>
-                <Table
+                <Table 
                     className="ds-margin-top"
                     aria-label="orph key table"
-                    cells={columns}
-                    key={rows}
-                    rows={rows}
-                    variant={TableVariant.compact}
-                    sortBy={sortBy}
-                    onSort={this.handleSort}
-                    actions={hasRows ? this.actions() : null}
-                    dropdownPosition="right"
-                    dropdownDirection="bottom"
+                    variant="compact"
                 >
-                    <TableHeader />
-                    <TableBody />
+                    <Thead>
+                        <Tr>
+                            {columns.map((column, idx) => (
+                                <Th 
+                                    key={idx}
+                                    sort={column.sortable ? {
+                                        sortBy,
+                                        onSort: this.handleSort,
+                                        columnIndex: idx
+                                    } : undefined}
+                                >
+                                    {column.title}
+                                </Th>
+                            ))}
+                            {hasRows && <Th screenReaderText="Actions" />}
+                        </Tr>
+                    </Thead>
+                    <Tbody>
+                        {tableRows.map((row, rowIndex) => (
+                            <Tr key={rowIndex}>
+                                {Array.isArray(row) ? (
+                                    row.map((cell, cellIndex) => (
+                                        <Td key={cellIndex}>{cell}</Td>
+                                    ))
+                                ) : (
+                                    row.cells.map((cell, cellIndex) => (
+                                        <Td key={cellIndex}>{cell}</Td>
+                                    ))
+                                )}
+                                {hasRows && (
+                                    <Td isActionCell>
+                                        <ActionsColumn 
+                                            items={this.getActionsForRow(row)}
+                                        />
+                                    </Td>
+                                )}
+                            </Tr>
+                        ))}
+                    </Tbody>
                 </Table>
                 {hasRows &&
                     <Pagination
-                        itemCount={this.state.rows.length}
+                        itemCount={rows.length}
                         widgetId="pagination-options-menu-bottom"
                         perPage={perPage}
                         page={page}
-                        variant={PaginationVariant.bottom}
+                        variant="bottom"
                         onSetPage={this.handleSetPage}
                         onPerPageSelect={this.handlePerPageSelect}
-                    />}
+                    />
+                }
             </div>
         );
     }
@@ -152,10 +199,10 @@ class CSRTable extends React.Component {
             sortBy: {},
             rows: [],
             columns: [
-                { title: _("Name"), transforms: [sortable] },
-                { title: _("Subject DN"), transforms: [sortable] },
-                { title: _("Subject Alternative Names"), transforms: [sortable] },
-                { title: _("Modification Date"), transforms: [sortable] },
+                { title: _("Name"), sortable: true },
+                { title: _("Subject DN"), sortable: true },
+                { title: _("Subject Alternative Names"), sortable: true },
+                { title: _("Modification Date"), sortable: true },
             ],
         };
 
@@ -177,7 +224,9 @@ class CSRTable extends React.Component {
     }
 
     handleSort(_event, index, direction) {
-        const sortedRows = this.state.rows.sort((a, b) => (a[index] < b[index] ? -1 : a[index] > b[index] ? 1 : 0));
+        const sortedRows = [...this.state.rows].sort((a, b) => 
+            (a[index] < b[index] ? -1 : a[index] > b[index] ? 1 : 0)
+        );
         this.setState({
             sortBy: {
                 index,
@@ -187,27 +236,37 @@ class CSRTable extends React.Component {
         });
     }
 
+    getActionsForRow = (rowData) => [
+        {
+            title: _("Delete CSR"),
+            onClick: () => this.props.delCSR(rowData[0])
+        },
+        {
+            title: _("View CSR"),
+            onClick: () => this.props.viewCSR(rowData[0])
+        }
+    ];
+
     componentDidMount() {
         let rows = [];
         let columns = this.state.columns;
         let hasRows = true;
 
         for (const ServerCSR of this.props.ServerCSRs) {
-            rows.push(
-                {
-                    isOpen: false,
-                    cells: [
-                        ServerCSR.attrs.name, ServerCSR.attrs.subject,
-                        ServerCSR.attrs.subject_alt_names.join(", "), ServerCSR.attrs.modified
-                    ],
-                },
-            );
+            rows.push([
+                ServerCSR.attrs.name,
+                ServerCSR.attrs.subject,
+                ServerCSR.attrs.subject_alt_names.join(", "),
+                ServerCSR.attrs.modified
+            ]);
         }
+
         if (rows.length === 0) {
             rows = [{ cells: [_("No Certificate Signing Requests")] }];
             columns = [{ title: _("Certificate Signing Requests") }];
             hasRows = false;
         }
+
         this.setState({
             rows,
             columns,
@@ -221,27 +280,19 @@ class CSRTable extends React.Component {
         for (const cert of this.props.ServerCSRs) {
             const val = value.toLowerCase();
 
-            // Check for matches of all the parts
             if (val !== "" && cert.attrs.name.toLowerCase().indexOf(val) === -1 &&
                 cert.attrs.subject.toLowerCase().indexOf(val) === -1 &&
-                cert.attrs.subject_alt_names.join().toLowerCase()
-                        .indexOf(val) === -1 &&
+                cert.attrs.subject_alt_names.join().toLowerCase().indexOf(val) === -1 &&
                 cert.attrs.modified.toLowerCase().indexOf(val) === -1) {
-                // Not a match
                 continue;
             }
 
-            rows.push(
-                {
-                    isOpen: false,
-                    cells: [
-                        cert.attrs.name, cert.attrs.subject,
-                        cert.attrs.subject_alt_names.join(", "),
-                        cert.attrs.modified
-                    ],
-
-                },
-            );
+            rows.push([
+                cert.attrs.name,
+                cert.attrs.subject,
+                cert.attrs.subject_alt_names.join(", "),
+                cert.attrs.modified
+            ]);
         }
 
         this.setState({
@@ -251,29 +302,9 @@ class CSRTable extends React.Component {
         });
     }
 
-    actions() {
-        return [
-            {
-                title: _("Delete CSR"),
-                onClick: (event, rowId, rowData, extra) => {
-                    if (rowData.cells.length > 1) {
-                        this.props.delCSR(rowData.cells[0]);
-                    }
-                }
-            },
-            {
-                title: _("View CSR"),
-                onClick: (event, rowId, rowData, extra) => {
-                    if (rowData.cells.length > 1) {
-                        this.props.viewCSR(rowData.cells[0]);
-                    }
-                }
-            }
-        ];
-    }
-
     render() {
         const { perPage, page, sortBy, rows, columns, hasRows } = this.state;
+        const tableRows = rows.slice((page - 1) * perPage, page * perPage);
 
         return (
             <div className="ds-margin-top-lg">
@@ -283,22 +314,52 @@ class CSRTable extends React.Component {
                         value={this.state.value}
                         onChange={this.handleSearchChange}
                         onClear={(evt) => this.handleSearchChange(evt, '')}
-                    />}
-                <Table
+                    />
+                }
+                <Table 
                     className="ds-margin-top"
                     aria-label="csr table"
-                    cells={columns}
-                    key={rows}
-                    rows={rows}
-                    variant={TableVariant.compact}
-                    sortBy={sortBy}
-                    onSort={this.handleSort}
-                    actions={hasRows ? this.actions() : null}
-                    dropdownPosition="right"
-                    dropdownDirection="bottom"
+                    variant="compact"
                 >
-                    <TableHeader />
-                    <TableBody />
+                    <Thead>
+                        <Tr>
+                            {columns.map((column, idx) => (
+                                <Th 
+                                    key={idx}
+                                    sort={column.sortable ? {
+                                        sortBy,
+                                        onSort: this.handleSort,
+                                        columnIndex: idx
+                                    } : undefined}
+                                >
+                                    {column.title}
+                                </Th>
+                            ))}
+                            {hasRows && <Th screenReaderText="Actions" />}
+                        </Tr>
+                    </Thead>
+                    <Tbody>
+                        {tableRows.map((row, rowIndex) => (
+                            <Tr key={rowIndex}>
+                                {Array.isArray(row) ? (
+                                    row.map((cell, cellIndex) => (
+                                        <Td key={cellIndex}>{cell}</Td>
+                                    ))
+                                ) : (
+                                    row.cells.map((cell, cellIndex) => (
+                                        <Td key={cellIndex}>{cell}</Td>
+                                    ))
+                                )}
+                                {hasRows && (
+                                    <Td isActionCell>
+                                        <ActionsColumn 
+                                            items={this.getActionsForRow(row)}
+                                        />
+                                    </Td>
+                                )}
+                            </Tr>
+                        ))}
+                    </Tbody>
                 </Table>
                 {hasRows &&
                     <Pagination
@@ -306,10 +367,11 @@ class CSRTable extends React.Component {
                         widgetId="pagination-options-menu-bottom"
                         perPage={perPage}
                         page={page}
-                        variant={PaginationVariant.bottom}
+                        variant="bottom"
                         onSetPage={this.handleSetPage}
                         onPerPageSelect={this.handlePerPageSelect}
-                    />}
+                    />
+                }
             </div>
         );
     }
@@ -330,11 +392,10 @@ class CertTable extends React.Component {
             columns: [
                 {
                     title: _("Nickname"),
-                    transforms: [sortable],
-                    cellFormatters: [expandable]
+                    sortable: true
                 },
-                { title: _("Subject DN"), transforms: [sortable] },
-                { title: _("Expiration Date"), transforms: [sortable] },
+                { title: _("Subject DN"), sortable: true },
+                { title: _("Expiration Date"), sortable: true },
             ],
         };
 
@@ -356,45 +417,47 @@ class CertTable extends React.Component {
         this.handleSearchChange = this.handleSearchChange.bind(this);
     }
 
-    handleSort(_event, index, direction) {
+    handleSort(_event, columnIndex, direction) {
         const sorted_rows = [];
         const rows = [];
         let count = 0;
 
-        // Convert the rows pairings into a sortable array based on the column indexes
+        // Convert the rows pairings into a sortable array
         for (let idx = 0; idx < this.state.rows.length; idx += 2) {
             sorted_rows.push({
                 expandedRow: this.state.rows[idx + 1],
-                1: this.state.rows[idx].cells[0],
-                2: this.state.rows[idx].cells[1],
-                3: this.state.rows[idx].cells[2],
+                1: this.state.rows[idx].cells[0].content,
+                2: this.state.rows[idx].cells[1].content,
+                3: this.state.rows[idx].cells[2].content,
                 issuer: this.state.rows[idx].issuer,
                 flags: this.state.rows[idx].flags
             });
         }
 
-        // Sort the rows and build the new rows
-        sorted_rows.sort((a, b) => (a[index] > b[index]) ? 1 : -1);
+        sorted_rows.sort((a, b) => (a[columnIndex + 1] > b[columnIndex + 1]) ? 1 : -1);
         if (direction !== SortByDirection.asc) {
             sorted_rows.reverse();
         }
+
         for (const srow of sorted_rows) {
             rows.push({
                 isOpen: false,
                 cells: [
-                    srow[1], srow[2], srow[3]
+                    { content: srow[1] },
+                    { content: srow[2] },
+                    { content: srow[3] }
                 ],
                 issuer: srow.issuer,
                 flags: srow.flags,
             });
-            srow.expandedRow.parent = count; // reset parent idx
+            srow.expandedRow.parent = count;
             rows.push(srow.expandedRow);
             count += 2;
         }
 
         this.setState({
             sortBy: {
-                index,
+                index: columnIndex,
                 direction
             },
             rows,
@@ -409,7 +472,6 @@ class CertTable extends React.Component {
                 <GridItem span={9}><b>{issuer}</b></GridItem>
                 <GridItem span={3}>{_("Trust Flags:")}</GridItem>
                 <GridItem span={9}><b>{flags}</b></GridItem>
-
             </Grid>
         );
     }
@@ -421,24 +483,21 @@ class CertTable extends React.Component {
         let hasRows = true;
 
         for (const cert of this.props.certs) {
-            rows.push(
-                {
-                    isOpen: false,
-                    cells: [cert.attrs.nickname, cert.attrs.subject, cert.attrs.expires],
-                    issuer: cert.attrs.issuer,
-                    flags: cert.attrs.flags,
-
-                },
-                {
-                    parent: count,
-                    fullWidth: true,
-                    cells: [{ title: this.getExpandedRow(cert.attrs.issuer, cert.attrs.flags) }]
-                },
-            );
-            count += 2;
+            rows.push({
+                isOpen: false,
+                cells: [
+                    { content: cert.attrs.nickname },
+                    { content: cert.attrs.subject },
+                    { content: cert.attrs.expires }
+                ],
+                issuer: cert.attrs.issuer,
+                flags: cert.attrs.flags,
+                originalData: cert.attrs  // Store the original data for expansion
+            });
+            count += 1;
         }
         if (rows.length === 0) {
-            rows = [{ cells: [_("No Certificates")] }];
+            rows = [{ cells: [{ content: _("No Certificates") }] }];
             columns = [{ title: _("Certificates") }];
             hasRows = false;
         }
@@ -449,13 +508,11 @@ class CertTable extends React.Component {
         });
     }
 
-    handleCollapse(event, rowKey, isOpen) {
-        const { rows, perPage, page } = this.state;
-        const index = (perPage * (page - 1) * 2) + rowKey; // Adjust for page set
-        rows[index].isOpen = isOpen;
-        this.setState({
-            rows
-        });
+    handleCollapse(_event, rowIndex, isExpanding) {
+        const rows = [...this.state.rows];
+        const index = (this.state.perPage * (this.state.page - 1) * 2) + rowIndex;
+        rows[index].isOpen = isExpanding;
+        this.setState({ rows });
     }
 
     handleSearchChange(event, value) {
@@ -498,39 +555,28 @@ class CertTable extends React.Component {
         });
     }
 
-    actions() {
-        return [
-            {
-                title: _("Edit Trust Flags"),
-                onClick: (event, rowId, rowData, extra) =>
-                    this.props.editCert(rowData.cells[0], rowData.flags)
-            },
-            {
-                title: _("Export Certificate"),
-                onClick: (event, rowId, rowData, extra) =>
-                    this.props.exportCert(rowData.cells[0])
-            },
-            {
-                isSeparator: true
-            },
-            {
-                title: _("Delete Certificate"),
-                onClick: (event, rowId, rowData, extra) =>
-                    this.props.delCert(rowData.cells[0])
-            }
-        ];
-    }
+    getActionsForRow = (rowData) => [
+        {
+            title: _("Edit Trust Flags"),
+            onClick: () => this.props.editCert(rowData.cells[0].content, rowData.flags)
+        },
+        {
+            title: _("Export Certificate"),
+            onClick: () => this.props.exportCert(rowData.cells[0].content)
+        },
+        {
+            isSeparator: true
+        },
+        {
+            title: _("Delete Certificate"),
+            onClick: () => this.props.delCert(rowData.cells[0].content)
+        }
+    ];
 
     render() {
         const { perPage, page, sortBy, rows, columns, hasRows } = this.state;
-        const origRows = [...rows];
         const startIdx = ((perPage * page) - perPage) * 2;
-        const tableRows = origRows.splice(startIdx, perPage * 2);
-
-        for (let idx = 1, count = 0; idx < tableRows.length; idx += 2, count += 2) {
-            // Rewrite parent index to match new spliced array
-            tableRows[idx].parent = count;
-        }
+        const tableRows = rows.slice(startIdx, startIdx + (perPage * 2));
 
         return (
             <div className="ds-margin-top-lg">
@@ -541,22 +587,62 @@ class CertTable extends React.Component {
                         onChange={this.handleSearchChange}
                         onClear={(evt) => this.handleSearchChange(evt, '')}
                     />}
-                <Table
-                    className="ds-margin-top"
+                <Table 
                     aria-label="cert table"
-                    cells={columns}
-                    key={tableRows}
-                    rows={tableRows}
-                    variant={TableVariant.compact}
-                    sortBy={sortBy}
-                    onSort={this.handleSort}
-                    onCollapse={this.handleCollapse}
-                    actions={hasRows ? this.actions() : null}
-                    dropdownPosition="right"
-                    dropdownDirection="bottom"
+                    variant='compact'
                 >
-                    <TableHeader />
-                    <TableBody />
+                    <Thead>
+                        <Tr>
+                            <Th screenReaderText="Row expansion" />
+                            {columns.map((column, columnIndex) => (
+                                <Th
+                                    key={columnIndex}
+                                    sort={column.sortable ? {
+                                        sortBy,
+                                        onSort: this.handleSort,
+                                        columnIndex
+                                    } : undefined}
+                                >
+                                    {column.title}
+                                </Th>
+                            ))}
+                            <Th screenReaderText="Actions" />
+                        </Tr>
+                    </Thead>
+                    <Tbody>
+                        {tableRows.map((row, rowIndex) => (
+                            <React.Fragment key={rowIndex}>
+                                <Tr>
+                                    <Td
+                                        expand={{
+                                            rowIndex,
+                                            isExpanded: row.isOpen,
+                                            onToggle: () => this.handleCollapse(null, rowIndex, !row.isOpen)
+                                        }}
+                                    />
+                                    {row.cells.map((cell, cellIndex) => (
+                                        <Td key={cellIndex}>
+                                            {cell.content}
+                                        </Td>
+                                    ))}
+                                    <Td isActionCell>
+                                        <ActionsColumn 
+                                            items={this.getActionsForRow(row)}
+                                        />
+                                    </Td>
+                                </Tr>
+                                {row.isOpen && (
+                                    <Tr isExpanded={true}>
+                                        <Td colSpan={columns.length + 2}>
+                                            <ExpandableRowContent>
+                                                {this.getExpandedRow(row.issuer, row.flags)}
+                                            </ExpandableRowContent>
+                                        </Td>
+                                    </Tr>
+                                )}
+                            </React.Fragment>
+                        ))}
+                    </Tbody>
                 </Table>
                 {hasRows &&
                     <Pagination
@@ -564,7 +650,7 @@ class CertTable extends React.Component {
                         widgetId="pagination-options-menu-bottom"
                         perPage={perPage}
                         page={page}
-                        variant={PaginationVariant.bottom}
+                        variant="bottom"
                         onSetPage={this.handleSetPage}
                         onPerPageSelect={this.handlePerPageSelect}
                     />}
@@ -584,13 +670,12 @@ class CRLTable extends React.Component {
             value: '',
             sortBy: {},
             rows: [],
-            dropdownIsOpen: false,
             hasRows: false,
             columns: [
-                { title: _("Issued By"), transforms: [sortable] },
-                { title: _("Effective Date"), transforms: [sortable] },
-                { title: _("Next Update"), transforms: [sortable] },
-                { title: _("Type"), transforms: [sortable] },
+                { title: _("Issued By"), sortable: true },
+                { title: _("Effective Date"), sortable: true },
+                { title: _("Next Update"), sortable: true },
+                { title: _("Type"), sortable: true },
             ],
         };
 
@@ -610,37 +695,48 @@ class CRLTable extends React.Component {
         this.handleSearchChange = this.handleSearchChange.bind(this);
     }
 
+    getActionsForRow = (rowData) => [
+        {
+            title: _("View CRL"),
+            onClick: () => this.props.editConfig(rowData.cells[0], rowData.cells[1], rowData.credsBindpw, rowData.pwInteractive)
+        },
+        {
+            title: _("Delete CRL"),
+            onClick: () => this.props.deleteConfig(rowData.cells[0])
+        }
+    ];
+
     handleSort(_event, index, direction) {
         const sorted_rows = [];
         const rows = [];
         let count = 0;
 
-        // Convert the rows pairings into a sortable array based on the column indexes
+        // Convert the rows pairings into a sortable array
         for (let idx = 0; idx < this.state.rows.length; idx += 2) {
             sorted_rows.push({
                 1: this.state.rows[idx].cells[0],
                 2: this.state.rows[idx].cells[1],
                 3: this.state.rows[idx].cells[2],
                 issuer: this.state.rows[idx].issuer,
-                flags: this.state.rows[idx].flags
+                flags: this.state.rows[idx].flags,
+                expandedRow: this.state.rows[idx + 1]
             });
         }
 
-        // Sort the rows and build the new rows
+        // Sort and rebuild rows
         sorted_rows.sort((a, b) => (a[index] > b[index]) ? 1 : -1);
         if (direction !== SortByDirection.asc) {
             sorted_rows.reverse();
         }
+        
         for (const srow of sorted_rows) {
             rows.push({
                 isOpen: false,
-                cells: [
-                    srow[1], srow[2], srow[3]
-                ],
+                cells: [srow[1], srow[2], srow[3]],
                 issuer: srow.issuer,
                 flags: srow.flags,
             });
-            srow.expandedRow.parent = count; // reset parent idx
+            srow.expandedRow.parent = count;
             rows.push(srow.expandedRow);
             count += 2;
         }
@@ -696,22 +792,12 @@ class CRLTable extends React.Component {
         });
     }
 
-    actions() {
-        return [
-            {
-                title: _("View CRL"),
-                onClick: (event, rowId, rowData, extra) =>
-                    this.props.editConfig(rowData.cells[0], rowData.cells[1], rowData.credsBindpw, rowData.pwInteractive)
-            },
-            {
-                title: _("Delete CRL"),
-                onClick: (event, rowId, rowData, extra) =>
-                    this.props.deleteConfig(rowData.cells[0])
-            }
-        ];
-    }
-
     render() {
+        const tableRows = this.state.rows.slice(
+            (this.state.page - 1) * this.state.perPage,
+            this.state.page * this.state.perPage
+        );
+
         return (
             <div className="ds-margin-top">
                 <SearchInput
@@ -720,27 +806,66 @@ class CRLTable extends React.Component {
                     onChange={this.handleSearchChange}
                     onClear={(evt) => this.handleSearchChange(evt, '')}
                 />
-                <Table
-                    variant={TableVariant.compact} aria-label="Cred Table"
-                    sortBy={this.sortBy} onSort={this.handleSort} cells={this.state.columns}
-                    rows={this.state.rows}
-                    actions={this.state.hasRows ? this.actions() : null}
-                    dropdownPosition="right"
-                    dropdownDirection="bottom"
+                <Table 
+                    aria-label="CRL Table"
+                    variant="compact"
                 >
-                    <TableHeader />
-                    <TableBody />
+                    <Thead>
+                        <Tr>
+                            {this.state.columns.map((column, idx) => (
+                                <Th 
+                                    key={idx}
+                                    sort={column.sortable ? {
+                                        sortBy: this.state.sortBy,
+                                        onSort: this.handleSort,
+                                        columnIndex: idx
+                                    } : undefined}
+                                >
+                                    {column.title}
+                                </Th>
+                            ))}
+                            {this.state.hasRows && <Th screenReaderText="Actions" />}
+                        </Tr>
+                    </Thead>
+                    <Tbody>
+                        {tableRows.map((row, rowIndex) => (
+                            <React.Fragment key={rowIndex}>
+                                <Tr>
+                                    {row.cells.map((cell, cellIndex) => (
+                                        <Td key={cellIndex}>{cell}</Td>
+                                    ))}
+                                    {this.state.hasRows && (
+                                        <Td isActionCell>
+                                            <ActionsColumn 
+                                                items={this.getActionsForRow(row)}
+                                            />
+                                        </Td>
+                                    )}
+                                </Tr>
+                                {row.isOpen && (
+                                    <Tr isExpanded>
+                                        <Td colSpan={this.state.columns.length + 1}>
+                                            <ExpandableRowContent>
+                                                {this.getExpandedRow(row.issuer, row.flags)}
+                                            </ExpandableRowContent>
+                                        </Td>
+                                    </Tr>
+                                )}
+                            </React.Fragment>
+                        ))}
+                    </Tbody>
                 </Table>
-                {this.state.hasRows &&
+                {this.state.hasRows && (
                     <Pagination
                         itemCount={this.state.rows.length}
                         widgetId="pagination-options-menu-bottom"
                         perPage={this.state.perPage}
                         page={this.state.page}
-                        variant={PaginationVariant.bottom}
+                        variant="bottom"
                         onSetPage={this.handleSetPage}
                         onPerPageSelect={this.handlePerPageSelect}
-                    />}
+                    />
+                )}
             </div>
         );
     }
