@@ -25,15 +25,13 @@ import {
 } from "@patternfly/react-core";
 import {
     Table,
-    TableHeader,
-    TableBody,
-    TableVariant
+    Thead,
+    Tr,
+    Th,
+    Tbody,
+    Td,
 } from '@patternfly/react-table';
-import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
-import {
-    faSyncAlt
-} from '@fortawesome/free-solid-svg-icons';
-import '@fortawesome/fontawesome-svg-core/styles.css';
+import { SyncAltIcon } from '@patternfly/react-icons';
 import PropTypes from "prop-types";
 
 const settings_attrs = [
@@ -41,6 +39,8 @@ const settings_attrs = [
     'nsslapd-accesslog-level',
     'nsslapd-accesslog-logbuffering',
     'nsslapd-accesslog-logging-enabled',
+    'nsslapd-accesslog-log-format',
+    'nsslapd-accesslog-time-format',
 ];
 
 const rotation_attrs = [
@@ -107,7 +107,7 @@ export class ServerAccessLog extends React.Component {
             });
         };
 
-        this.handleOnToggle = isExpanded => {
+        this.handleOnToggle = (_event, isExpanded) => {
             this.setState({
                 isExpanded
             });
@@ -381,6 +381,8 @@ export class ServerAccessLog extends React.Component {
                         'nsslapd-accesslog-maxlogsize': attrs['nsslapd-accesslog-maxlogsize'][0],
                         'nsslapd-accesslog-maxlogsperdir': attrs['nsslapd-accesslog-maxlogsperdir'][0],
                         'nsslapd-accesslog-compress': compress,
+                        'nsslapd-accesslog-log-format': attrs['nsslapd-accesslog-log-format'][0],
+                        'nsslapd-accesslog-time-format': attrs['nsslapd-accesslog-time-format'][0],
                         rows,
                         // Record original values
                         _rows:  JSON.parse(JSON.stringify(rows)),
@@ -400,6 +402,8 @@ export class ServerAccessLog extends React.Component {
                         '_nsslapd-accesslog-maxlogsize': attrs['nsslapd-accesslog-maxlogsize'][0],
                         '_nsslapd-accesslog-maxlogsperdir': attrs['nsslapd-accesslog-maxlogsperdir'][0],
                         '_nsslapd-accesslog-compress': compress,
+                        '_nsslapd-accesslog-log-format': attrs['nsslapd-accesslog-log-format'][0],
+                        '_nsslapd-accesslog-time-format': attrs['nsslapd-accesslog-time-format'][0],
                     });
                 })
                 .fail(err => {
@@ -462,6 +466,8 @@ export class ServerAccessLog extends React.Component {
             'nsslapd-accesslog-maxlogsize': attrs['nsslapd-accesslog-maxlogsize'][0],
             'nsslapd-accesslog-maxlogsperdir': attrs['nsslapd-accesslog-maxlogsperdir'][0],
             'nsslapd-accesslog-compress': compress,
+            'nsslapd-accesslog-log-format': attrs['nsslapd-accesslog-log-format'][0],
+            'nsslapd-accesslog-time-format': attrs['nsslapd-accesslog-time-format'][0],
             rows,
             // Record original values
             _rows: JSON.parse(JSON.stringify(rows)),
@@ -481,6 +487,8 @@ export class ServerAccessLog extends React.Component {
             '_nsslapd-accesslog-maxlogsize': attrs['nsslapd-accesslog-maxlogsize'][0],
             '_nsslapd-accesslog-maxlogsperdir': attrs['nsslapd-accesslog-maxlogsperdir'][0],
             '_nsslapd-accesslog-compress': compress,
+            '_nsslapd-accesslog-log-format': attrs['nsslapd-accesslog-log-format'][0],
+            '_nsslapd-accesslog-time-format': attrs['nsslapd-accesslog-time-format'][0],
         }, this.props.enableTree);
     }
 
@@ -542,6 +550,12 @@ export class ServerAccessLog extends React.Component {
         }
         rotationTime = hour + ":" + min;
 
+        const time_format_title = (
+            <>
+                {_("Time Format")} <font size="1">({_("JSON only")})</font>
+            </>
+        );
+
         let body = (
             <div className="ds-margin-top-lg ds-left-margin">
                 <Tabs className="ds-margin-top-xlg" activeKey={this.state.activeTabKey} onSelect={this.handleNavSelect}>
@@ -550,7 +564,7 @@ export class ServerAccessLog extends React.Component {
                             className="ds-margin-top-xlg"
                             id="nsslapd-accesslog-logging-enabled"
                             isChecked={this.state['nsslapd-accesslog-logging-enabled']}
-                            onChange={(checked, e) => {
+                            onChange={(e, checked) => {
                                 this.handleChange(e, "settings");
                             }}
                             title={_("Enable access logging (nsslapd-accesslog-logging-enabled).")}
@@ -568,17 +582,51 @@ export class ServerAccessLog extends React.Component {
                                     id="nsslapd-accesslog"
                                     aria-describedby="horizontal-form-name-helper"
                                     name="nsslapd-accesslog"
-                                    onChange={(str, e) => {
+                                    onChange={(e, str) => {
                                         this.handleChange(e, "settings");
                                     }}
                                 />
                             </FormGroup>
+                            <FormGroup
+                                label={time_format_title}
+                                fieldId="nsslapd-accesslog-time-format"
+                                title={_("Time format using strftime formatting (nsslapd-accesslog-time-format). This only applies to the JSON log format")}
+                            >
+                                <TextInput
+                                    value={this.state['nsslapd-accesslog-time-format']}
+                                    type="text"
+                                    id="nsslapd-accesslog-time-format"
+                                    aria-describedby="horizontal-form-name-helper"
+                                    name="nsslapd-accesslog-time-format"
+                                    onChange={(e, str) => {
+                                        this.handleChange(e, "settings");
+                                    }}
+                                />
+                            </FormGroup>
+                            <FormGroup
+                                label={_("Log Format")}
+                                fieldId="nsslapd-accesslog-log-format"
+                                title={_("Choose the log format (nsslapd-accesslog-log-format).")}
+                            >
+                                <FormSelect
+                                    id="nsslapd-accesslog-log-format"
+                                    value={this.state['nsslapd-accesslog-log-format']}
+                                    onChange={(e, str) => {
+                                        this.handleChange(e, "settings");
+                                    }}
+                                    aria-label="FormSelect Input"
+                                >
+                                    <FormSelectOption key="0" value="default" label="Default" />
+                                    <FormSelectOption key="1" value="json" label="JSON" />
+                                    <FormSelectOption key="2" value="json-pretty" label="JSON (pretty)" />
+                                </FormSelect>
+                            </FormGroup>
                         </Form>
                         <Checkbox
                             className="ds-left-margin-md ds-margin-top-lg"
                             id="nsslapd-accesslog-logbuffering"
                             isChecked={this.state['nsslapd-accesslog-logbuffering']}
-                            onChange={(checked, e) => {
+                            onChange={(e, checked) => {
                                 this.handleChange(e, "settings");
                             }}
                             title={_("Disable access log buffering for faster troubleshooting, but this will impact server performance (nsslapd-accesslog-logbuffering).")}
@@ -591,17 +639,30 @@ export class ServerAccessLog extends React.Component {
                             onToggle={this.handleOnToggle}
                             isExpanded={this.state.isExpanded}
                         >
-                            <Table
-                                className="ds-left-margin"
-                                onSelect={this.handleOnSelect}
-                                canSelectAll={this.state.canSelectAll}
-                                variant={TableVariant.compact}
-                                aria-label="Selectable Table"
-                                cells={this.state.columns}
-                                rows={this.state.rows}
-                            >
-                                <TableHeader />
-                                <TableBody />
+                            <Table aria-label="Selectable Table" variant="compact">
+                                <Thead>
+                                    <Tr>
+                                        <Th screenReaderText="Checkboxes" />
+                                        <Th>{this.state.columns[0].title}</Th>
+                                    </Tr>
+                                </Thead>
+                                <Tbody>
+                                    {this.state.rows.map((row, rowIndex) => (
+                                        <Tr key={rowIndex}>
+                                            <Td
+                                                select={{
+                                                    rowIndex,
+                                                    onSelect: (_event, isSelecting) =>
+                                                        this.handleOnSelect(_event, isSelecting, rowIndex),
+                                                    isSelected: row.selected
+                                                }}
+                                            />
+                                            <Td>
+                                                {row.cells[0].title}
+                                            </Td>
+                                        </Tr>
+                                    ))}
+                                </Tbody>
                             </Table>
                         </ExpandableSection>
 
@@ -689,7 +750,7 @@ export class ServerAccessLog extends React.Component {
                                             <FormSelect
                                                 id="nsslapd-accesslog-logrotationtimeunit"
                                                 value={this.state['nsslapd-accesslog-logrotationtimeunit']}
-                                                onChange={(str, e) => {
+                                                onChange={(e, str) => {
                                                     this.handleChange(e, "rotation");
                                                 }}
                                                 aria-label="FormSelect Input"
@@ -724,7 +785,7 @@ export class ServerAccessLog extends React.Component {
                                     <Switch
                                         id="nsslapd-accesslog-compress"
                                         isChecked={this.state['nsslapd-accesslog-compress']}
-                                        onChange={this.handleSwitchChange}
+                                        onChange={(_event, value) => this.handleSwitchChange(value)}
                                         aria-label="nsslapd-accesslog-compress"
                                     />
                                 </GridItem>
@@ -818,7 +879,7 @@ export class ServerAccessLog extends React.Component {
                                             <FormSelect
                                                 id="nsslapd-accesslog-logexpirationtimeunit"
                                                 value={this.state['nsslapd-accesslog-logexpirationtimeunit']}
-                                                onChange={(str, e) => {
+                                                onChange={(e, str) => {
                                                     this.handleChange(e, "exp");
                                                 }}
                                                 aria-label="FormSelect Input"
@@ -869,15 +930,15 @@ export class ServerAccessLog extends React.Component {
                         <TextContent>
                             <Text component={TextVariants.h3}>
                                 {_("Access Log Settings")}
-                                <FontAwesomeIcon
-                                    size="lg"
-                                    className="ds-left-margin ds-refresh"
-                                    icon={faSyncAlt}
-                                    title={_("Refresh log settings")}
+                                <Button
+                                    variant="plain"
+                                    aria-label={_("Refresh log settings")}
                                     onClick={() => {
                                         this.refreshConfig();
                                     }}
-                                />
+                                >
+                                    <SyncAltIcon />
+                                </Button>
                             </Text>
                         </TextContent>
                     </GridItem>
