@@ -2,34 +2,32 @@ import cockpit from "cockpit";
 import React from "react";
 import { listsEqual, log_cmd } from "../tools.jsx";
 import {
-    Button,
-    Checkbox,
-    Form,
-    FormGroup,
-    FormSelect,
-    FormSelectOption,
-    Grid,
-    GridItem,
-    NumberInput,
-    Select,
-    SelectVariant,
-    SelectOption,
-    Spinner,
-    Switch,
-    Tab,
-    Tabs,
-    TabTitleText,
-    TextInput,
-    Text,
-    TextContent,
-    TextVariants,
-    TimePicker,
-} from "@patternfly/react-core";
-import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
+	Button,
+	Checkbox,
+	Form,
+	FormGroup,
+	FormSelect,
+	FormSelectOption,
+	Grid,
+	GridItem,
+	NumberInput,
+	Spinner,
+	Switch,
+	Tab,
+	Tabs,
+	TabTitleText,
+	TextInput,
+	Text,
+	TextContent,
+	TextVariants,
+	TimePicker
+} from '@patternfly/react-core';
 import {
-    faSyncAlt
-} from '@fortawesome/free-solid-svg-icons';
-import '@fortawesome/fontawesome-svg-core/styles.css';
+	Select,
+	SelectVariant,
+	SelectOption
+} from '@patternfly/react-core/deprecated';
+import { SyncAltIcon } from '@patternfly/react-icons';
 import PropTypes from "prop-types";
 
 const settings_attrs = [
@@ -110,7 +108,7 @@ export class ServerAuditLog extends React.Component {
                 );
             }
         };
-        this.handleOnDisplayAttrToggle = isDisplayAttrOpen => {
+        this.handleOnDisplayAttrToggle = (_event, isDisplayAttrOpen) => {
             this.setState({
                 isDisplayAttrOpen
             });
@@ -525,6 +523,12 @@ export class ServerAuditLog extends React.Component {
         }
         rotationTime = hour + ":" + min;
 
+        const time_format_title = (
+            <>
+                {_("Time Format")} <font size="1">({_("JSON only")})</font>
+            </>
+        );
+
         let body = (
             <div className="ds-margin-top-lg ds-left-margin">
                 <Tabs className="ds-margin-top-xlg" activeKey={this.state.activeTabKey} onSelect={this.handleNavSelect}>
@@ -533,7 +537,7 @@ export class ServerAuditLog extends React.Component {
                             className="ds-margin-top-xlg"
                             id="nsslapd-auditlog-logging-enabled"
                             isChecked={this.state['nsslapd-auditlog-logging-enabled']}
-                            onChange={(checked, e) => {
+                            onChange={(e, checked) => {
                                 this.handleChange(e, "settings");
                             }}
                             title={_("Enable audit logging (nsslapd-auditlog-logging-enabled).")}
@@ -551,15 +555,15 @@ export class ServerAuditLog extends React.Component {
                                     id="nsslapd-auditlog"
                                     aria-describedby="horizontal-form-name-helper"
                                     name="nsslapd-auditlog"
-                                    onChange={(str, e) => {
+                                    onChange={(e, str) => {
                                         this.handleChange(e, "settings");
                                     }}
                                 />
                             </FormGroup>
                             <FormGroup
-                                label="Time Format"
+                                label={time_format_title}
                                 fieldId="nsslapd-auditlog-time-format"
-                                title="Time format using strftime formatting (nsslapd-auditlog-time-format)."
+                                title={_("Time format using strftime formatting (nsslapd-auditlog-time-format). This only applies to the JSON log format")}
                             >
                                 <TextInput
                                     value={this.state['nsslapd-auditlog-time-format']}
@@ -567,20 +571,20 @@ export class ServerAuditLog extends React.Component {
                                     id="nsslapd-auditlog-time-format"
                                     aria-describedby="horizontal-form-name-helper"
                                     name="nsslapd-auditlog-time-format"
-                                    onChange={(str, e) => {
+                                    onChange={(e, str) => {
                                         this.handleChange(e, "settings");
                                     }}
                                 />
                             </FormGroup>
                             <FormGroup
-                                label="Log Format"
+                                label={_("Log Format")}
                                 fieldId="nsslapd-auditlog-log-format"
-                                title="Choose the log format (nsslapd-auditlog-log-format)."
+                                title={_("Choose the log format (nsslapd-auditlog-log-format).")}
                             >
                                 <FormSelect
                                     id="nsslapd-auditlog-log-format"
                                     value={this.state['nsslapd-auditlog-log-format']}
-                                    onChange={(str, e) => {
+                                    onChange={(e, str) => {
                                         this.handleChange(e, "settings");
                                     }}
                                     aria-label="FormSelect Input"
@@ -601,7 +605,7 @@ export class ServerAuditLog extends React.Component {
                                     <Select
                                         variant={SelectVariant.typeaheadMulti}
                                         typeAheadAriaLabel="Type an attribute"
-                                        onToggle={this.handleOnDisplayAttrToggle}
+                                        onToggle={(event, isOpen) => this.handleOnDisplayAttrToggle(event, isOpen)}
                                         onSelect={this.handleOnDisplayAttrSelect}
                                         onClear={this.handleOnDisplayAttrClear}
                                         selections={this.state.displayAttrs}
@@ -622,7 +626,7 @@ export class ServerAuditLog extends React.Component {
                                     className="ds-lower-field-md"
                                     id="displayAllAttrs"
                                     isChecked={this.state.displayAllAttrs}
-                                    onChange={(checked, e) => {
+                                    onChange={(e, checked) => {
                                         this.handleChange(e, "settings");
                                     }}
                                     title={_("Display all attributes from the entry in the audit log (nsslapd-auditlog-display-attrs).")}
@@ -634,7 +638,7 @@ export class ServerAuditLog extends React.Component {
                             className="ds-left-margin-md ds-margin-top-lg"
                             id="nsslapd-auditlog-logbuffering"
                             isChecked={this.state['nsslapd-auditlog-logbuffering']}
-                            onChange={(checked, e) => {
+                            onChange={(e, checked) => {
                                 this.handleChange(e, "settings");
                             }}
                             title={_("This applies to both the audit & auditfail logs.  Disable audit log buffering for faster troubleshooting, but this will impact server performance (nsslapd-auditlog-logbuffering).")}
@@ -724,7 +728,7 @@ export class ServerAuditLog extends React.Component {
                                             <FormSelect
                                                 id="nsslapd-auditlog-logrotationtimeunit"
                                                 value={this.state['nsslapd-auditlog-logrotationtimeunit']}
-                                                onChange={(str, e) => {
+                                                onChange={(e, str) => {
                                                     this.handleChange(e, "rotation");
                                                 }}
                                                 aria-label="FormSelect Input"
@@ -759,7 +763,7 @@ export class ServerAuditLog extends React.Component {
                                     <Switch
                                         id="nsslapd-auditlog-compress"
                                         isChecked={this.state['nsslapd-auditlog-compress']}
-                                        onChange={this.handleSwitchChange}
+                                        onChange={(_event, value) => this.handleSwitchChange(value)}
                                         aria-label="nsslapd-auditlog-compress"
                                     />`
                                 </GridItem>
@@ -853,7 +857,7 @@ export class ServerAuditLog extends React.Component {
                                             <FormSelect
                                                 id="nsslapd-auditlog-logexpirationtimeunit"
                                                 value={this.state['nsslapd-auditlog-logexpirationtimeunit']}
-                                                onChange={(str, e) => {
+                                                onChange={(e, str) => {
                                                     this.handleChange(e, "exp");
                                                 }}
                                                 aria-label="FormSelect Input"
@@ -904,15 +908,15 @@ export class ServerAuditLog extends React.Component {
                         <TextContent>
                             <Text component={TextVariants.h3}>
                                 {_("Audit Log Settings")}
-                                <FontAwesomeIcon
-                                    size="lg"
-                                    className="ds-left-margin ds-refresh"
-                                    icon={faSyncAlt}
-                                    title={_("Refresh log settings")}
+                                <Button 
+                                    variant="plain"
+                                    aria-label={_("Refresh log settings")}
                                     onClick={() => {
                                         this.refreshConfig();
                                     }}
-                                />
+                                >
+                                    <SyncAltIcon />
+                                </Button>
                             </Text>
                         </TextContent>
                     </GridItem>
