@@ -70,14 +70,14 @@ export class SASLMappingModal extends React.Component {
                                 id="saslMapName"
                                 aria-describedby="horizontal-form-name-helper"
                                 name="saslMapName"
-                                onChange={(str, e) => {
+                                onChange={(e, str) => {
                                     this.props.handleChange(e);
                                 }}
                                 validated={this.props.error.saslMapName ? ValidatedOptions.error : ValidatedOptions.default}
                                 isRequired
                                 isDisabled={this.props.type === "Edit"}
                             />
-                            <FormHelperText isError isHidden={!this.props.error.saslMapName}>
+                            <FormHelperText  >
                                 {_("You must provide a name for this mapping")}
                             </FormHelperText>
                         </GridItem>
@@ -95,13 +95,13 @@ export class SASLMappingModal extends React.Component {
                                 id="saslMapRegex"
                                 aria-describedby="horizontal-form-name-helper"
                                 name="saslMapRegex"
-                                onChange={(str, e) => {
+                                onChange={(e, str) => {
                                     this.props.handleChange(e);
                                 }}
                                 isRequired
                                 validated={this.props.error.saslMapRegex ? ValidatedOptions.error : ValidatedOptions.default}
                             />
-                            <FormHelperText isError isHidden={!this.props.error.saslMapRegex}>
+                            <FormHelperText  >
                                 {_("You must provide a valid regular expression")}
                             </FormHelperText>
                         </GridItem>
@@ -119,7 +119,7 @@ export class SASLMappingModal extends React.Component {
                                 id="saslTestText"
                                 aria-describedby="horizontal-form-name-helper"
                                 name="saslTestText"
-                                onChange={(str, e) => {
+                                onChange={(e, str) => {
                                     this.props.handleChange(e);
                                 }}
                                 placeholder={_("Enter text to test regex")}
@@ -149,13 +149,13 @@ export class SASLMappingModal extends React.Component {
                                 id="saslBase"
                                 aria-describedby="horizontal-form-name-helper"
                                 name="saslBase"
-                                onChange={(str, e) => {
+                                onChange={(e, str) => {
                                     this.props.handleChange(e);
                                 }}
                                 isRequired
                                 validated={this.props.error.saslBase ? ValidatedOptions.error : ValidatedOptions.default}
                             />
-                            <FormHelperText isError isHidden={!this.props.error.saslBase}>
+                            <FormHelperText  >
                                 {_("You must provide a search base")}
                             </FormHelperText>
                         </GridItem>
@@ -173,13 +173,13 @@ export class SASLMappingModal extends React.Component {
                                 id="saslFilter"
                                 aria-describedby="horizontal-form-name-helper"
                                 name="saslFilter"
-                                onChange={(str, e) => {
+                                onChange={(e, str) => {
                                     this.props.handleChange(e);
                                 }}
                                 isRequired
                                 validated={this.props.error.saslFilter ? ValidatedOptions.error : ValidatedOptions.default}
                             />
-                            <FormHelperText isError isHidden={!this.props.error.saslFilter}>
+                            <FormHelperText  >
                                 {_("You must provide an LDAP search filter")}
                             </FormHelperText>
                         </GridItem>
@@ -197,12 +197,12 @@ export class SASLMappingModal extends React.Component {
                                 id="saslPriority"
                                 aria-describedby="horizontal-form-name-helper"
                                 name="saslPriority"
-                                onChange={(str, e) => {
+                                onChange={(e, str) => {
                                     this.props.handleChange(e);
                                 }}
                                 validated={this.props.error.saslPriority ? ValidatedOptions.error : ValidatedOptions.default}
                             />
-                            <FormHelperText isError isHidden={!this.props.error.saslPriority}>
+                            <FormHelperText  >
                                 {_("Priority must be between 1 and 100")}
                             </FormHelperText>
                         </GridItem>
