@@ -10,16 +10,23 @@
 # This module handles dsconf libdb sub-commands
 #
 
+import sys
 import os
-import re
 import glob
+import pwd
+import re
 import shutil
-from lib389.dseldif import DSEldif
 import subprocess
+from enum import Enum
+from errno import ENOSPC
+from lib389.cli_base import CustomHelpFormatter
+from lib389._constants import DEFAULT_LMDB_SIZE, BDB_IMPL_STATUS, DN_CONFIG
+from lib389.dseldif import DSEldif
+from lib389.utils import parse_size, format_size, check_plugin_strings, find_plugin_path
+from pathlib import Path
 
 
 DBLIB_LDIF_PREFIX = "__dblib-"
-DEFAULT_DBMAP_SIZE = 2 * 1024 * 1024 * 1024
 DBSIZE_MARGIN = 1.2
 DBI_MARGIN = 60
 
@@ -28,6 +35,7 @@ MDB_MAP = "data.mdb"
 MDB_LOCK = "lock.mdb"
 
 LDBM_DN = "cn=config,cn=ldbm database,cn=plugins,cn=config"
+CL5DB='replication_changelog.db'
 
 _log = None
 
@@ -41,6 +49,27 @@ class FakeArgs(dict):
         self.__dict__ = self
 
 
+def get_bdb_impl_status():
+    backldbm = 'libback-ldbm'
+    bundledbdb_plugin = 'libback-ldbm'
+    robdb_symbol = 'bdbro_getcb_vector'
+    libdb = 'libdb-'
+    plgstrs = check_plugin_strings(backldbm, [bundledbdb_plugin, robdb_symbol, libdb])
+    if plgstrs[bundledbdb_plugin] is True:
+        # bundled bdb build
+        if find_plugin_path(bundledbdb_plugin):
+            return BDB_IMPL_STATUS.BUNDLED
+        return BDB_IMPL_STATUS.NONE
+    if plgstrs[robdb_symbol] is True:
+        # read-only bdb build
+        return BDB_IMPL_STATUS.READ_ONLY
+    if plgstrs[libdb] is True:
+        # standard bdb package build
+        return BDB_IMPL_STATUS.STANDARD
+    # Unable to find libback-ldbm plugin
+    return BDB_IMPL_STATUS.UNKNOWN
+
+
 def get_ldif_dir(instance):
     """
     Get the server's LDIF directory.
@@ -62,6 +91,7 @@ def get_backends(log, dse, tmpdir):
     # Lets be sure to keep config backend info
     ic2ec['config'] = 'config'
     update_dse = []
+    dbis = None
     for entry in dse._contents:
         found = re.search(r'^nsslapd-backend: (.*)', entry)
         if found:
@@ -71,22 +101,28 @@ def get_backends(log, dse, tmpdir):
             dn = found[0][4:]
             bename = found[1].lower()
             if not bename in ic2ec:
-                # Not a mapping tree backend 
+                # Not a mapping tree backend
                 continue
             ecbename = ic2ec[bename]
             suffix = dse.get(dn, "nsslapd-suffix", True)
             dbdir = dse.get(dn, "nsslapd-directory", True)
             ecdbdir = dbdir
-            if dbdir is None and 'config' in res:
+            dblib = dse.get(dn, "nsslapd-backend-implement", True)
+            if dblib is None and 'config' in res:
+                dblib = res['config']['dblib']
+            if dbis is None:
+                dbis = get_mdb_dbis(dbdir) if dblib == 'mdb' else []
+            # in bdb case dbdir should be the database instance directory
+            # in mdb case it is the database map file directory
+            if 'config' in res and ( dbdir is None or dblib == 'mdb'):
                 dbdir = f"{res['config']['dbdir']}/{bename}"
                 ecdbdir = f"{res['config']['dbdir']}/{ecbename}"
                 # bdb requires nsslapd-directory so lets add it once reading is done.
                 update_dse.append((dn, ecdbdir))
-            dblib = dse.get(dn, "nsslapd-backend-implement", True)
             ldifname = f'{tmpdir}/{DBLIB_LDIF_PREFIX}{bename}.ldif'
             cl5name = f'{tmpdir}/{DBLIB_LDIF_PREFIX}{bename}.cl5.dbtxt'
-            cl5dbname = f'{dbdir}/replication_changelog.db'
-            eccl5dbname = f'{ecdbdir}/replication_changelog.db'
+            cl5dbname = f'{dbdir}/{CL5DB}'
+            eccl5dbname = f'{ecdbdir}/{CL5DB}'
             dbsize = 0
             entrysize = 0
             for f in glob.glob(f'{dbdir}/id2entry.db*'):
@@ -96,8 +132,14 @@ def get_backends(log, dse, tmpdir):
             indexes = dse.get_indexes(bename)
             # Let estimate the number of dbis: id2entry + 1 per regular index + 2 per vlv index
             dbi = 1 + len(indexes) + len([index for index in indexes if index.startswith("vlv#")])
+            if dblib == "bdb":
+                has_changelog = os.path.isfile(eccl5dbname)
+            elif bename in dbis:
+                has_changelog = CL5DB in dbis[bename]
+            else:
+                has_changelog = False
 
-            res[bename] = ({
+            res[bename] = {
                 'dn': dn,
                 'bename': bename,
                 'ecbename': ecbename,
@@ -113,13 +155,15 @@ def get_backends(log, dse, tmpdir):
                 'dbsize': dbsize,
                 'entrysize': entrysize,
                 'indexes': indexes,
+                'has_changelog': has_changelog,
                 'dbi': dbi
-            })
+            }
+
     # now that we finish reading the dse.ldif we may update it if needed.
     for dn, dir in update_dse:
         dse.replace(dn, 'nsslapd-directory', dir)
     log.debug(f'lib389.cli_ctl.dblib.get_backends returns: {str(res)}')
-    return res
+    return (res, dbis)
 
 
 def get_mdb_dbis(dbdir):
@@ -142,14 +186,6 @@ def get_mdb_dbis(dbdir):
     return result
 
 
-def size_fmt(num):
-    for unit in ["B", "KB", "MB", "GB", "TB"]:
-        if (num < 1024):
-            return f"{num:3.1f} {unit}"
-        num /= 1024
-    return f"{num:.1f} TB"
-
-
 def run_dbscan(args):
     prefix = os.environ.get('PREFIX', "")
     prog = f'{prefix}/bin/dbscan'
@@ -165,8 +201,11 @@ def run_dbscan(args):
 
 def export_changelog(be, dblib):
     # Export backend changelog
+    if not be['has_changelog']:
+        return False
     try:
         cl5dbname = be['eccl5dbname'] if dblib == "bdb" else be['cl5dbname']
+        _log.info(f"Exporting changelog {cl5dbname} to {be['cl5name']}")
         run_dbscan(['-D', dblib, '-f', cl5dbname, '-X', be['cl5name']])
         return True
     except subprocess.CalledProcessError as e:
@@ -177,7 +216,8 @@ def import_changelog(be, dblib):
     # import backend changelog
     try:
         cl5dbname = be['eccl5dbname'] if dblib == "bdb" else be['cl5dbname']
-        run_dbscan(['-D', dblib, '-f', cl5dbname, '-I', be['cl5name']])
+        _log.info(f"Importing changelog {cl5dbname} from {be['cl5name']}")
+        run_dbscan(['-D', dblib, '-f', cl5dbname, '--import', be['cl5name'], '--do-it'])
         return True
     except subprocess.CalledProcessError as e:
         return False
@@ -194,6 +234,15 @@ def set_owner(list, uid, gid):
             pass
 
 
+def get_uid_gid_from_dse(dse):
+    # For some reason inst.get_user_uid() always returns dirsrv uid
+    # even for non root install.
+    # Lets looks directly in the dse.ldif intead
+    user = dse.get(DN_CONFIG, 'nsslapd-localuser', single=True)
+    pwent = pwd.getpwnam(user)
+    return ( pwent.pw_uid, pwent.pw_gid )
+
+
 def dblib_bdb2mdb(inst, log, args):
     global _log
     _log = log
@@ -207,12 +256,20 @@ def dblib_bdb2mdb(inst, log, args):
         log.error(f"Failed trying to create the directory {tmpdir} needed to store the ldif files, error: {str(e)}")
         return
 
+    status = get_bdb_impl_status()
+    if status is BDB_IMPL_STATUS.UNKNOWN:
+        log.warning('Unable to determine if Berkeley Database library is available. If it is not the case, the migration will fail.')
+    elif status is BDB_IMPL_STATUS.NONE:
+        log.error('Berkeley Database library is not available. Maybe 389-ds-base-bdb rpm should be installed.')
+        raise RuntimeError('Berkeley Database library is not available')
+
     # Cannot use Backends(inst).list() because it requires a connection.
     # lets use directlt the dse.ldif after having stopped the instance
 
     inst.stop()
     dse = DSEldif(inst)
-    backends = get_backends(log, dse, tmpdir)
+    uid, gid = get_uid_gid_from_dse(dse)
+    backends,dbis = get_backends(log, dse, tmpdir)
     dbmapdir = backends['config']['dbdir']
     dblib = backends['config']['dblib']
 
@@ -223,6 +280,8 @@ def dblib_bdb2mdb(inst, log, args):
     # Remove ldif files and mdb files
     dblib_cleanup(inst, log, args)
 
+    # Check if changelog is present in backends
+
     # Compute the needed space and the lmdb map configuration
     total_dbsize = 0
     total_entrysize = 0
@@ -235,23 +294,23 @@ def dblib_bdb2mdb(inst, log, args):
         total_entrysize += be['entrysize']
         total_dbi += be['dbi']
 
-    # Round up dbmap size
-    dbmap_size = DEFAULT_DBMAP_SIZE
-    while (total_dbsize * DBSIZE_MARGIN > dbmap_size):
-        dbmap_size *= 1.25
+    required_dbsize = round(total_dbsize * DBSIZE_MARGIN)
+
+    # Compute a dbmap size greater than required_dbsize
+    dbmap_size = parse_size(DEFAULT_LMDB_SIZE)
+    while (required_dbsize > dbmap_size):
+        dbmap_size = round(dbmap_size * 1.25)
 
     # Round up number of dbis
     nbdbis = 1
     while nbdbis < total_dbi + DBI_MARGIN:
         nbdbis *= 2
 
-    log.info(f"Required space for LDIF files is about {size_fmt(total_entrysize)}")
-    log.info(f"Required space for DBMAP files is about {size_fmt(dbmap_size)}")
+    log.info(f"Required space for LDIF files is about {format_size(total_entrysize)}")
+    log.info(f"Required space for DBMAP files is about {format_size(required_dbsize)}")
     log.info(f"Required number of dbi is {nbdbis}")
 
     # Generate the info file (so dbscan could generate the map)
-    uid = inst.get_user_uid()
-    gid = inst.get_group_gid()
     with open(f'{dbmapdir}/{MDB_INFO}', 'w') as f:
         f.write('LIBVERSION=9025\n')
         f.write('DATAVERSION=0\n')
@@ -260,20 +319,29 @@ def dblib_bdb2mdb(inst, log, args):
         f.write(f'MAXDBS={nbdbis}\n')
     os.chown(f'{dbmapdir}/{MDB_INFO}', uid, gid)
 
-    if os.stat(dbmapdir).st_dev == os.stat(tmpdir).st_dev:
-        total, used, free = shutil.disk_usage(dbmapdir)
-        if free < total_entrysize + dbmap_size:
-            log.error(f"Not enough space on {dbmapdir} to migrate to lmdb (Need {size_fmt(total_entrysize + dbmap_size)}, Have {size_fmt(free)})")
-            return
-    else:
-        total, used, free = shutil.disk_usage(dbmapdir)
-        if free < dbmap_size:
-            log.error(f"Not enough space on {dbmapdir} to migrate to lmdb (Need {size_fmt(dbmap_size)}, Have {size_fmt(free)})")
-            return
+    total, used, free = shutil.disk_usage(dbmapdir)
+    if os.stat(dbmapdir).st_dev != os.stat(tmpdir).st_dev:
+        # Ldif and db are on different filesystems
+        # Let check that we have enough space in tmpdir for ldif files
         total, used, free = shutil.disk_usage(tmpdir)
         if free < total_entrysize:
-            log.error("Not enough space on {tmpdir} to migrate to lmdb (Need {size_fmt(total_entrysize)}, Have {size_fmt(free)})")
-            return
+            raise OSError(ENOSPC, "Not enough space on {tmpdir} to migrate to lmdb " +
+                                  "(In {tmpdir}, {format_size(total_entrysize)} is "+
+                                  "needed but only {format_size(free)} is available)")
+        total_entrysize = 0    # do not count total_entrysize when checking dbmapdir size
+
+    # Let check that we have enough space in dbmapdir for the db and ldif files
+    total, used, free = shutil.disk_usage(dbmapdir)
+    size = required_dbsize + total_entrysize
+    if free < required_dbsize + total_entrysize:
+            raise OSError(ENOSPC, "Not enough space on {tmpdir} to migrate to lmdb " +
+                                  "(In {dbmapdir}, " +
+                                  "{format_size(required_dbsize + total_entrysize)} is "
+                                  "needed but only {format_size(free)} is available)")
+    # Lets use dbmap_size if possible, otherwise use required_dbsize
+    if free < dbmap_size + total_entrysize:
+        dbmap_size = required_dbsize
+
     progress = 0
     encrypt = False       # Should maybe be a args param
     for bename, be in backends.items():
@@ -329,7 +397,7 @@ def dblib_bdb2mdb(inst, log, args):
     dbhome=backends["config"]["dbdir"]
     set_owner(glob.glob(f'{dbhome}/*.mdb'), uid, gid)
     log.info("Backends importation 100%")
-    inst.start()
+    inst.start(post_open=False)
     log.info("Migration from Berkeley database to lmdb is done.")
 
 
@@ -346,16 +414,26 @@ def dblib_mdb2bdb(inst, log, args):
         log.error(f"Failed trying to create the directory {tmpdir} needed to store the ldif files, error: {str(e)}")
         return
 
+    status = get_bdb_impl_status()
+    if status is BDB_IMPL_STATUS.UNKNOWN:
+        log.warning('Unable to determine if Berkeley Database library is available. If it is not the case, the migration will fail.')
+    elif status is BDB_IMPL_STATUS.READ_ONLY:
+        log.error('It is not possible to migrate to read-only Berkeley Database library.')
+        raise RuntimeError('Berkeley Database library is read-only')
+    elif status is BDB_IMPL_STATUS.NONE:
+        log.error('Berkeley Database library is not available. Maybe 389-ds-base-bdb rpm should be installed.')
+        raise RuntimeError('Berkeley Database library is not available')
+
     # Cannot use Backends(inst).list() because it requires a connection.
     # lets use directlt the dse.ldif after having stopped the instance
 
     inst.stop()
     dse = DSEldif(inst)
-    backends = get_backends(log, dse, tmpdir)
+    uid, gid = get_uid_gid_from_dse(dse)
+    backends,dbis = get_backends(log, dse, tmpdir)
     dbmapdir = backends['config']['dbdir']
     dbhome = inst.ds_paths.db_home_dir
     dblib = backends['config']['dblib']
-    dbis = get_mdb_dbis(dbmapdir)
 
     if dblib == "bdb":
         log.error(f"Instance {inst.serverid} is already configured with bdb.")
@@ -376,23 +454,26 @@ def dblib_mdb2bdb(inst, log, args):
     # Clearly over evaluated (but better than nothing )
     total_entrysize = dbmap_size
 
-    log.info(f"Required space for LDIF files is about {size_fmt(total_entrysize)}")
-    log.info(f"Required space for bdb files is about {size_fmt(dbmap_size)}")
+    log.info(f"Required space for LDIF files is about {format_size(total_entrysize)}")
+    log.info(f"Required space for bdb files is about {format_size(dbmap_size)}")
 
-    if os.stat(dbmapdir).st_dev == os.stat(tmpdir).st_dev:
-        total, used, free = shutil.disk_usage(dbmapdir)
-        if free < total_entrysize + dbmap_size:
-            log.error(f"Not enough space on {dbmapdir} to migrate to bdb (Need {size_fmt(total_entrysize + dbmap_size)}, Have {size_fmt(free)})")
-            return
-    else:
-        total, used, free = shutil.disk_usage(dbmapdir)
-        if free < dbmap_size:
-            log.error(f"Not enough space on {dbmapdir} to migrate to bdb (Need {size_fmt(dbmap_size)}, Have {size_fmt(free)})")
-            return
+    if os.stat(dbmapdir).st_dev != os.stat(tmpdir).st_dev:
+        # Ldif and db are on different filesystems
+        # Let check that we have enough space for ldif files
         total, used, free = shutil.disk_usage(tmpdir)
         if free < total_entrysize:
-            log.error("Not enough space on {tmpdir} to migrate to bdb (Need {size_fmt(total_entrysize)}, Have {size_fmt(free)})")
-            return
+            raise OSError(ENOSPC, "Not enough space on {tmpdir} to migrate to bdb " +
+                                  "(In {tmpdir}, {format_size(total_entrysize)} bytes "+
+                                  "are needed but only {format_size(free)} are available)")
+        total_entrysize = 0    # do not count total_entrysize when checking dbmapdir size
+
+    # Let check that we have enough space for the db and ldif files
+    total, used, free = shutil.disk_usage(dbmapdir)
+    if free < dbmap_size + total_entrysize:
+            raise OSError(ENOSPC, "Not enough space on {tmpdir} to migrate to bdb " +
+                                  "(In {dbmapdir}, {format_size(dbmap_size+total_entrysize)} "+
+                                  "is needed but only {format_size(free)} is available)")
+
     progress = 0
     encrypt = False       # Should maybe be a args param
     total_dbsize = 0
@@ -401,8 +482,6 @@ def dblib_mdb2bdb(inst, log, args):
         if 'has_id2entry' not in be:
             continue
         total_dbsize += 1
-    uid = inst.get_user_uid()
-    gid = inst.get_group_gid()
     for bename, be in backends.items():
         # Keep only backend associated with a db
         if 'has_id2entry' not in be:
@@ -447,7 +526,7 @@ def dblib_mdb2bdb(inst, log, args):
     set_owner((f'{dbhome}/DBVERSION', f'{dbmapdir}/DBVERSION', f'{dbhome}/guardian', '{dbmapdir}/guardian'), uid, gid)
 
     log.info("Backends importation 100%")
-    inst.start()
+    inst.start(post_open=False)
     log.info("Migration from ldbm to Berkeley database is done.")
 
 
@@ -464,7 +543,7 @@ def dblib_cleanup(inst, log, args):
     _log = log
     tmpdir = get_ldif_dir(inst)
     dse = DSEldif(inst)
-    backends = get_backends(log, dse, tmpdir)
+    backends,dbis = get_backends(log, dse, tmpdir)
     dbmapdir = backends['config']['dbdir']
     dbhome = inst.ds_paths.db_home_dir
     dblib = backends['config']['dblib']
@@ -475,14 +554,19 @@ def dblib_cleanup(inst, log, args):
         # Keep only backend associated with a db
         if 'has_id2entry' not in be and be['dbsize'] == 0:
             continue
-        rm(be['ldifname'])
-        rm(be['cl5name'])
-        dbdir = be['dbdir']
-        if dblib == "mdb":
-            # remove db dir
-            for f in glob.glob(f'{dbdir}/*.db*'):
+        # rm(be['ldifname'])
+        # rm(be['cl5name'])
+
+    if dblib == "mdb":
+        # Looks for bdb database instance subdirectories
+        for id2entry in glob.glob(f'{dbmapdir}/*/id2entry.db*'):
+            dbdir = Path(id2entry).parent.absolute()
+            log.info(f"cleanup removing {dbdir}")
+            for f in glob.iglob(f'{dbdir}/*.db*'):
                 rm(f)
-            rm(f'{dbdir}/DBVERSION')
+            for f in [ 'guardian', 'DBVERSION' ]:
+                if os.path.isfile(f'{dbdir}/{f}'):
+                    rm(f'{dbdir}/{f}')
             os.rmdir(dbdir)
 
     if dblib == "bdb":
@@ -490,13 +574,13 @@ def dblib_cleanup(inst, log, args):
         rm(f'{dbmapdir}/data.mdb')
         rm(f'{dbmapdir}/lock.mdb')
     else:
-        for f in glob.glob(f'{dbhome}/__db.*'):
+        for f in glob.iglob(f'{dbhome}/__db.*'):
             rm(f)
-        for f in glob.glob(f'{dbmapdir}/__db.*'):
+        for f in glob.iglob(f'{dbmapdir}/__db.*'):
             rm(f)
-        for f in glob.glob(f'{dbhome}/log.*'):
+        for f in glob.iglob(f'{dbhome}/log.*'):
             rm(f)
-        for f in glob.glob(f'{dbmapdir}/log.*'):
+        for f in glob.iglob(f'{dbmapdir}/log.*'):
             rm(f)
         rm(f'{dbhome}/DBVERSION')
         rm(f'{dbmapdir}/DBVERSION')
@@ -505,16 +589,16 @@ def dblib_cleanup(inst, log, args):
 
 
 def create_parser(subparsers):
-    dblib_parser = subparsers.add_parser('dblib', help="database library (i.e bdb/lmdb) migration")
+    dblib_parser = subparsers.add_parser('dblib', help="database library (i.e bdb/lmdb) migration", formatter_class=CustomHelpFormatter)
     subcommands = dblib_parser.add_subparsers(help="action")
 
-    dblib_bdb2mdb_parser = subcommands.add_parser('bdb2mdb', help='Migrate bdb databases to lmdb')
+    dblib_bdb2mdb_parser = subcommands.add_parser('bdb2mdb', help='Migrate bdb databases to lmdb', formatter_class=CustomHelpFormatter)
     dblib_bdb2mdb_parser.set_defaults(func=dblib_bdb2mdb)
     dblib_bdb2mdb_parser.add_argument('--tmpdir', help="ldif migration files directory path.")
 
-    dblib_mdb2bdb_parser = subcommands.add_parser('mdb2bdb', help='Migrate lmdb databases to bdb')
+    dblib_mdb2bdb_parser = subcommands.add_parser('mdb2bdb', help='Migrate lmdb databases to bdb', formatter_class=CustomHelpFormatter)
     dblib_mdb2bdb_parser.set_defaults(func=dblib_mdb2bdb)
     dblib_mdb2bdb_parser.add_argument('--tmpdir', help="ldif migration files directory path.")
 
-    dblib_cleanup_parser = subcommands.add_parser('cleanup', help='Remove migration ldif file and old database')
+    dblib_cleanup_parser = subcommands.add_parser('cleanup', help='Remove migration ldif file and old database', formatter_class=CustomHelpFormatter)
     dblib_cleanup_parser.set_defaults(func=dblib_cleanup)
