@@ -52,8 +52,8 @@ def _get_args(args, kws):
     return kwargs
 
 
-def _get_basedn_arg(inst, args, log, msg=None):
-    basedn_arg = _get_dn_arg(args.basedn, msg="Enter basedn")
+def _get_basedn_arg(inst, args, basedn, log, msg=None):
+    basedn_arg = _get_dn_arg(basedn, msg="Enter basedn")
     if not DSLdapObject(inst, basedn_arg).exists():
         raise ValueError(f'The base DN "{basedn_arg}" does not exist.')
 
@@ -141,7 +141,7 @@ def _generic_get(inst, basedn, log, manager_class, selector, args=None):
 def _generic_get_dn(inst, basedn, log, manager_class, dn, args=None):
     mc = manager_class(inst, basedn)
     o = mc.get(dn=dn)
-    o_str = o.__unicode__()
+    o_str = o.display()
     log.info(o_str)
 
 
